@@ -23,6 +23,11 @@
 #else
 #include <ext/hash_map>
 #endif
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string>
 
 #include <GL/gl.h>
@@ -35,13 +40,14 @@
 #include <tulip/TemplateFactory.h>
 #include <tulip/Reflect.h>
 #include <tulip/MutableContainer.h>
-
+#include <tulip/hash_string.h>
 #include <tulip/tulipconf.h>
 #include "tulip/Camera.h"
 #include "tulip/GlGraphStrategy.h"
 #include "tulip/OcclusionTest.h"
 #include "tulip/ObservableGlGraph.h"
 
+
 class LayoutProxy;
 class MetricProxy;
 class StringProxy;
@@ -56,7 +62,7 @@ class GlyphFactory;
 class GlyphContext;
 class OcclusionTest;
 class PluginLoader;
-
+class TextRenderer;
 
 enum DrawState {DRAWEDGE = 0, DRAWNODE = 1, DRAWSELECTEDNODELABELS = 2, DRAWSELECTEDEDGELABELS = 3,
 		DRAWNODELABELS = 4 , DRAWEDGELABELS = 5 , DRAWEND = 6};
@@ -66,7 +72,7 @@ enum DrawState {DRAWEDGE = 0, DRAWNODE = 1, DRAWSELECTEDNODELABELS = 2, DRAWSELE
  *  It also includes 3D navigation capabilities and selection methods.
  *  All the displaying is done with OpenGl.
  */
-class GlGraph : public GraphObserver, public ObservableGlGraph {
+class TLP_GL_SCOPE GlGraph : public GraphObserver, public ObservableGlGraph {
   
 public:
   GlGraph(GlGraphStrategy &strategy);
@@ -174,6 +180,9 @@ public:
    * \sa fontsType
    */
   void setFontsType(unsigned int type);
+  /** set the path for the fonts loading
+   */
+  void setFontsPath(std::string path);
   /** if true activate the Orthogonal projection, else perspective is used.
    * \sa isViewOrtho
    */
@@ -190,10 +199,12 @@ public:
    *  \sa setIncrementalRendering
    */
   bool isIncrementalRendering() const;
-  void setViewKey(const bool state);
-  bool isViewKey() const;
-  void setDisplayEdges(const bool state);
 
+  /*If true and if labels are activated label inside meta nodes will be displayed */
+  void setViewMetaLabel(const bool state);
+  bool isViewMetaLabel() const;
+
+  void setDisplayEdges(const bool state);
   bool isDisplayEdges() const;
   /** activate Strahler drawing mode. The graph is then drawn in Strahler order
    *  \sa isViewStrahler
@@ -349,6 +360,13 @@ public:
    */
   SuperGraph* getSuperGraph() const;
 
+
+  /**
+   * Define the name of the layout that is used
+   * for rendering the graph (default is "viewLayout")
+   */
+  void setInputLayout(const std::string &layoutName);
+
   static TemplateFactory<GlyphFactory,Glyph,GlyphContext *> glyphFactory;
   static std::string glyphName(int id);
   static int glyphId(std::string name);
@@ -365,21 +383,21 @@ protected:
   void delEdge (SuperGraph *, const edge);
   void destroy (SuperGraph *);
   float projectSize(const Coord&, const Size&);
-  void drawPixmapFont(const std::string &str, const Coord &position, bool selected);
+  void drawPixmapFont(const std::string &str, const Coord &position, bool selected, float width);
   void drawEdge(const Coord &startNode, const Coord &finalNode,
                 const Coord &startPoint,const LineType::RealType &bends, const Coord &endPoint,
 		const Color &startColor, const Color &endColor, const Size &size, int shape, const bool selected=false);
   void drawEdge(edge ite);
-  unsigned int drawEdges(unsigned int , Iterator<edge> *);
+  unsigned int drawEdges(unsigned int , Iterator<edge> *, unsigned int = 0);
   void drawNode(node itv,unsigned int depth);
-  unsigned int drawNodes(unsigned int , Iterator<node> *);
-  unsigned int drawLabels(unsigned int , Iterator<node> *, bool);
-  void drawLabel(node itn);
-  void drawEdgeLabel(edge e);
-  unsigned int drawEdgeLabels(unsigned int number, Iterator<edge> *itE, bool mode);
+  unsigned int drawNodes(unsigned int , Iterator<node> *, unsigned int = 0);
+  unsigned int drawNodeLabels(unsigned int , Iterator<node> *, bool, unsigned int =0);
+  void drawNodeLabel(node itn, bool, unsigned int);
+  void drawEdgeLabel(edge e, bool);
+  unsigned int drawEdgeLabels(unsigned int number, Iterator<edge> *itE, bool, unsigned int =0);
   void drawFanNode(node n) ;
   unsigned int drawFanNodes(unsigned int , Iterator<node> *);
-  void drawMetaNode(node n,unsigned int depth, bool label = false);
+  void drawMetaNode(node n,unsigned int depth, bool = false, bool = false);
   void DrawBitmapString(void *, const char *);
   void DrawStrokeString(void *font, const char *string);
   void makeArrowMatrix(GLfloat *, const Coord , const Coord , GLfloat, GLfloat, GLfloat);
@@ -398,7 +416,7 @@ protected:
   void buildDisplayLists();
   void deleteDisplayLists();
   void transparentSphere();
-  void cubeWire();
+  void cube(GLenum type);
   void solidCone();
 
 
@@ -407,10 +425,11 @@ private:
   SuperGraph     *_superGraph;
   Color  backgroundColor;
 
-  bool _viewArrow, _viewLabel, _viewKey, _viewStrahler;
+  bool _viewArrow, _viewLabel, _viewMetaLabel, _viewStrahler;
   bool _viewAutoScale, _incrementalRendering, _edgeColorInterpolate, _edge3D;
   unsigned int _viewOrtho;
   unsigned int _FontsType;
+  std::string fontsPath;
   bool _displayEdges;
   
   //  stdext::hash_map<int, Glyph *, stdext::hash<int> >  glyphTable;
@@ -440,7 +459,7 @@ private:
   //we never have to get a copy of that GlGraph.
   //GlGraph objects should be only passed by reference or pointer
   GlGraph(const GlGraph &);
-
+  static void loadPlugins(std::string dir, PluginLoader *plug);
 
 private:
 
@@ -487,6 +506,10 @@ private:
 
   //Occlusion testing
   OcclusionTest occlusionTest;
+
+  //
+  std::string layoutName;
+  TextRenderer * fontRenderer;
 };
 
 
