@@ -19,14 +19,6 @@ public:
 
   //
   virtual void mPaint(GlGraph *)=0;
-  /*
-  virtual void outputSetText(const std::string&)=0;
-  virtual const std::string outputGetText()=0;
-  */
-  //
-  //GlGraph will call this if it can't handle Observable
-  //  virtual void update(std::set<Observable *>::iterator itb)=0;
-
 
   bool toUpdate;
 };
