@@ -2,6 +2,10 @@
 #ifndef GLYPH_H
 #define GLYPH_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <tulip/Plugin.h>
 #include <tulip/WithParameter.h>
 #include <tulip/Size.h>
@@ -26,7 +30,7 @@ public:
   ~GlyphContext(){};
 };
 
-class Glyph : public WithParameter
+class TLP_GL_SCOPE Glyph : public WithParameter
 {
 protected:
   SuperGraph **superGraph;
