@@ -6,7 +6,11 @@
 #include FT_GLYPH_H
 
 #include <FTGL.h>
+#ifdef _WIN32
+#include "../../../thirdparty/ftgl/FTGlyph.h"
+#else
 #include <FTGlyph.h>
+#endif
 
 /**
  * TLPPixmapGlyph is a specialisation of FTGlyph for creating pixmaps.
