@@ -11,13 +11,6 @@ Context::Context(string str, int s, unsigned char r, unsigned char v, unsigned c
   font_name = str; size = s;
   c[0] = r;  c[1] = v;  c[2] = b;
 }
-  
-/*Context::Context(const Context& ct){
-  font_name = ct.font_name;
-  size = ct.size;
-  c[0] = ct.c[0];  c[1] = ct.c[1];  c[2] = ct.c[2];
-  }*/
-
 //---------------------------------------------------------------------------
 void Context::getColor(unsigned char& r, unsigned char& v, unsigned char& b) const{
   r = c[0];  v = c[1];  b = c[2];
@@ -35,3 +28,6 @@ bool operator==(Context& a, Context& b){
     return false;
 }
 
+Renderer& Context::getRenderer() const {
+  return *renderer;
+}
