@@ -1,7 +1,4 @@
 //-*-c++-*-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include <list>
 #include <cmath>
@@ -28,6 +25,7 @@
 #include <tulip/MetaGraphProxy.h>
 #include <tulip/SuperGraph.h>
 #include <tulip/TemplateFactory.h>
+#include <tulip/DrawingTools.h>
 
 #include "tulip/GlGraph.h"
 #include "tulip/Color.h"
@@ -37,6 +35,7 @@
 #include "tulip/TlpTools.h"
 #include "tulip/Glyph.h"
 #include "tulip/PluginLoader.h"
+#include "tulip/TextRenderer.h"
 
 using namespace std;
 
@@ -44,9 +43,19 @@ using namespace std;
 //test 
 #include <sys/timeb.h>
 //====================================================
+#ifdef _WIN32 
+#ifdef DLL_EXPORT
 TemplateFactory<GlyphFactory,Glyph,GlyphContext *> GlGraph::glyphFactory;
 stdext::hash_map<int,std::string>  GlGraph::idToName;
 stdext::hash_map<std::string, int> GlGraph::nameToId;
+#endif
+#else
+TemplateFactory<GlyphFactory,Glyph,GlyphContext *> GlGraph::glyphFactory;
+stdext::hash_map<int,std::string>  GlGraph::idToName;
+stdext::hash_map<std::string, int> GlGraph::nameToId;
+#endif
+
+
 std::string GlGraph::glyphName(int id) {
   if (idToName.find(id)!=idToName.end())
     return idToName[id];
@@ -67,29 +76,44 @@ int GlGraph::glyphId(std::string name) {
   }
 }
 //====================================================
-void GlGraph::loadPlugins(PluginLoader *plug) {
-  string getEnvVar=tlp::TulipLibDir + "/tlp/plugins/";
-  GlGraph::glyphFactory.load(getEnvVar + "glyph", "Glyph", plug);
+void GlGraph::loadPlugins(string dir, PluginLoader *plug) {
+  GlGraph::glyphFactory.load(dir + "glyph", "Glyph", plug);
   idToName.clear();
   nameToId.clear();
   Iterator<string> *itS=glyphFactory.availablePlugins();
   while (itS->hasNext()) {
-    string pluginName=itS->next();
+  	string pluginName=itS->next();
     int pluginId=glyphFactory.objMap[pluginName]->getId();
     idToName[pluginId]=pluginName;
     nameToId[pluginName]=pluginId;
   } delete itS;
 }
 //====================================================
+void GlGraph::loadPlugins(PluginLoader *plug) {
+  string::const_iterator begin=tlp::TulipPluginsPath.begin();
+  string::const_iterator end=begin;
+  while (end!=tlp::TulipPluginsPath.end())
+    if ((*end)==tlp::PATH_DELIMITER) {
+      if (begin!=end) 
+	loadPlugins(string(begin,end)+"/",plug);
+      ++end;
+      begin=end;
+    } else
+      ++end;
+  if (begin!=end) 
+    loadPlugins(string(begin,end)+"/",plug);
+}
+//====================================================
 //dummy constructor made private since we want to forbid calling copy constructor
-GlGraph::GlGraph(const GlGraph &) {}
+GlGraph::GlGraph(const GlGraph &) { 
+}
 
 GlGraph::GlGraph(GlGraphStrategy &strategy):
   strategy(&strategy),
   _superGraph(0),
   backgroundColor(65,65,65),
   _viewArrow(false), _viewLabel(false),
-  _viewKey(false), _viewStrahler(false),
+  _viewMetaLabel(false), _viewStrahler(false),
   _viewAutoScale(true),  _incrementalRendering(true),_edgeColorInterpolate(true), _edge3D(false),
   _viewOrtho(true), _FontsType(0),
   elementColor(0), elementSize(0),elementShape(0),elementSelected(0),elementLabel(0),
@@ -110,16 +134,13 @@ GlGraph::GlGraph(GlGraphStrategy &strategy):
   drawEdgeSelectedLabelsIterator(0),
   winX(0), winY(0),
   winH(480), winW(640),
-  labelsBorder(2)
+  labelsBorder(2),
+  layoutName("viewLayout")
 {
   initProxies();
   TRACE_EXEC();
-  // cerr << "GlGraph constructor" << endl;
-  // it loads a default glyphTable
-  // later setGlyphTable can be called to set a particular order of glyphs,
-  // then completed by missing glyphs in this new table
-  //  buildDisplayLists();
-  //  cerr << "GlGraph constructor Ok" << endl;
+  fontsPath = tlp::TulipLibDir + "tlp/bitmaps/";
+  fontRenderer = new TextRenderer();
 }
 
 GlGraph::GlGraph(GlGraphStrategy &strategy, const GlGraph &g) :
@@ -127,7 +148,7 @@ GlGraph::GlGraph(GlGraphStrategy &strategy, const GlGraph &g) :
   _superGraph(g._superGraph),
   backgroundColor(g.backgroundColor),
   _viewArrow(g._viewArrow), _viewLabel(g._viewLabel),
-  _viewKey(g._viewKey), _viewStrahler(g._viewStrahler),
+  _viewMetaLabel(g._viewMetaLabel), _viewStrahler(g._viewStrahler),
   _viewAutoScale(g._viewAutoScale), _incrementalRendering(g._incrementalRendering),
   _edgeColorInterpolate(g._edgeColorInterpolate), _edge3D(g._edge3D),
   _viewOrtho(g._viewOrtho), _FontsType(g._FontsType),
@@ -158,21 +179,20 @@ GlGraph::GlGraph(GlGraphStrategy &strategy, const GlGraph &g) :
   if (isViewStrahler()) {
     buildOrderedList();
   }
-  //  setGlyphTable(g.getGlyphTable());
+  fontRenderer = new TextRenderer();
 }
 //====================================================
 GlGraph::~GlGraph() {
-  /*  for (unsigned int i=0;i<glyphTable.size();++i)
-    delete glyphTable[i];
-  */
+  notifyDestroy(this);
+  removeObservers();
+  if(_superGraph != 0)
+    _superGraph->removeObserver(this);
   deleteDisplayLists();
+  delete fontRenderer;
 }
 //====================================================
 void GlGraph::initializeGL() {
-  //  cerr << __PRETTY_FUNCTION__ << endl;
   buildDisplayLists();
-  //  GlyphTableGlyph v;
-  //  this->setGlyphTable(v);
 }
 //==================================================
 void GlGraph::centerScene() {
@@ -181,7 +201,6 @@ void GlGraph::centerScene() {
   if (_superGraph==0) return;
   TRACE_EXEC();
   goodScale();
-  //  sceneTranslation.set(0,0,0);
 }
 //====================================================
 void GlGraph::changeViewport( unsigned int x, unsigned int y, unsigned int w, unsigned int h ) {
@@ -201,14 +220,14 @@ SuperGraph* GlGraph::getSuperGraph() const {
 }
 //====================================================
 void GlGraph::setSuperGraph(SuperGraph *superGraph) {
-  //  cerr << __PRETTY_FUNCTION__ << endl;
+  //   cerr << __PRETTY_FUNCTION__ << endl;
   if ( superGraph == _superGraph ) return;
   TRACE_EXEC();
   strategy->timerStop();
   if (_superGraph!=0)
     _superGraph->removeObserver(this);
   if (superGraph!=_superGraph)
-    nbElementsFrame.setAll(100);
+    nbElementsFrame.setAll(200);
   _superGraph=superGraph;
   if (_superGraph == 0) return;
   initProxies();
@@ -220,7 +239,7 @@ void GlGraph::setSuperGraph(SuperGraph *superGraph) {
 }
 //==================================================
 void GlGraph::draw() {
-  //  cerr << __PRETTY_FUNCTION__ << endl;
+  //cerr << __PRETTY_FUNCTION__ << endl;
   Observable::holdObservers();
   strategy->timerStop();
   strategy->MakeCurrent();
@@ -231,25 +250,20 @@ void GlGraph::draw() {
   initModelView();
   drawState = 0;
   currentFrame = 1;
-
   if (_superGraph==0) {
     Observable::unholdObservers();
     return;
   }
   initIterators();
   if (!_incrementalRendering) {
-    if (isViewKey()) 
-      drawFanNodes(_superGraph->numberOfNodes(),drawNodesIterator);
-    else {
-      if (_displayEdges) 
-	drawEdges(_superGraph->numberOfEdges(),drawEdgesIterator);
-      drawNodes(_superGraph->numberOfNodes(),drawNodesIterator);
-      if (isViewLabel()) {
-	drawLabels(_superGraph->numberOfNodes(),drawSelectedLabelsIterator,true);
-	drawEdgeLabels(_superGraph->numberOfEdges(),drawEdgeSelectedLabelsIterator,true);
-	drawLabels(_superGraph->numberOfNodes(),drawLabelsIterator,false);
-	drawEdgeLabels(_superGraph->numberOfEdges(),drawEdgeLabelsIterator,false);
-      }
+    if (_displayEdges) 
+      drawEdges(_superGraph->numberOfEdges(),drawEdgesIterator);
+    drawNodes(_superGraph->numberOfNodes(),drawNodesIterator);
+    if (isViewLabel()) {
+      drawNodeLabels(_superGraph->numberOfNodes(),drawSelectedLabelsIterator,true);
+      drawEdgeLabels(_superGraph->numberOfEdges(),drawEdgeSelectedLabelsIterator,true);
+      drawNodeLabels(_superGraph->numberOfNodes(),drawLabelsIterator,false);
+      drawEdgeLabels(_superGraph->numberOfEdges(),drawEdgeLabelsIterator,false);
     }
     glFinish();
   }
@@ -259,7 +273,7 @@ void GlGraph::draw() {
   strategy->mPaint(this);
   notifyDraw(this);
   Observable::unholdObservers();
-}
+ }
 //====================================================
 int getTime() {
   return (10000*clock())/CLOCKS_PER_SEC;
@@ -280,7 +294,7 @@ bool GlGraph::drawPart() {
   unsigned int elementToDraw = nbElementsFrame.get(currentFrame);
   switch (drawState) {
   case DRAWEDGE :
-    if (!_displayEdges || !drawEdgesIterator->hasNext()) 
+   if (!_displayEdges || !drawEdgesIterator->hasNext()) 
       drawState++;
     else {
       elementToDraw -= drawEdges(elementToDraw, drawEdgesIterator);
@@ -288,23 +302,23 @@ bool GlGraph::drawPart() {
       else drawState++;
     }
   case DRAWNODE :
-    if (!drawNodesIterator->hasNext())
+  if (!drawNodesIterator->hasNext())
       drawState ++;
     else {
       elementToDraw -= drawNodes(elementToDraw, drawNodesIterator);
       if (drawNodesIterator->hasNext()) break;
       else drawState++;
-    }
+     }
   case DRAWSELECTEDNODELABELS :
-    if (!isViewLabel() || !drawSelectedLabelsIterator->hasNext())
+     if (!isViewLabel() || !drawSelectedLabelsIterator->hasNext())
       drawState++;
     else {
-      elementToDraw -= drawLabels(elementToDraw, drawSelectedLabelsIterator,true);
+      elementToDraw -= drawNodeLabels(elementToDraw, drawSelectedLabelsIterator,true);
       if (drawSelectedLabelsIterator->hasNext()) break;
       else drawState++;
     }
   case DRAWSELECTEDEDGELABELS :
-    if (!isViewLabel() || !_displayEdges || !drawEdgeSelectedLabelsIterator->hasNext())
+     if (!isViewLabel() || !_displayEdges || !drawEdgeSelectedLabelsIterator->hasNext())
       drawState++;
     else {
       elementToDraw -= drawEdgeLabels(elementToDraw, drawEdgeSelectedLabelsIterator,true);
@@ -315,7 +329,7 @@ bool GlGraph::drawPart() {
     if (!isViewLabel() || !drawLabelsIterator->hasNext())
       drawState++;
     else {
-      elementToDraw -= drawLabels(elementToDraw, drawLabelsIterator,false);
+      elementToDraw -= drawNodeLabels(elementToDraw, drawLabelsIterator,false);
       if (drawLabelsIterator->hasNext()) break;
       else drawState++;
     }
@@ -331,7 +345,6 @@ bool GlGraph::drawPart() {
     if (drawState==DRAWEND) finished=true;
   }
   endTime=getTime();
-
   unsigned int elapsedTime = endTime - startTime;
   unsigned int elementDrawn = nbElementsFrame.get(currentFrame) - elementToDraw;
   if (elapsedTime > 0 && elementDrawn > 0)
@@ -350,19 +363,34 @@ void GlGraph::goodScale() {
   if (_superGraph==0) return;
   initProxies();
   //  cerr << __PRETTY_FUNCTION__ << endl;
-  TRACE_EXEC();
+  
+  pair<Coord, Coord> bboxes = tlp::computeBoundingBox(_superGraph, elementLayout, elementSize);
+  Coord maxC = bboxes.first;
+  Coord minC = bboxes.second;
+  
+  /*
   double dx=elementSize->getMax(_superGraph)[0] + elementLayout->getMax(_superGraph)[0]
     - elementLayout->getMin(_superGraph)[0];
   double dy=elementSize->getMax(_superGraph)[1] + elementLayout->getMax(_superGraph)[1]
     - elementLayout->getMin(_superGraph)[1];
   double dz=elementSize->getMax(_superGraph)[2] + elementLayout->getMax(_superGraph)[2]
     - elementLayout->getMin(_superGraph)[2];
-  sceneTranslation[0]=- (elementLayout->getMax(_superGraph)[0]+elementLayout->getMin(_superGraph)[0])/2.0;
-  sceneTranslation[1]=- (elementLayout->getMax(_superGraph)[1]+elementLayout->getMin(_superGraph)[1])/2.0;
-  sceneTranslation[2]=- (elementLayout->getMax(_superGraph)[2]+elementLayout->getMin(_superGraph)[2])/2.0;
+  */
+  double dx = maxC[0] - minC[0];
+  double dy = maxC[1] - minC[1];
+  double dz = maxC[2] - minC[2];
+
+  /*
+    sceneTranslation[0]=- (elementLayout->getMax(_superGraph)[0]+elementLayout->getMin(_superGraph)[0])/2.0;
+    sceneTranslation[1]=- (elementLayout->getMax(_superGraph)[1]+elementLayout->getMin(_superGraph)[1])/2.0;
+    sceneTranslation[2]=- (elementLayout->getMax(_superGraph)[2]+elementLayout->getMin(_superGraph)[2])/2.0;
+  */
+  Coord center = (maxC + minC) / -2.0;
+  sceneTranslation = center;
+
   if ((dx==0) && (dy==0) && (dz==0))
     dx=dy=dz=10;
-  distCam=sqrt(dx*dx+dy*dy+dz*dz)/2; //radius of the sphere hull of the layout bounding box
+  distCam = sqrt(dx*dx+dy*dy+dz*dz)/2; //radius of the sphere hull of the layout bounding box
   cameraEyes.set(0,0,-distCam);
   cameraCenter.set(0,0,0);
   cameraUp.set(0,1,0);
@@ -398,11 +426,11 @@ void GlGraph::outputEPS(int size, int doSort, const char *filename) {
   delete drawEdgesIterator;
   drawNodesIterator=_superGraph->getNodes();
   if (_viewLabel)
-    drawLabels(_superGraph->numberOfNodes(), drawNodesIterator, true);
+    drawNodeLabels(_superGraph->numberOfNodes(), drawNodesIterator, true);
   delete drawNodesIterator;
   drawNodesIterator=_superGraph->getNodes();
   if (_viewLabel)
-    drawLabels(_superGraph->numberOfNodes(), drawNodesIterator, false);
+    drawNodeLabels(_superGraph->numberOfNodes(), drawNodesIterator, false);
   delete drawNodesIterator;
   glFlush();
   returned = glRenderMode(GL_RENDER);
@@ -424,15 +452,15 @@ unsigned char * GlGraph::getImage(int &w, int &h) {
   strategy->timerStop();
   strategy->MakeCurrent();
   bool saveState=_incrementalRendering;
-  _incrementalRendering=false;
-  draw();
-  _incrementalRendering=saveState;
   w=winW;
   h=winH;
   unsigned char *image=(unsigned char *)malloc(w*h*3*sizeof(unsigned char));
-  strategy->MakeCurrent();
+  _incrementalRendering=false;
+  draw();
+  strategy->MakeCurrent(); //necessary because notify inside draw, the openGL context can change.
   glPixelStorei(GL_PACK_ALIGNMENT,1);
   glReadPixels(winX,winY,winW,winH,GL_RGB,GL_UNSIGNED_BYTE,image);
+  _incrementalRendering=saveState;
   return image;
 }
 //====================================================
@@ -521,8 +549,15 @@ void GlGraph::delEdge (SuperGraph *, const edge e) {
 }
 //====================================================
 void GlGraph::destroy (SuperGraph *graph) {
-  cerr << __PRETTY_FUNCTION__ << endl;
-  _superGraph=0;
+  //  cerr << __PRETTY_FUNCTION__ << endl;
+  if (graph->getRoot()!=graph) {
+    setSuperGraph(graph->getRoot());
+    goodScale();
+    centerScene();
+    draw();
+  }
+  else
+    setSuperGraph(0);
 }
 //====================================================
 /**
@@ -564,7 +599,7 @@ void GlGraph::initProxies() {
     elementColor=_superGraph->getProperty<ColorsProxy>("viewColor");
     elementShape=_superGraph->getProperty<IntProxy>("viewShape");
     elementSize=_superGraph->getProperty<SizesProxy>("viewSize");
-    elementLayout=_superGraph->getProperty<LayoutProxy>("viewLayout");
+    elementLayout=_superGraph->getProperty<LayoutProxy>(layoutName);
     elementMetaGraph=_superGraph->getProperty<MetaGraphProxy>("viewMetaGraph");
     elementTexture=_superGraph->getProperty<StringProxy>("viewTexture");
   }
