@@ -13,28 +13,30 @@
 #include <tulip/SizesProxy.h>
 #include <tulip/ColorsProxy.h>
 #include <tulip/TlpTools.h>
-#include "tulip/GlFonts.h"
+#include "tulip/GlRenderer.h"
 #include "tulip/GlLines.h"
 #include "tulip/GlGraph.h"
-#include "tulip/FanError.h"
 #include "tulip/Glyph.h"
 #include "tulip/TLPPixmapGlyph.h"
 #include "tulip/TLPPixmapFont.h"
-#include "tulip/Rendu.h"
-#include "tulip/DynamicFunctions.h"
-
-
-//static FTFont* normalFont=0;
-//static FTFont* selectFont=0;
-static Rendu* myRender = new Rendu();
+#include "tulip/TextRenderer.h"
+#include "tulip/DrawingTools.h"
+using namespace std;
+//====================================================
 static const unsigned int TLPMAXDEPTH=10;
 const Color colorSelect= Color(255, 102, 255, 255);
 static float colorMat[4] = { 0.0, 0.0, 0.0, 1.0 };
-
+//====================================================
+bool glTest(){
+  if (glGetError()!=GL_NO_ERROR) 
+    return false;
+  return true;
+}
 //====================================================
 inline void SetColor(const Color &c) {
-  glColor4ub(c[0],c[1],c[2],c[3]);
+  glColor4ub(c[0],c[1],c[2], 255);
 }
+//====================================================
 inline void setMaterial(const Color &C) {
   colorMat[0]=((float)C[0])/255.0;
   colorMat[1]=((float)C[1])/255.0;
@@ -42,166 +44,247 @@ inline void setMaterial(const Color &C) {
   glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, colorMat);
 }
 //====================================================
-void GlGraph::drawMetaNode(node n,unsigned int depth, bool labels) {
-  SuperGraph *sp=_superGraph;
-  _superGraph=elementMetaGraph->getNodeValue(n);
-  initProxies();
-  Coord maxL=elementLayout->getMax(_superGraph);
-  Coord minL=elementLayout->getMin(_superGraph);
-  Size  maxS=elementSize->getMax(_superGraph);
-  double saveMatrix[16];
-  for (unsigned int i=0;i<16;++i) saveMatrix[i]=modelviewMatrix[i];
-  Coord translate= (elementLayout->getMax(_superGraph)+elementLayout->getMin(_superGraph))/-2.0;
-  double max=maxS[0]+maxL[0]-minL[0];
-  max=max>?maxS[1]+maxL[1]-minL[1];
-  max=max>?maxS[2]+maxL[2]-minL[2];
-  
-  if (max<0.0001) max=1;
-  max=1/max;
-  glPushMatrix();
-  glScalef(max,max,max);
-  glTranslatef(translate[0],translate[1],translate[2]);
-  glGetDoublev (GL_MODELVIEW_MATRIX, modelviewMatrix);
-
-  Iterator<node> *itN=_superGraph->getNodes();
-  while (itN->hasNext()) {
-    node itn=itN->next();
-    if (!labels)
-      drawNode(itn,depth+1);
-    else {
-      drawLabel(itn);
-    }
-  } delete itN;
-
-  Iterator<edge> *itE=_superGraph->getEdges();
-  while (itE->hasNext()) {
-    edge ite=itE->next();
-    if (!labels)
-      drawEdge(ite);
-    else
-      drawEdgeLabel(ite);
-  } delete itE;
-  
-  glPopMatrix();
-  _superGraph=sp;
-  initProxies();
-  for (unsigned int i=0;i<16;++i) modelviewMatrix[i]=saveMatrix[i];
-}
-//====================================================
 float GlGraph::projectSize(const Coord& position, const Size& size) {
   bool project;  
   double x1Scr,y1Scr,zScr;
   double x2Scr,y2Scr;
-  if (project=(gluProject(position[0] - size[0],
-			  position[1] - size[1],
-			  position[2] - size[2],
+  bool visible = false;
+  double max = 0;
+  //test x-axis
+  if (project=(gluProject(position[0] - size[0]/2.0, position[1], position[2],
 			  modelviewMatrix,projectionMatrix,viewportArray,&x1Scr,&y1Scr,&zScr) &&
-	       gluProject(position[0] + size[0],
-			  position[1] + size[1],
-			  position[2] + size[2],
+	       gluProject(position[0] + size[0]/2.0,position[1], position[2],
 			  modelviewMatrix,projectionMatrix,viewportArray,&x2Scr,&y2Scr,&zScr)))  {
-    if ( (x1Scr<0.0 && x2Scr<0.0) ||
-	 (x1Scr>winW && x2Scr>winW) ||
-	 (y1Scr<0.0 && y2Scr<0.0) ||
-	 (y1Scr>winH && y2Scr>winH)) {
-      return 0;
+    if (! ((x1Scr<0.0 && x2Scr<0.0) || (x1Scr>winW && x2Scr>winW) ||
+	   (y1Scr<0.0 && y2Scr<0.0) || (y1Scr>winH && y2Scr>winH)) ) {
+      max >?= (x1Scr-x2Scr)*(x1Scr-x2Scr)+(y1Scr-y2Scr)*(y1Scr-y2Scr);
+      visible = true;
     }
   }
-  else 
-    return 0;
-  return ((x1Scr-x2Scr)*(x1Scr-x2Scr)+(y1Scr-y2Scr)*(y1Scr-y2Scr));
+  //test Y-axis
+  if (project=(gluProject(position[0], position[1] - size[1]/2.0, position[2],
+			  modelviewMatrix,projectionMatrix,viewportArray,&x1Scr,&y1Scr,&zScr) &&
+	       gluProject(position[0], position[1] + size[1]/2.0, position[2],
+			  modelviewMatrix,projectionMatrix,viewportArray,&x2Scr,&y2Scr,&zScr)))  {
+    if (!( (x1Scr<0.0 && x2Scr<0.0) || (x1Scr>winW && x2Scr>winW) ||
+	   (y1Scr<0.0 && y2Scr<0.0) || (y1Scr>winH && y2Scr>winH))) {
+      max >?= (x1Scr-x2Scr)*(x1Scr-x2Scr)+(y1Scr-y2Scr)*(y1Scr-y2Scr);
+      visible = true;
+    }
+  }
+  //test z-axis
+  if (project=(gluProject(position[0], position[1], position[2] - size[2]/2.0,
+			  modelviewMatrix,projectionMatrix,viewportArray,&x1Scr,&y1Scr,&zScr) &&
+	       gluProject(position[0], position[1], position[2] + size[2]/2.0,
+			  modelviewMatrix,projectionMatrix,viewportArray,&x2Scr,&y2Scr,&zScr)))  {
+    if (! ((x1Scr<0.0 && x2Scr<0.0) || (x1Scr>winW && x2Scr>winW) ||
+	   (y1Scr<0.0 && y2Scr<0.0) || (y1Scr>winH && y2Scr>winH))) {
+      max >?= (x1Scr-x2Scr)*(x1Scr-x2Scr)+(y1Scr-y2Scr)*(y1Scr-y2Scr);
+      visible = true;
+    }
+  }
+  return max;
+}
+//====================================================
+void GlGraph::drawMetaNode(node n,unsigned int depth, bool labels, bool selectedLabels) {
+  SuperGraph *sp = _superGraph;
+  _superGraph = elementMetaGraph->getNodeValue(n);
+  string layoutNameBackup(layoutName);
+  layoutName = "viewLayout";
+  initProxies();
+  pair<Coord, Coord> bboxes = tlp::computeBoundingBox(_superGraph, elementLayout, elementSize);
+  Coord maxC = bboxes.first;
+  Coord minC = bboxes.second;
+  double saveMatrix[16];
+  for (unsigned int i=0;i<16;++i) saveMatrix[i] = modelviewMatrix[i];
+  Coord translate= (maxC + minC)/ (-2.0);
+  double dept  = maxC[2] - minC[2];
+  double width  = maxC[0] - minC[0];
+  double height = maxC[1] - minC[1];
+  if (width<0.0001) width=1;
+  if (height<0.0001) height=1;
+  if (dept<0.0001) dept=1;
+  glPushMatrix();
+  glScalef(1.0/width, 1.0/height, 1.0/dept);
+  glTranslatef(translate[0],translate[1],translate[2]);
+  glGetDoublev (GL_MODELVIEW_MATRIX, modelviewMatrix);
+  if (_displayEdges) {
+    Iterator<edge> *itE=_superGraph->getEdges();
+    if (!labels)
+      drawEdges(_superGraph->numberOfEdges(), itE, depth+1);
+    else
+      drawEdgeLabels(_superGraph->numberOfEdges(), itE , selectedLabels, depth+1);
+  }
+  Iterator<node> *itN=_superGraph->getNodes();
+  if (!labels)
+    drawNodes(_superGraph->numberOfNodes(), itN , depth+1);
+  else
+    drawNodeLabels(_superGraph->numberOfNodes(), itN , selectedLabels, depth+1);
+  delete itN;
+  glPopMatrix();
+  _superGraph=sp;
+  layoutName = layoutNameBackup;
+  initProxies();
+  for (unsigned int i=0;i<16;++i) modelviewMatrix[i]=saveMatrix[i];
 }
 //====================================================
 void GlGraph::drawNode(node n, unsigned int depth) {
   if (depth>TLPMAXDEPTH) return;
+  this->desactivateTexture();
   const Coord &nodeCoord = elementLayout->getNodeValue(n);
   const Size &nodeSize = elementSize->getNodeValue(n);
   if( nodeSize == Size(0,0,0) )	return;
   float lod= projectSize(nodeCoord,nodeSize);
   if (lod==0) return;
-  if (lod < 8.1) {
+  if (lod <10.0) { //less than four pixel on screen
     const Color &nodeColor = elementColor->getNodeValue(n);
+
     if (!elementSelected->getNodeValue(n)) {
+      glPointSize(3);
       setMaterial(nodeColor);
-    } else
+    } else {
+      glPointSize(4);
       setMaterial(Color(255, 102, 255, 255));
+    }
     glPassThrough(n.id);
+
     glBegin(GL_POINTS);
-     glVertex3f(nodeCoord[0], nodeCoord[1], nodeCoord[2]);
+    glVertex3f(nodeCoord[0], nodeCoord[1], nodeCoord[2]);
     glEnd();
   }
   else {
-    this->desactivateTexture();
     glPushMatrix();
     glTranslatef(nodeCoord[0], nodeCoord[1], nodeCoord[2]);
     glScalef(nodeSize[0], nodeSize[1], nodeSize[2]);
-    if (elementSelected->getNodeValue(n)) {
-      assert(glIsList(selectionDL));
-      glCallList(selectionDL);
-    }
+
     glPassThrough(n.id);
     if (elementMetaGraph->getNodeValue(n) == 0) {
       glyphs.get(elementShape->getNodeValue(n))->draw(n);
     }
     else {
-      setMaterial(colorSelect);
       assert(glIsList(metaGraphDL));
-      glCallList(metaGraphDL);
+      glCallList(metaGraphDL); //cube
       drawMetaNode(n,depth);
     }
+    if (elementSelected->getNodeValue(n)) {
+      assert(glIsList(selectionDL));
+      glCallList(selectionDL);
+    }
     glPopMatrix();
   }
 }
 //====================================================
-unsigned int GlGraph::drawNodes(unsigned int number, Iterator<node> *itN) {
+unsigned int GlGraph::drawNodes(unsigned int number, Iterator<node> *itN, unsigned int depth) {
   if (!itN->hasNext() || number==0) return 0;
+  if (depth>TLPMAXDEPTH) return 0;
   unsigned int tmp=number;
   glPushAttrib(GL_ALL_ATTRIB_BITS);
   glMatrixMode(GL_MODELVIEW); 
   glEnable(GL_LIGHTING);
   glEnable(GL_DEPTH_TEST);
   glDisable(GL_COLOR_MATERIAL);
-  glDisable(GL_BLEND);
   initProxies();
   glPassThrough(-1.0);	  //mark beginning of nodes drawing for feedback mode
   while ((itN->hasNext()) && (number >0)) {
     number--;
-    drawNode(itN->next(),0);
+    drawNode(itN->next(),depth);
   }
   glPassThrough(-1.0);  //mark end of nodes drawing
   glPopAttrib();
   return tmp-number;
 }
 //====================================================
-void GlGraph::drawPixmapFont(const string &str, const Coord &position, bool selected) {
-  /*
-  FTFont *bitmapFont;
-  int rastPos[4];
-  unsigned int border = labelsBorder;
-  float x1, y1, z1, x2, y2, z2;
-  if (selected) {
-    bitmapFont=selectFont;
-    glColor4ub(255,0,0,0);
+unsigned int GlGraph::drawEdges(unsigned int number,Iterator<edge> *itE, unsigned int depth) {
+  if (!itE->hasNext() || number==0) return 0;
+  if (depth>TLPMAXDEPTH) return 0;
+  unsigned int tmp=number;
+  glPushAttrib(GL_ALL_ATTRIB_BITS); 
+  glDisable(GL_LIGHTING);
+  initProxies();
+  while ((itE->hasNext()) && (number>0)) {
+    number--;
+    drawEdge(itE->next());
   }
-  else {
-    bitmapFont=normalFont;
-    glColor4ub(0,0,0,0);
-  }
-  glRasterPos3f(position[0],position[1],position[2]);
-  bitmapFont->BBox( str.c_str(), x1, y1, z1, x2, y2, z2);
-  glBitmap(0,0,0,0,-(x2+x1)/2+x1 - border ,-(y2+y1)/2+y1 - border,0);
-  glGetIntegerv(GL_CURRENT_RASTER_POSITION,rastPos);
-  if (!occlusionTest.addRectangle(RectangleInt2D(rastPos[0],rastPos[1],
-						 rastPos[0]+(int)(x2-x1)+2*border,
-						 rastPos[1]+(int)(y2-y1)+2*border))) {
-    glRasterPos3f(position[0],position[1],position[2]);
-    glBitmap(0,0,0,0,-(x2+x1)/2,-(y2+y1)/2,0);
-    bitmapFont->Render(str.c_str());
-  }
-  */
+  glPopAttrib();
+  return tmp-number;
 }
 //====================================================
-void GlGraph::drawEdgeLabel(edge e) {
+unsigned int GlGraph::drawEdgeLabels(unsigned int number, Iterator<edge> *itE, bool mode, unsigned int depth) {
+  if (!itE->hasNext() || number==0) return 0;
+  if (depth>TLPMAXDEPTH) return 0;
+  unsigned int tmp=number;
+  glPushAttrib(GL_ALL_ATTRIB_BITS);
+  glDisable(GL_LIGHTING);
+  glDepthFunc(GL_ALWAYS );
+  glDisable(GL_COLOR_MATERIAL);
+  initProxies();
+  if(mode)
+    fontRenderer->setContext(fontsPath + "fontb.ttf", 14, 0, 0, 255);
+  else	
+    fontRenderer->setContext(fontsPath + "font.ttf", 12, 255, 255, 255);
+  while ((itE->hasNext()) && (number >0)) {
+    edge ite=itE->next();
+    if (elementSelected->getEdgeValue(ite)==mode){
+      number--;
+      drawEdgeLabel(ite, mode);
+    }
+  }
+  glPopAttrib();
+  return tmp-number;
+}
+//====================================================
+unsigned int GlGraph::drawNodeLabels(unsigned int number, Iterator<node> *itN, bool mode, unsigned int depth) {
+  if (!itN->hasNext() || number==0) return 0;
+  if (depth>TLPMAXDEPTH) return 0;
+  unsigned int tmp=number;
+  glPushAttrib(GL_ALL_ATTRIB_BITS);
+  glDisable(GL_LIGHTING);
+  glDepthFunc(GL_ALWAYS );
+  glDisable(GL_COLOR_MATERIAL);
+  initProxies();
+  if(mode)
+    fontRenderer->setContext(fontsPath + "fontb.ttf", 14, 0, 0, 255);
+   else	
+     fontRenderer->setContext(fontsPath + "font.ttf", 12, 255, 255, 255);
+  while ((itN->hasNext()) && (number >0)) {
+    node itv=itN->next();
+    if (elementSelected->getNodeValue(itv)==mode){
+      number--;
+      drawNodeLabel(itv, mode, depth);
+    }
+  }
+  glPopAttrib();
+  return tmp-number;
+}
+//====================================================
+void GlGraph::drawPixmapFont(const string &str, const Coord &position, bool selected, float width) {
+  int rastPos[4];
+  float w_max = 300;
+  float w,h;
+  glRasterPos3f(position[0], position[1], position[2]);
+  glGetIntegerv(GL_CURRENT_RASTER_POSITION,rastPos);
+  if(occlusionTest.testRectangle(RectangleInt2D(rastPos[0] - labelsBorder - 5,
+						rastPos[1] - labelsBorder - 5,
+						rastPos[0] + labelsBorder + 5,
+						rastPos[1] + labelsBorder + 5)))
+    return;
+  if (selected)
+    glColor4ub(255,0,0,255);
+  else
+    glColor4ub(0,0,0,255);
+  fontRenderer->setMode(TLP_TLPPIXMAP);
+  fontRenderer->setString(str, VERBATIM);
+  //  w_max = width;
+  fontRenderer->getBoundingBox(w_max, h, w);
+  if(!occlusionTest.addRectangle(RectangleInt2D(rastPos[0]-(int)(w/2.0) - labelsBorder,
+						rastPos[1]-(int)(h/2.0) - labelsBorder,
+						rastPos[0]+(int)(w/2.0) + labelsBorder,
+						rastPos[1]+(int)(h/2.0) + labelsBorder))) {
+    fontRenderer->draw(w, w);
+  }
+}
+//====================================================
+void GlGraph::drawEdgeLabel(edge e, bool mode) {
   string tmp=elementLabel->getEdgeValue(e);
   if (tmp.length()==0) return;
   const Coord & srcCoord = elementLayout->getNodeValue(_superGraph->source(e));
@@ -217,39 +300,23 @@ void GlGraph::drawEdgeLabel(edge e) {
     else
       position = bends[bends.size()/2];
   }
-  int rastPos[4];
-  glRasterPos3f(position[0], position[1], position[2]);
-  glGetIntegerv(GL_CURRENT_RASTER_POSITION,rastPos);
-  if(occlusionTest.testRectangle(RectangleInt2D(rastPos[0] - labelsBorder - 5,
-						rastPos[1] - labelsBorder - 5,
-						rastPos[0] + labelsBorder + 5,
-						rastPos[1] + labelsBorder + 5)))
-    return;
-  myRender->setString(tmp, VERBATIM);
-  if (elementSelected->getEdgeValue(e))
-    glColor4ub(255,0,0,255);
-  else
-    glColor4ub(0,0,0,255);
-  DynamicFunctions* RenderContext = DynamicFunctions::create();
-  RenderContext->setMode(TLPPIXMAP);
-  float w,h;
-  //  w_max = nodeSize.getW();
-  myRender->getBoundingBox(50, h, w);
-  if(!occlusionTest.addRectangle(RectangleInt2D(rastPos[0]-(int)(w/2.) - labelsBorder,
-						rastPos[1]-(int)(h/2.)-labelsBorder,
-						rastPos[0]+(int)(w/2.)+labelsBorder,
-						rastPos[1]+(int)(h/2.)+labelsBorder))) {
-    myRender->draw(50, w);
-  }
-  //drawPixmapFont(tmp,position,elementSelected->getEdgeValue(e));
+  drawPixmapFont(tmp, position, elementSelected->getEdgeValue(e), 50);
 }
-  //====================================================
-void GlGraph::drawLabel(node n) {
-  const string &tmp=elementLabel->getNodeValue(n);
-  if (tmp.length()==0) return;
+//====================================================
+void GlGraph::drawNodeLabel(node n, bool mode, unsigned int depth) {
   const Coord &nodeCoord = elementLayout->getNodeValue(n);
   const Size &nodeSize = elementSize->getNodeValue(n);
-
+  if (_viewMetaLabel && elementMetaGraph->getNodeValue(n)!=0) {
+    glPushMatrix();
+    glTranslatef(nodeCoord[0], nodeCoord[1], nodeCoord[2]);
+    glScalef(nodeSize[0], nodeSize[1], nodeSize[2]);
+    drawMetaNode(n, depth, true, mode);
+    glPopMatrix();
+  }
+  const string &tmp=elementLabel->getNodeValue(n);
+  if (tmp.length()==0) {
+    return;
+  }
   Color fontColor;
   if (elementSelected->getNodeValue(n))
     fontColor.set(255,0,0,255);
@@ -261,21 +328,17 @@ void GlGraph::drawLabel(node n) {
   glColor4ub(fontColor.getR(),fontColor.getG(),fontColor.getB(),fontColor.getA());
   setMaterial(fontColor);
 
-  //  double wi,he;
-  int rastPos[4];
   float w_max = 300;
   float w,h;
-
-  DynamicFunctions* RenderContext = DynamicFunctions::create();
   float div_w, div_h;
   if (tmp.length()>0) {
     switch(_FontsType){
     case 0:
-      if (projectSize(nodeCoord,nodeSize) < 36.0) return;
-      myRender->setString(tmp, VERBATIM);
-      RenderContext->setMode(POLYGON);
-      w_max = nodeSize.getW();
-      myRender->getBoundingBox(w_max, h, w);
+      if (projectSize(nodeCoord,nodeSize) < 8.0) return;
+      fontRenderer->setMode(TLP_POLYGON);
+      fontRenderer->setString(tmp, VERBATIM);
+      //      w_max = nodeSize.getW()*50.0;
+      fontRenderer->getBoundingBox(w_max, h, w);
       glPushMatrix();
       glTranslatef(nodeCoord[0], nodeCoord[1], nodeCoord[2]);
       div_w = nodeSize.getW()/w;
@@ -284,34 +347,18 @@ void GlGraph::drawLabel(node n) {
 	glScalef(-div_w, -div_w, 1);
       else 
 	glScalef(-div_h, -div_h, 1);
-      myRender->draw(w_max,w);
+      fontRenderer->draw(w,w);
       glPopMatrix();
       break;
     case 1:
-      glRasterPos3f(nodeCoord[0], nodeCoord[1], nodeCoord[2]);
-      glGetIntegerv(GL_CURRENT_RASTER_POSITION,rastPos);
-      if(occlusionTest.testRectangle(RectangleInt2D(rastPos[0] - labelsBorder - 5,
-						    rastPos[1] - labelsBorder - 5,
-						    rastPos[0] + labelsBorder + 5,
-						    rastPos[1] + labelsBorder + 5)))
-	return;
-      myRender->setString(tmp, VERBATIM);
-      RenderContext->setMode(TLPPIXMAP);
-      w_max = nodeSize.getW();
-      myRender->getBoundingBox(w_max, h, w);
-      if(!occlusionTest.addRectangle(RectangleInt2D(rastPos[0]-(int)(w/2.) - labelsBorder,
-						    rastPos[1]-(int)(h/2.) - labelsBorder,
-						    rastPos[0]+(int)(w/2.) + labelsBorder,
-						    rastPos[1]+(int)(h/2.) + labelsBorder))) {
-	myRender->draw(w_max, w);
-      }
+      drawPixmapFont(tmp, nodeCoord, elementSelected->getNodeValue(n), nodeSize.getW());
       break;
     case 2:
-      if (projectSize(nodeCoord,nodeSize) < 36.0) return;
-      myRender->setString(tmp, VERBATIM);
-      RenderContext->setMode(TEXTURE);
-      w_max = nodeSize.getW();
-      myRender->getBoundingBox(w_max, h, w);
+      if (projectSize(nodeCoord,nodeSize) < 8.0) return;
+      fontRenderer->setMode(TLP_TEXTURE);
+      fontRenderer->setString(tmp, VERBATIM);
+      //      w_max = nodeSize.getW();
+      fontRenderer->getBoundingBox(w_max, h, w);
       glPushMatrix();
       glTranslatef(nodeCoord[0], nodeCoord[1], nodeCoord[2]);
       div_w = nodeSize.getW()/w;
@@ -321,10 +368,8 @@ void GlGraph::drawLabel(node n) {
       else 
 	glScalef(-div_h, -div_h, 1);
       glEnable( GL_TEXTURE_2D);
-      glEnable(GL_BLEND);
       glBlendFunc(GL_ONE_MINUS_DST_COLOR,GL_ONE_MINUS_SRC_COLOR);
-      myRender->draw(w_max, w);
-      glDisable(GL_BLEND);
+      fontRenderer->draw(w, w);
       glDisable( GL_TEXTURE_2D);
       glPopMatrix();
       break;
@@ -333,55 +378,7 @@ void GlGraph::drawLabel(node n) {
       break;
     }
   }
-}
-//====================================================
-unsigned int GlGraph::drawEdgeLabels(unsigned int number, Iterator<edge> *itE, bool mode) {
-  if (!itE->hasNext() || number==0) return 0;
-  unsigned int tmp=number;
-  glPushAttrib(GL_ALL_ATTRIB_BITS);
-  glMatrixMode(GL_MODELVIEW); 
-  glDisable(GL_LIGHTING);
-  glDepthFunc(GL_ALWAYS );
-  glDisable(GL_BLEND);
-  glDisable(GL_COLOR_MATERIAL);
-  initProxies();
-  while ((itE->hasNext()) && (number >0)) {
-    edge ite=itE->next();
-    if (elementSelected->getEdgeValue(ite)==mode){
-      number--;
-      drawEdgeLabel(ite);
-    }
-  }
-  glDepthFunc(GL_LEQUAL );
-  glPopAttrib();
-  return tmp-number;
-}
-//====================================================
-unsigned int GlGraph::drawLabels(unsigned int number, Iterator<node> *itN, bool mode) {
-  if (!itN->hasNext() || number==0) return 0;
-  unsigned int tmp=number;
 
-  glPushAttrib(GL_ALL_ATTRIB_BITS);
-  glMatrixMode(GL_MODELVIEW); 
-  glDisable(GL_LIGHTING);
-  glDepthFunc(GL_ALWAYS );
-  glDisable(GL_BLEND);
-  glDisable(GL_COLOR_MATERIAL);
-  initProxies();
-  if(mode)
-    myRender->setContext(tlp::TulipLibDir + "tlp/bitmaps/" + "fontb.ttf", 14, 0, 0, 255);
-  else	
-    myRender->setContext(tlp::TulipLibDir + "tlp/bitmaps/" + "font.ttf", 12, 255, 255, 255);
-  while ((itN->hasNext()) && (number >0)) {
-    node itv=itN->next();
-    if (elementSelected->getNodeValue(itv)==mode){
-      number--;
-      drawLabel(itv);
-    }
-  }
-  glDepthFunc(GL_LEQUAL );
-  glPopAttrib();
-  return tmp-number;
 }
 //=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*
 #define L3D_BIT (1<<9)
@@ -418,40 +415,40 @@ void GlGraph::drawEdge(const Coord &startNode, const Coord &finalNode,
   case 14:GlLines::glDrawSpline2Curve(startPoint,bends,endPoint,10,width,2,startColor,endColor);break;
   case 15:GlLines::glDrawSpline2Curve(startPoint,bends,endPoint,10,width,3,startColor,endColor);break;
     //3D lines
-  case L3D_BIT: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::PLAIN,
+  case L3D_BIT: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_PLAIN,
 					 GlLines::LINEAR, startColor, endColor); break;
-  case L3D_BIT+1: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::DOT,
+  case L3D_BIT+1: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_DOT,
                                            GlLines::LINEAR, startColor, endColor); break;
-  case L3D_BIT+2: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::DASHED,
+  case L3D_BIT+2: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_DASHED,
                                            GlLines::LINEAR, startColor, endColor); break;
-  case L3D_BIT+3: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::ALTERNATE,
+  case L3D_BIT+3: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_ALTERNATE,
                                            GlLines::LINEAR, startColor, endColor); break;
 
-  case L3D_BIT+4: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::PLAIN,
+  case L3D_BIT+4: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_PLAIN,
                                            GlLines::BEZIER, startColor, endColor); break;
-  case L3D_BIT+5: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::DOT,
+  case L3D_BIT+5: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_DOT,
                                            GlLines::BEZIER, startColor, endColor); break;
-  case L3D_BIT+6: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::DASHED,
+  case L3D_BIT+6: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_DASHED,
                                            GlLines::BEZIER, startColor, endColor); break;
-  case L3D_BIT+7: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::ALTERNATE,
+  case L3D_BIT+7: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_ALTERNATE,
                                            GlLines::BEZIER, startColor, endColor); break;
 
-  case L3D_BIT+8: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::PLAIN,
+  case L3D_BIT+8: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_PLAIN,
                                            GlLines::SPLINE3, startColor, endColor); break;
-  case L3D_BIT+9: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::DOT,
+  case L3D_BIT+9: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_DOT,
                                            GlLines::SPLINE3, startColor, endColor); break;
-  case L3D_BIT+10: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::DASHED,
+  case L3D_BIT+10: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_DASHED,
 					    GlLines::SPLINE3, startColor, endColor); break;
-  case L3D_BIT+11: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::ALTERNATE,
+  case L3D_BIT+11: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_ALTERNATE,
 					    GlLines::SPLINE3, startColor, endColor); break;
     
-  case L3D_BIT+12: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::PLAIN,
+  case L3D_BIT+12: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_PLAIN,
 					    GlLines::SPLINE4, startColor, endColor); break;
-  case L3D_BIT+13: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::DOT,
+  case L3D_BIT+13: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_DOT,
 					    GlLines::SPLINE4, startColor, endColor); break;
-  case L3D_BIT+14: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::DASHED,
+  case L3D_BIT+14: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_DASHED,
 					    GlLines::SPLINE4, startColor, endColor); break;
-  case L3D_BIT+15: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::ALTERNATE,
+  case L3D_BIT+15: GlLines::glDrawExtrusion(startNode, finalNode, startPoint, bends, endPoint, 10, size, GlLines::TLP_ALTERNATE,
 					    GlLines::SPLINE4, startColor, endColor); break;
 
   default:
@@ -469,12 +466,13 @@ void GlGraph::drawEdge(const Coord &startNode, const Coord &finalNode,
 void GlGraph::drawEdge(edge ite) {
   const Coord & srcCoord = elementLayout->getNodeValue(_superGraph->source(ite));
   Coord tgtCoord = elementLayout->getNodeValue(_superGraph->target(ite));
+  const LineType::RealType &lCoord = elementLayout->getEdgeValue(ite);
+  if (srcCoord == tgtCoord && lCoord.size()==0) return;
   Coord srcAnchor, tgtAnchor, endLineAnchor, tmpAnchor;
   const Size &srcSize = elementSize->getNodeValue(_superGraph->source(ite));
   const Size &tgtSize = elementSize->getNodeValue(_superGraph->target(ite));
   const Size &edgeSize = elementSize->getEdgeValue(ite);
   Color C1,C2;
-  const LineType::RealType &lCoord = elementLayout->getEdgeValue(ite);
   // set color
   if (isEdgeColorInterpolate()) {
     C1 = elementColor->getNodeValue(_superGraph->source(ite));
@@ -485,11 +483,19 @@ void GlGraph::drawEdge(edge ite) {
   }
   
   // set srcAnchor, tgtAnchor. tmpAnchor will be on the point just before tgtAnchor
-  Glyph *sourceGlyph=glyphs.get(elementShape->getNodeValue(_superGraph->source(ite)));
+  node source = _superGraph->source(ite);
+  int srcGlyphId = 1; //cube outlined
+  if (elementMetaGraph->getNodeValue(source)==0)
+    srcGlyphId = elementShape->getNodeValue(source);
+  Glyph *sourceGlyph=glyphs.get(srcGlyphId);
   tmpAnchor = (lCoord.size() > 0) ? lCoord.front() : tgtCoord;
   srcAnchor = sourceGlyph->getAnchor(srcCoord, tmpAnchor, srcSize);
 
-  Glyph *targetGlyph=glyphs.get(elementShape->getNodeValue(_superGraph->target(ite)));
+  node target;
+  int tgtGlyphId = 1; //cube outlined
+  if (elementMetaGraph->getNodeValue(target)==0)
+    tgtGlyphId = elementShape->getNodeValue(target);
+  Glyph *targetGlyph = glyphs.get(tgtGlyphId);
   //this time we don't take srcCoord but srcAnchor to be oriented to where the line comes from
   tmpAnchor = (lCoord.size() > 0) ? lCoord.back() : srcAnchor;
   tgtAnchor = targetGlyph->getAnchor(tgtCoord, tmpAnchor, tgtSize);
@@ -545,200 +551,3 @@ void GlGraph::drawEdge(edge ite) {
   
   drawEdge(srcCoord, tgtCoord, srcAnchor, lCoord, endLineAnchor, C1, C2, edgeSize, elementShape->getEdgeValue(ite));
 }
-//====================================================
-unsigned int GlGraph::drawEdges(unsigned int number,Iterator<edge> *itE) {
-  if (!itE->hasNext() || number==0) return 0;
-  unsigned int tmp=number;
-  glDisable(GL_LIGHTING);
-  glPushAttrib(GL_ALL_ATTRIB_BITS); 
-  initProxies();
-  while ((itE->hasNext()) && (number>0)) {
-    number--;
-    drawEdge(itE->next());
-  }
-  glPopAttrib();
-  return tmp-number;
-}
-//====================================================
-//Fan rendering methods for nodes David Auber, David Duke
-void GlGraph::drawFanNode(node n) {
-  if (elementSelected->getNodeValue(n)) {
-    drawNode(n,0);
-    Iterator<edge> *itE=_superGraph->getOutEdges(n);
-    for (;itE->hasNext();) {
-      edge ite=itE->next();
-      drawEdge(ite);
-    }delete itE;
-  } 
-  else {
-    glEnable(GL_BLEND);
-    glBlendFunc(GL_SRC_ALPHA,GL_ONE);
-    Coord centerCoord,lastValid,lastTested;
-    Color centerColor,lastTestedColor,lastValidColor;
-    int numberOfChildren;
-    if ((numberOfChildren=_superGraph->outdeg(n))==0)  {
-      if (_superGraph->indeg(n)==0)  drawNode(n,0);
-      return;
-    }
-    centerCoord=elementLayout->getNodeValue(n);
-    centerColor=elementColor->getNodeValue(n);
-    //Initiallize the FanError Object
-    int k;
-    if (numberOfChildren<5) k=2; else k=0;
-    FanError fanError(centerCoord,6.28/(0.7*numberOfChildren+k),3);
-
-    //We strore coordinates in order to compute normals
-    vector<Coord> neighboors(numberOfChildren);
-    vector<Color> neighboorsColors(numberOfChildren);
-    Iterator<node> *itChild=_superGraph->getOutNodes(n);
-    for (int i=0;itChild->hasNext();++i) {
-      node itchild=itChild->next();
-      neighboors[i]=elementLayout->getNodeValue(itchild);
-      neighboorsColors[i]=elementColor->getNodeValue(itchild);
-    }delete itChild;
-    glFrontFace(GL_CW);
-
-    //compute normal of the center average of the normal of all faces.
-    Coord centerNormal(0,0,0);
-    for (int j=0;j<numberOfChildren-1;++j) {
-      centerNormal+=(neighboors[j]-centerCoord)^(neighboors[j+1]-centerCoord);
-    }
-    centerNormal/=(numberOfChildren-1);
-
-    //Compute and draw the FRONT fans
-    unsigned int result;
-    unsigned int nbElements;
-    node itchild;
-    itChild=_superGraph->getOutNodes(n);
-    itchild=itChild->next();
-    lastTested=lastValid=elementLayout->getNodeValue(itchild);
-    lastTestedColor=lastValidColor=elementColor->getNodeValue(itchild);
-    result=2;
-    nbElements=0;
-    for (int i=0;itChild->hasNext();) {
-      fanError.reset();
-      fanError.addVertex(lastTested);
-      if (result==2) {
-	nbElements=0;
-	glBegin(GL_TRIANGLE_FAN);
-	//	SetMaterial(centerColor);
-	SetColor(centerColor);
-	glNormal3f(centerNormal.getX(),centerNormal.getY(),centerNormal.getZ());
-	glVertex3f(centerCoord.getX() , centerCoord.getY() , centerCoord.getZ());
-	//	SetMaterial(lastTestedColor);
-	SetColor(lastTestedColor);
-	if (i+1<numberOfChildren) {
-	  Coord resultCoord=(neighboors[i+1]-neighboors[i])^(centerCoord-neighboors[i]);
-	  glNormal3f(resultCoord.getX(),resultCoord.getY(),resultCoord.getZ());
-	}
-	glVertex3f(lastTested.getX() , lastTested.getY() , lastTested.getZ());	
-      }
-      lastValid=lastTested;
-      for (;itChild->hasNext();) {
-	node itchild=itChild->next();
-	i++;
-	lastTested=elementLayout->getNodeValue(itchild);
-	lastTestedColor=elementColor->getNodeValue(itchild);
-	if ((result=fanError.addVertex(lastTested))!=0) break;
-	lastValid=lastTested;
-	lastValidColor=lastTestedColor;
-	nbElements++;
-      }
-      //      SetMaterial(lastValidColor);
-      SetColor(lastValidColor);
-
-      if (i-1>0) {
-	Coord resultCoord=(centerCoord-neighboors[i])^(neighboors[i-1]-neighboors[i]);
-	glNormal3f(resultCoord.getX(),resultCoord.getY(),resultCoord.getZ());
-      }
-      glVertex3f(lastValid.getX() , lastValid.getY() , lastValid.getZ());
-      if (result==2) glEnd();
-      if ((nbElements==0) && (result==2)) {
-	glDisable(GL_BLEND);
-	glDisable(GL_LIGHTING);
-	GlLines::glDrawLine(centerCoord,lastValid,1.0f,0,centerColor,lastValidColor);
-	glEnable(GL_LIGHTING);
-	glEnable(GL_BLEND);
-      }
-    }
-    if (result!=2) glEnd();
-    else {
-      glDisable(GL_BLEND);
-      glDisable(GL_LIGHTING);
-      GlLines::glDrawLine(centerCoord,lastTested,1.0f,0,centerColor,lastTestedColor);
-      glEnable(GL_LIGHTING);
-      glEnable(GL_BLEND);
-    }
-    delete itChild;
-
-
-    //We make the BACK drawing now
-    glFrontFace(GL_CCW);
-    centerNormal*=-1;
-    itChild=_superGraph->getOutNodes(n);
-    itchild=itChild->next();
-    lastTested=lastValid=elementLayout->getNodeValue(itchild);
-    lastTestedColor=lastValidColor=elementColor->getNodeValue(itchild);
-    result=2;
-    nbElements=0;
-    for (int i=0;itChild->hasNext();) {
-      fanError.reset();
-      fanError.addVertex(lastTested);
-      if (result==2) {
-	nbElements=0;
-	glBegin(GL_TRIANGLE_FAN);
-	//SetMaterial(centerColor);
-	SetColor(centerColor);
-	glNormal3f(centerNormal.getX(),centerNormal.getY(),centerNormal.getZ());
-	glVertex3f(centerCoord.getX() , centerCoord.getY() , centerCoord.getZ());
-	//	SetMaterial(lastTestedColor);
-	SetColor(lastTestedColor);
-	if (i+1<numberOfChildren) {
-	  Coord resultCoord=(centerCoord-neighboors[i])^(neighboors[i+1]-neighboors[i]);
-	  glNormal3f(resultCoord.getX(),resultCoord.getY(),resultCoord.getZ());
-	}
-	glVertex3f(lastTested.getX() , lastTested.getY() , lastTested.getZ());	
-      }
-      lastValid=lastTested;
-      for (;itChild->hasNext();) {
-	node itchild=itChild->next();
-	i++;
-	lastTested=elementLayout->getNodeValue(itchild);
-	lastTestedColor=elementColor->getNodeValue(itchild);
-	if ((result=fanError.addVertex(lastTested))!=0) break;
-	lastValid=lastTested;
-	lastValidColor=lastTestedColor;
-	nbElements++;
-      }
-      //      SetMaterial(lastValidColor);
-      SetColor(lastValidColor);
-
-      if (i-1>0) {
-	Coord resultCoord=(neighboors[i-1]-neighboors[i])^(centerCoord-neighboors[i]);
-	glNormal3f(resultCoord.getX(),resultCoord.getY(),resultCoord.getZ());
-      }
-
-      glVertex3f(lastValid.getX() , lastValid.getY() , lastValid.getZ());
-      if (result==2) glEnd();
-    }
-    if (result!=2) glEnd();
-    delete itChild;
-  }
-
-  glFrontFace(GL_CCW);
-  glDisable(GL_BLEND);
-}
-//====================================================
-unsigned int GlGraph::drawFanNodes(unsigned int number, Iterator<node> *itN) {
-  unsigned int tmp=number;
-  glPushAttrib(GL_ALL_ATTRIB_BITS); 
-  initProxies();
-  while ((itN->hasNext()) && (number >0)) {
-    number--;
-    node itv=itN->next();
-    drawFanNode(itv);
-  }
-  glPopAttrib();
-  return tmp-number;
-}
-//====================================================
