@@ -7,7 +7,6 @@
 
 #include "tulip/GlGraph.h"
 
-
 //====================================================
 void GlGraph::initProjection(bool reset){
   glMatrixMode(GL_PROJECTION);
@@ -45,9 +44,6 @@ void GlGraph::initLights() {
   GLfloat attL[3] = {0,0,0};
   GLfloat attQ[3] = {0,0,0};
 
-  GLfloat spotExp[1]= {0};
-  GLfloat spotCut[1]= {180};
-
   glEnable( GL_LIGHTING );
   glEnable( GL_LIGHT0 );
 
@@ -63,9 +59,11 @@ void GlGraph::initLights() {
 void GlGraph::initGlParameter() {
   glGetIntegerv (GL_VIEWPORT, viewportArray);
   glEnable(GL_LINE_SMOOTH);
-  glBlendFunc(GL_SRC_ALPHA,GL_ONE);
+  glEnable(GL_POINT_SMOOTH);
+  glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
   glHint(GL_LINE_SMOOTH_HINT,GL_DONT_CARE);
   glLineWidth(1.0);
+  glPointSize(1.0);
   glShadeModel(GL_SMOOTH);
   glEnable(GL_CULL_FACE);
   glEnable(GL_DEPTH_TEST);
@@ -73,6 +71,7 @@ void GlGraph::initGlParameter() {
   glDepthFunc(GL_LEQUAL );
   glPolygonMode(GL_FRONT, GL_FILL);
   glColorMask(1, 1, 1, 1);
+  glEnable(GL_BLEND);
   glIndexMask(~0);
   glClearColor(backgroundColor.getRGL(), backgroundColor.getGGL(), backgroundColor.getBGL(), 1.0);
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
