@@ -13,12 +13,12 @@
 
 #include <tulip/TlpTools.h>
 #include "tulip/GlGraph.h"
-#include "tulip/GlFonts.h"
 #include "tulip/Glyph.h"
 
 using namespace std;
 
 const Color colorSelect2= Color(255, 102, 255, 255);
+const Color colorMeta= Color(79, 36, 80, 255);
 //====================================================
 void SetMat(const Color &C) {
   float color[4];
@@ -87,8 +87,8 @@ void GlGraph::makeArrowMatrix(GLfloat *matrix, const Coord A, const Coord B, GLf
 //========================================================
 //Common display list
 //========================================================
-void GlGraph::cubeWire() {
-  GLenum type = GL_LINE_LOOP;
+void GlGraph::cube(GLenum type) {
+  //  GLenum type = GL_LINE_LOOP;
   /* front face */
   glBegin(type);
   glNormal3f(0.0f, 0.0f, 1.0f);
@@ -179,7 +179,7 @@ void GlGraph::solidCone() {
 void GlGraph::transparentSphere() {
   glDepthMask(GL_FALSE);
   glEnable(GL_BLEND);
-  glBlendFunc(GL_DST_COLOR,GL_SRC_COLOR);
+  glBlendFunc(GL_SRC_ALPHA,GL_SRC_COLOR);
   SetMat(colorSelect2);
   GLUquadricObj *quadratic;
   quadratic = gluNewQuadric();
@@ -217,16 +217,39 @@ void GlGraph::buildDisplayLists() {
     solidCone();
   } glEndList();  
   glNewList(selectionDL=glGenLists(1), GL_COMPILE); {
-    transparentSphere();
+    //    transparentSphere();
+    glPushAttrib(GL_ALL_ATTRIB_BITS);
+    glDisable(GL_LIGHTING);
+    //    glDepthMask(GL_FALSE);
+    //    glEnable(GL_BLEND);
+    //    glDisable(GL_DEPTH_TEST);
+    glDepthFunc(GL_LEQUAL);
+    glLineWidth(3);
+    //    SetMat(colorSelect2);
+    glColor4ub(colorSelect2[0], colorSelect2[1],  colorSelect2[2], colorSelect2[3]); 
+    //    glBlendFunc(GL_ONE_MINUS_SRC_ALPHA, GL_SRC_COLOR);
+    //    cube(GL_QUADS);
+    //    glBlendFunc(GL_SRC_ALPHA, GL_SRC_COLOR);
+    cube(GL_LINE_LOOP);
+    //glDepthMask(GL_TRUE);
+    //glEnable(GL_LIGHTING);
+    glPopAttrib();
   } glEndList();
   glNewList(metaGraphDL=glGenLists(1), GL_COMPILE); {
-    cubeWire();
+    glPushAttrib(GL_ALL_ATTRIB_BITS);
+    glDisable(GL_LIGHTING);
+    glDepthFunc(GL_LEQUAL);
+    glLineStipple(2, 0xAAAA);
+    glEnable(GL_LINE_STIPPLE);
+    glLineWidth(1);
+    glColor4ub(colorMeta[0], colorMeta[1],  colorMeta[2], colorMeta[3]); 
+    cube(GL_LINE_LOOP);
+    glPopAttrib();
   } glEndList();
   GLenum error=glGetError();
   if ( error != GL_NO_ERROR)
     cerr << "Open GL Error : " << error << " in " << __PRETTY_FUNCTION__ << endl;
-  //  GlFonts::setTextureFont(tlp::TulipLibDir + "/tlp/bitmaps/" + "Fonts.bmp");
-  Iterator<string> *itS=glyphFactory.availablePlugins();
+  Iterator<string> *itS = glyphFactory.availablePlugins();
   unsigned int i=0;
   GlyphContext gc = GlyphContext(&_superGraph, this);
   glyphs.setAll(0);
