@@ -10,6 +10,7 @@
 #include <tulip/SelectionProxy.h>
 #include <tulip/StringProxy.h>
 #include <tulip/MetricProxy.h>
+#include <tulip/MetaGraphProxy.h>
 #include <tulip/IntProxy.h>
 #include <tulip/LayoutProxy.h>
 #include <tulip/SizesProxy.h>
@@ -44,26 +45,28 @@ void GlGraph::initDoSelect(GLint x, GLint y, GLint w,GLint h) {
   glRenderMode(GL_SELECT);
   glInitNames();
   glPushName(~0);
-  glViewport(0, 0, winW, winH);
-  glGetIntegerv(GL_VIEWPORT, vp);
+  //  glViewport(0, 0, winW, winH);
+  //  glGetIntegerv(GL_VIEWPORT, vp);
   glMatrixMode(GL_PROJECTION);
   glPushMatrix();
   glLoadIdentity();
-  gluPickMatrix(x, y, w, h, vp);
+  gluPickMatrix(x, y, w, h, viewportArray);
   initProjection(false);
-
   glMatrixMode(GL_MODELVIEW);
   glPushMatrix();
   glPolygonMode(GL_FRONT, GL_FILL);
   glDisable(GL_LIGHTING);
+  glDisable(GL_BLEND);
   initModelView();
 }
 //=====================================================
 void GlGraph::endSelect() {
   glMatrixMode(GL_MODELVIEW);
   glPopMatrix();
+  glGetDoublev (GL_PROJECTION_MATRIX, modelviewMatrix);
   glMatrixMode(GL_PROJECTION);
   glPopMatrix();
+  glGetDoublev (GL_PROJECTION_MATRIX, projectionMatrix);
   glRenderMode(GL_RENDER);
 }
 //=====================================================
@@ -197,24 +200,42 @@ bool GlGraph::doSelect(GLint x, GLint y, tlp::ElementType &type ,node &n, edge &
 //Placement des sommets du graphe  l'index i=startIndex..startIndex+n-1
 void GlGraph::makeNodeSelect(int startIndex) {
   glMatrixMode(GL_MODELVIEW);
-  int i=startIndex;
+  //  int i=startIndex;
+  glPushAttrib(GL_ALL_ATTRIB_BITS);
   Iterator<node> *itN=_superGraph->getNodes();
   while (itN->hasNext()) {
     node itv=itN->next();
+    const Size &nSize=elementSize->getNodeValue(itv);
+    if( nSize == Size(0,0,0) )	continue;
+    const Coord &tmpCoord = elementLayout->getNodeValue(itv);	  
+    //    float lod= projectSize(tmpCoord, nSize);
+    //    float lod = 100.0;
+    //    if (lod==0) continue;
     glLoadName(itv.id);
-    const Coord &tmpCoord=elementLayout->getNodeValue(itv);	  
+    /*    if (lod < 8.0) { //less than four pixel on screen
+	  glPointSize(4);
+	  glBegin(GL_POINTS);
+	  glVertex3f(tmpCoord[0], tmpCoord[1], tmpCoord[2]);
+	  glEnd();
+	  }
+	  else {*/
     glPushMatrix();
     glTranslatef( tmpCoord.getX() , tmpCoord.getY() , tmpCoord.getZ() );
-    const Size &nSize=elementSize->getNodeValue(itv);
     glScalef(nSize.getW(), nSize.getH(), nSize.getD());
-    glyphs.get(elementShape->getNodeValue(itv))->draw(itv);
+    if (elementMetaGraph->getNodeValue(itv) == 0)
+      glyphs.get(elementShape->getNodeValue(itv))->draw(itv);
+    else
+      glyphs.get(0)->draw(itv);
     glPopMatrix();
-    ++i;
+      // }
+    //    ++i;
   } delete itN;
+  glPopAttrib();
 }
 //=================================================================
 //Placement des artes du graphe  l'index i=startIndex..startIndex+n-number_of_edges
 void GlGraph::makeEdgeSelect(int startIndex) {
+  if (!_displayEdges) return;
   glMatrixMode(GL_MODELVIEW);
   int i=startIndex;
   static const Color tmpColor(255,255,255,100);
