@@ -25,15 +25,14 @@ void GlLines::glDrawLine(const Coord &startPoint, const Coord &endPoint, const d
   GlLines::glEnableLineStipple(stippleType);
   glLineWidth(width);
   glBegin(GL_LINES);
-  glColor4ub(startColor.getR(),startColor.getG(),startColor.getB(),startColor.getA());
+  glColor4ub(startColor.getR(),startColor.getG(),startColor.getB(), 255);//startColor.getA());
   glVertex3f(startPoint[0],startPoint[1],startPoint[2]);
-  glColor4ub(endColor.getR(),endColor.getG(),endColor.getB(),endColor.getA());
+  glColor4ub(endColor.getR(),endColor.getG(),endColor.getB(), 255); //endColor.getA());
   glVertex3f(endPoint[0],endPoint[1],endPoint[2]);
   glEnd();
   GlLines::glDisableLineStipple(stippleType);
 }
 
-
 void GlLines::glDrawCurve(const Coord &startPoint, const vector<Coord> &bends, const Coord &endPoint, const double width,
 			  const unsigned int stippleType, const Color &startColor, const Color &endColor,
 			  const bool arrow, const double arrowWidth, const double arrowHeight)
@@ -46,7 +45,9 @@ void GlLines::glDrawCurve(const Coord &startPoint, const vector<Coord> &bends, c
   glLineWidth(width);
   
   GLfloat *colorStart=startColor.getGL();
+  colorStart[3] = 1.0;
   GLfloat *colorEnd=endColor.getGL();
+  colorEnd[3] = 1.0;
   GLfloat colorDelta[4];
   for (int i=0;i<4;i++) colorDelta[i]=(colorEnd[i]-colorStart[i])/(bends.size()+2);
   
@@ -80,7 +81,9 @@ void GlLines::glDrawBezierCurve(const Coord &startPoint,const vector<Coord> &ben
   glLineWidth(width);
   GLfloat *bendsCoordinates=buildCurvePoints(startPoint,bends,endPoint);
   GLfloat *colorStart=startColor.getGL();
+  colorStart[3] = 1.0;
   GLfloat *colorEnd=endColor.getGL();
+  colorEnd[3] = 1.0;
   GLfloat colorDelta[4];
   for (int i=0;i<4;i++)
     colorDelta[i]=(colorEnd[i]-colorStart[i])/(steps);
@@ -115,7 +118,9 @@ void GlLines::glDrawSplineCurve(const Coord &startPoint,const vector<Coord> &ben
   glLineWidth(width);
 
   GLfloat *colorStart=startColor.getGL();
+  colorStart[3] = 1.0;
   GLfloat *colorEnd=endColor.getGL();
+  colorEnd[3] = 1.0;
   GLfloat colorDelta[4];
   for (int i=0;i<4;i++)
     colorDelta[i]=(colorEnd[i]-colorStart[i])/(steps*(bends.size()+1));
@@ -128,12 +133,12 @@ void GlLines::glDrawSplineCurve(const Coord &startPoint,const vector<Coord> &ben
     p0=startPoint;
     p3=bends[0];
     if (bends.size()>1) p4=bends[1]; else p4=endPoint;
-    Coord v03=p3-p0;
-    Coord v34=p4-p3;
-    v03=v03/v03.norm();
-    v34=v34/v34.norm();
-    p1=v03+p0;
-    double scalaireTmp=v03*v34/(v03.norm()*v34.norm());
+    Coord v03 = p3-p0;
+    Coord v34 = p4-p3;
+    v03=  v03/v03.norm();
+    v34 = v34/v34.norm();
+    p1 = v03+p0;
+    double scalaireTmp=v03.dotProduct(v34) / (v03.norm()*v34.norm());
     if ((scalaireTmp<0.99999) && (scalaireTmp>-0.9999999)) {
       Coord vP2=(((v03^v34)^(v34-v03)));
       vP2=vP2/vP2.norm();
@@ -169,7 +174,7 @@ void GlLines::glDrawSplineCurve(const Coord &startPoint,const vector<Coord> &ben
     if ((i+1)<bends.size()) p4=bends[i+1]; else p4=endPoint;
     Coord v03=p3-p0;
     Coord v34=p4-p3;
-    double scalaireTmp=v03*v34/(v03.norm()*v34.norm());
+    double scalaireTmp=v03.dotProduct(v34)/(v03.norm()*v34.norm());
     if ((scalaireTmp<0.99999) && (scalaireTmp>-0.9999999)) {
       v03=v03/v03.norm();
       v34=v34/v34.norm();
@@ -246,7 +251,7 @@ void GlLines::glDrawSpline2Curve(const Coord &startPoint,const vector<Coord> &be
     if (bends.size()>1) p4=bends[1]; else p4=endPoint;
     Coord v03=p3-p0;
     Coord v34=p4-p3;   
-    double scalaireTmp=v03*v34/(v03.norm()*v34.norm());
+    double scalaireTmp=v03.dotProduct(v34)/(v03.norm()*v34.norm());
     if ((scalaireTmp<0.99999) && (scalaireTmp>-0.9999999)) {
       v03=v03/v03.norm();
       v34=v34/v34.norm();
@@ -273,7 +278,7 @@ void GlLines::glDrawSpline2Curve(const Coord &startPoint,const vector<Coord> &be
     if ((i+1)<bends.size()) p4=bends[i+1]; else p4=endPoint;
     Coord v03=p3-p0;
     Coord v34=p4-p3;
-    double scalaireTmp=v03*v34/(v03.norm()*v34.norm());
+    double scalaireTmp=v03.dotProduct(v34)/(v03.norm()*v34.norm());
     if ((scalaireTmp<0.99999) && (scalaireTmp>-0.9999999)) {
       v03=v03/v03.norm();
       v34=v34/v34.norm();
@@ -535,11 +540,11 @@ static Coord gleComputeAngle(Coord point, const Coord &finalPoint, const Coord &
   //point is point b, finalPoint is point a, target is b
   Coord ab = point - finalPoint;
   Coord ac = target - finalPoint;
-  float scal = ab*ac;
+  float scal = ab.dotProduct(ac);
   if (scal < 0) {  //this means ABC > 90deg, so we reverse ab and change point to its new location
     ab *= -1;
     point = ab + finalPoint;
-    scal = ab*ac;
+    scal = ab.dotProduct(ac);
   }
   //b' is b projected on ac
   Coord tmp = ac / ac.norm();  // tmp is vector ab' = (ab.ac)/ norm(ac) * ac->
