@@ -1,11 +1,7 @@
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <cmath>
 #include <tulip/Size.h>
 #include <tulip/Coord.h>
-#include "tulip/Glyph.h"
+#include <tulip/Glyph.h>
 
 Glyph::Glyph(GlyphContext *gc)
 {
@@ -16,7 +12,8 @@ Glyph::Glyph(GlyphContext *gc)
     LOD=gc->LOD;
   }
   else {
-    (void *)superGraph = (void *)glGraph = (void *)NULL;
+    superGraph = NULL;
+    glGraph = NULL;
     LOD=LOF=0;
   }
 }
