@@ -1,6 +1,12 @@
 #ifndef CLUSTERTREE_H
 #define CLUSTERTREE_H
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <qpoint.h>
+#include <tulip/tulipconf.h>
 #include "ClusterTreeData.h"
 
 class SuperGraph;
@@ -8,7 +14,7 @@ class QListViewItem;
 class QListView;
 class QPopupMenu;
 
-class ClusterTree : public ClusterTreeData
+class TLP_QT_SIMPLE_SCOPE ClusterTree : public ClusterTreeData
 { 
   Q_OBJECT;
   
@@ -47,6 +53,7 @@ public:
 protected:
   void buildTreeView(QListView *item,SuperGraph *p);
   void buildTreeView(QListViewItem *item,SuperGraph *p);
+  void removeSubgraph(SuperGraph *graph, bool recursive);
 
 private:
   bool removeOperation;
