@@ -11,6 +11,11 @@
  (at your option) any later version.
 */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+
 #include <qgl.h>
 #include <qpoint.h>
 
@@ -23,7 +28,7 @@
 //class QTextView;
 class QTimer;
 
-class GlGraphWidget : public QGLWidget, GlGraphStrategy
+class TLP_QT_SIMPLE_SCOPE GlGraphWidget : public QGLWidget, GlGraphStrategy
 {
   Q_OBJECT;
   
