@@ -2,11 +2,17 @@
 #ifndef MOUSEOBJECT_H
 #define MOUSEOBJECT_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <tulip/tulipconf.h>
+
 #include <qcursor.h>
 
 #include "MouseInterface.h"
 ///
-class MouseRotXRotY:public MouseInterface
+class TLP_QT_SCOPE MouseRotXRotY:public MouseInterface
 {
  public:
   MouseRotXRotY(){}
@@ -21,7 +27,7 @@ class MouseRotXRotY:public MouseInterface
   void wheelEvent(GlGraphWidget *, QWheelEvent *){}
 };
 ///
-class MouseZoomRotZ:public MouseInterface
+class TLP_QT_SCOPE MouseZoomRotZ:public MouseInterface
 {
  public:
   MouseZoomRotZ(){}
@@ -36,7 +42,7 @@ class MouseZoomRotZ:public MouseInterface
   void wheelEvent(GlGraphWidget *, QWheelEvent *){}
 };
 ///
-class MouseMove:public MouseInterface
+class TLP_QT_SCOPE MouseMove:public MouseInterface
 {
  public:
   int x,y;
@@ -51,7 +57,7 @@ class MouseMove:public MouseInterface
   void wheelEvent(GlGraphWidget *, QWheelEvent *){}
 };
 ///
-class MouseSelect:public MouseInterface
+class TLP_QT_SCOPE MouseSelect:public MouseInterface
 {
  public:
   MouseSelect(){}
@@ -65,7 +71,7 @@ class MouseSelect:public MouseInterface
   void wheelEvent(GlGraphWidget *, QWheelEvent *){}
 };
 ///
-class MouseDel:public MouseInterface
+class TLP_QT_SCOPE MouseDel:public MouseInterface
 {
 public:
   MouseDel(){}
@@ -80,7 +86,7 @@ public:
 };
 
 ///
-class MouseDelSelection:public MouseInterface
+class TLP_QT_SCOPE MouseDelSelection:public MouseInterface
 {
 public:
   MouseDelSelection(){}
@@ -94,7 +100,7 @@ public:
   void wheelEvent(GlGraphWidget *, QWheelEvent *){}
 };
 
-class MouseGraphNavigate: public MouseInterface
+class TLP_QT_SCOPE MouseGraphNavigate: public MouseInterface
 {
 private:
   MouseInterface *currentMouse;
@@ -114,7 +120,7 @@ public:
   void wheelEvent(GlGraphWidget *, QWheelEvent *);
 };
 
-class Mouse2D: public MouseInterface
+class TLP_QT_SCOPE Mouse2D: public MouseInterface
 {
 private:
   MouseInterface *currentMouse;
