@@ -2,13 +2,18 @@
 #ifndef MOUSEZOOMBOX_H
 #define MOUSEZOOMBOX_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+
 #include <tulip/MouseInterface.h>
 
 class SuperGraph;
 class QMouseEvent;
 class QKeyEvent;
 
-class MouseZoomBox : public MouseInterface
+class TLP_QT_SCOPE MouseZoomBox : public MouseInterface
 {
 private:
   unsigned int x, y;
