@@ -1,6 +1,10 @@
 #ifndef PROPERTYWIDGETS_H
 #define PROPERTYWIDGETS_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #if (__GNUC__ < 3)
 #include <hash_map>
 #else
@@ -24,9 +28,8 @@ class QPaintEvent;
 class QPushButton;
 class PProxy;
 
-
 /* this table handle displaying and editing node or edge properties */
-class TulipPropertyTable : public TulipTableWidget {
+class TLP_QT_SIMPLE_SCOPE TulipPropertyTable : public TulipTableWidget {
   Q_OBJECT;
 
 private:
