@@ -1,6 +1,10 @@
 #ifndef TULIPELEMENTPROPERTIES_H
 #define TULIPELEMENTPROPERTIES_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <qstringlist.h>
 #include <qsize.h>
 
@@ -8,7 +12,7 @@
 #include <tulip/ObservableGraph.h>
 #include "TulipElementPropertiesData.h"
 
-class TulipElementProperties : public TulipElementPropertiesData, public GraphObserver
+class TLP_QT_SIMPLE_SCOPE TulipElementProperties : public TulipElementPropertiesData, public GraphObserver
 {
   Q_OBJECT;
   // moc as of qt 3.0.5 doesn't understand '::'... silly
@@ -52,7 +56,7 @@ public slots:
   void setDisplayMode(const tlp::ElementType);
   void setCurrentNode(SuperGraph *, const node &);
   void setCurrentEdge(SuperGraph *, const edge &);
-  void setSuperGraph(SuperGraph *);
+  void setSuperGraph(SuperGraph *, bool distroy = true);
   void setCurrentListedProperties(const QStringList &);
   void setNodeListedProperties(const QStringList &);
   void setEdgeListedProperties(const QStringList &);
