@@ -91,7 +91,14 @@ static QListViewItem *findItemBySuperGraph(QListViewItem *item, const int id) {
 //=======================================================
 void ClusterTree::setSuperGraph(SuperGraph *graph) {
   //  cerr << __PRETTY_FUNCTION__ << endl;
-  if (graph==0) return;
+  if (graph==0) {
+    _currentSuperGraph = 0;
+    _rootSuperGraph = 0;
+    treeView->clear();
+    QListViewItem *item = new QListViewItem( treeView, 0 );
+    item->setText( 0, trUtf8( "New Item" ) );
+    return;
+  }
   if (_currentSuperGraph==0 || findItemBySuperGraph(treeView->firstChild(), graph->getId())==0) {
     _currentSuperGraph=graph;
     update();
@@ -109,6 +116,7 @@ void ClusterTree::currentSuperGraphChanged(const SuperGraph *graph) {
   if (item != NULL) {
     disconnect(treeView, SIGNAL(currentChanged(QListViewItem*)), this, SLOT(changeSuperGraph(QListViewItem*)));
     treeView->setCurrentItem(item);
+    item->setOpen(true);
     connect(treeView, SIGNAL(currentChanged(QListViewItem*)), this, SLOT(changeSuperGraph(QListViewItem*)));    
     _currentSuperGraph=((ClusterListViewItem *)item)->getSuperGraph();
   }
@@ -123,6 +131,7 @@ void ClusterTree::update()
     buildTreeView(treeView, _rootSuperGraph);
     currentSuperGraphChanged(_currentSuperGraph);
   }
+  show();
 }
 //=======================================================
 //Building of the cluster tree view
@@ -130,37 +139,41 @@ void ClusterTree::buildTreeView(QListView *item, SuperGraph *p) {
   //  cerr << __PRETTY_FUNCTION__ << endl;
   QListViewItem *tmpItem = new ClusterListViewItem(p, item);
   tmpItem->setText(0, QString(p->getAttribute<string>("name").c_str()));
-  tmpItem->setExpandable(true);
-  item->setOpen(tmpItem,true);
   Iterator<SuperGraph *> *itS=p->getSubGraphs();
   while (itS->hasNext())
     buildTreeView(tmpItem,itS->next());
   delete itS;
+  tmpItem->setExpandable(true);
+  item->setOpen(tmpItem,true);
 }
 //=======================================================
 void ClusterTree::buildTreeView(QListViewItem *item, SuperGraph *p) {
   QListViewItem *tmpItem=new ClusterListViewItem(p,item);
   tmpItem->setText(0, QString(p->getAttribute<string>("name").c_str()));
-  tmpItem->setExpandable(true);
-  treeView->setOpen(tmpItem,true);
+  //  tmpItem->setExpandable(true);
+  // treeView->setOpen(tmpItem,true);
   Iterator<SuperGraph *> *itS=p->getSubGraphs();
   while (itS->hasNext())
     buildTreeView(tmpItem,itS->next());
   delete itS;
 }
+
 //=======================================================
 //Cluster Tree Structure modification
-void ClusterTree::contextRemoveCluster() {
-  //  cerr << __PRETTY_FUNCTION__ << endl;
-  if (_currentSuperGraph == _rootSuperGraph) {
+void ClusterTree::removeSubgraph(SuperGraph *graph, bool recursive) {
+  //cerr << __PRETTY_FUNCTION__ << endl;
+  if (graph == graph->getRoot()) {
     QMessageBox::critical( 0, "Tulip Hierarchy Editor Remove Failed", QString("You cannot remove the root graph"));
     return;
   } 
   Observable::holdObservers();
   removeOperation = true;
-  emit aboutToRemoveView(_currentSuperGraph);
-  SuperGraph *father=_currentSuperGraph->getFather();
-  father->delSubGraph(_currentSuperGraph);
+  emit aboutToRemoveView(graph);
+  SuperGraph *father=graph->getFather();
+  if (!recursive)
+    father->delSubGraph(graph);
+  else
+    father->delAllSubGraphs(graph);
   _currentSuperGraph=father;
   update();
   currentSuperGraphChanged(father);
@@ -168,20 +181,15 @@ void ClusterTree::contextRemoveCluster() {
   Observable::unholdObservers();
   emit supergraphChanged(father);
 }
+
+//=======================================================
+//Cluster Tree Structure modification
+void ClusterTree::contextRemoveCluster() {
+  removeSubgraph(_currentSuperGraph, false);
+}
 //=======================================================
 void ClusterTree::contextRemoveAllCluster() {
-  if (_currentSuperGraph == _rootSuperGraph) {
-    QMessageBox::critical( 0, "Tulip Cluster Tree Editor Remove Failed",QString("You cannot remove the root cluster"));
-    return;
-  }
-  Observable::holdObservers();
-  removeOperation = true;
-  emit aboutToRemoveAllView(_currentSuperGraph);
-  _currentSuperGraph->getFather()->delAllSubGraphs(_currentSuperGraph);
-  _currentSuperGraph=_rootSuperGraph;
-  update();
-  removeOperation = false;
-  Observable::unholdObservers();
+  removeSubgraph(_currentSuperGraph, true);
 }
 //=======================================================
 void ClusterTree::contextCloneCluster() {  
