@@ -1,7 +1,3 @@
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <qpopupmenu.h>
 #include <qtimer.h>
 #include <qtextview.h>
@@ -188,8 +184,8 @@ void GlGraphWidget::paintGL() {
   TRACE_EXEC();
   makeCurrent();
   glGraph->draw();
-  if (!glGraph->isIncrementalRendering()) 
-    swapBuffers();
+  if (!glGraph->isIncrementalRendering())
+     swapBuffers();
   else
     drawGraph();
 }
