@@ -1,7 +1,3 @@
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <iostream>
 
 #include <qevent.h>
@@ -130,9 +126,8 @@ void MouseZoomBox::mPaint(GlGraphWidget *glw){
     started = false;
     glw->setMouseTracking(false);
   }
-  
   if (!started) return;
-  
+  glPushAttrib(GL_ALL_ATTRIB_BITS);
   glMatrixMode (GL_PROJECTION);
   glPushMatrix();
   glLoadIdentity();
@@ -165,15 +160,17 @@ void MouseZoomBox::mPaint(GlGraphWidget *glw){
   glVertex2f(x+w, y-h);
   glVertex2f(x, y-h);
   glEnd();
+  /*
   glLineWidth(1);
-  glDisable(GL_LINE_STIPPLE);
-  
+  glDisable(GL_LINE_STIPPLE);  
   glEnable(GL_DEPTH_TEST);
   glEnable(GL_CULL_FACE);
   glEnable(GL_LIGHTING);
+  */
   glPopMatrix();
   glMatrixMode (GL_PROJECTION);
   glPopMatrix();
   glMatrixMode (GL_MODELVIEW);
+  glPopAttrib();
 }
 
