@@ -13,9 +13,12 @@ TulipElementProperties::TulipElementProperties(SuperGraph *supergraph,
                                                const QStringList &nodeListedProperties,
                                                const QStringList &edgeListedProperties,
                                                QWidget *parent, const char *name, WFlags fl) :
-  TulipElementPropertiesData(parent, name, fl), displayMode(NODE), nodeSet(false), edgeSet(false)
+  TulipElementPropertiesData(parent, name, fl), 
+  displayMode(NODE), 
+  nodeSet(false), 
+  edgeSet(false),
+  supergraph(0)
 {
-  supergraph=0;
   setSuperGraph(supergraph);
   setNodeListedProperties(nodeListedProperties);
   setEdgeListedProperties(edgeListedProperties);
@@ -27,9 +30,12 @@ TulipElementProperties::TulipElementProperties(SuperGraph *supergraph,
 }
 //==========================================
 TulipElementProperties::TulipElementProperties(QWidget *parent, const char *name, WFlags fl) :
-  TulipElementPropertiesData(parent, name, fl), displayMode(NODE), nodeSet(false), edgeSet(false)
+  TulipElementPropertiesData(parent, name, fl), 
+  displayMode(NODE), 
+  nodeSet(false), 
+  edgeSet(false),
+  supergraph(0)
 {
-  supergraph=0;
   setSuperGraph(0);
   propertyTable->horizontalHeader()->setLabel(0, tr("Property"));
   propertyTable->horizontalHeader()->setLabel(1, tr("Value"));
@@ -114,8 +120,8 @@ void TulipElementProperties::setCurrentEdge(SuperGraph *graph,const edge &e) {
   updateTable();
 }
 //==========================================
-void TulipElementProperties::setSuperGraph(SuperGraph *s) {
-  if (supergraph!=0)
+void TulipElementProperties::setSuperGraph(SuperGraph *s, bool destroy) {
+  if (supergraph!=0 && !destroy)
     supergraph->removeObserver(this);
   supergraph = s;
   nodeSet = false;
@@ -235,7 +241,7 @@ void TulipElementProperties::updateTable() {
 using namespace std;
 //==========================================
 void TulipElementProperties::propertyTableValueChanged(int row, int col) {
-  cerr << __PRETTY_FUNCTION__ << endl;
+  //  cerr << __PRETTY_FUNCTION__ << endl;
   bool *elementSet;
   QStringList *listedProperties;
   switch(displayMode) {
@@ -248,7 +254,7 @@ void TulipElementProperties::propertyTableValueChanged(int row, int col) {
   PProxy *editedProperty = supergraph->getProperty(property.latin1());
   if (editedProperty==0) return;
   std::string tmp = value.latin1();
-  cerr << "Value :" << value << endl;
+  //  cerr << "Value :" << value << endl;
   bool result=true;
   switch(displayMode) {
   case NODE:
@@ -276,35 +282,31 @@ void TulipElementProperties::propertyTableValueChanged(int row, int col) {
       break;
     }
   }
-
-
   //}
 }
 //==========================================
-void TulipElementProperties::nodePropertyChanged(SuperGraph *s, node const &n, QString const &property, QString const &value)
-{
+void TulipElementProperties::nodePropertyChanged(SuperGraph *s, node const &n, QString const &property, QString const &value) {
   if ((displayMode == NODE) && (supergraph == s) && (currentNode == n))
     updateTable();
 }
 //==========================================
-void TulipElementProperties::edgePropertyChanged(SuperGraph *s, edge const &e, QString const &property, QString const &value)
-{
+void TulipElementProperties::edgePropertyChanged(SuperGraph *s, edge const &e, QString const &property, QString const &value) {
   if ((displayMode == EDGE) && (supergraph == s) && (currentEdge == e))
     updateTable();
 }
 //==========================================
 void TulipElementProperties::delNode(SuperGraph *graph, node n) {
-  if (graph!=supergraph)
+  if (graph!=supergraph && supergraph!=0 )
     supergraph->removeObserver(this);
   if (displayMode==NODE && currentNode==n)
     setSuperGraph(graph);
 }
 void TulipElementProperties::delEdge(SuperGraph *graph, edge e) {
-  if (graph!=supergraph)
+  if (graph!=supergraph && supergraph!=0)
     supergraph->removeObserver(this);
   if (displayMode==EDGE && currentEdge==e)
     setSuperGraph(graph);
 }
 void TulipElementProperties::destroy(SuperGraph *) {
-  setSuperGraph(0);
+  setSuperGraph(0, true);
 }
