@@ -74,7 +74,11 @@ void ColorTableItem::setContentFromEditor(QWidget *w) {
   color = ((ColorButton *)w)->getColor();
   stringstream ss;
   ss << "(" << color.red() << "," << color.green() << "," << color.blue() << ",255)";
+  #if defined _WIN32 || (__CYGWIN__)
+    setText(ss.str().c_str());
+  #else
   setText(ss.str());
+  #endif
 }
 void ColorTableItem::paint(QPainter *p, const QColorGroup &cg, const QRect &cr, bool selected) {
   p->fillRect(table()->cellRect(row(), col()), color);
