@@ -12,6 +12,10 @@
 #ifndef TULIP_BICONNEX_H
 #define TULIP_BICONNEX_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #if (__GNUC__ < 3)
 #include <hash_set>
 #else
@@ -23,7 +27,7 @@ class SuperGraph;
 
 /** \addtogroup graph_test */ 
 /*@{*/
-class BiconnexTest : public GraphObserver {
+class TLP_SCOPE BiconnexTest : public GraphObserver {
 public:
   static bool isBiconnex(SuperGraph *graph);
 
