@@ -5,7 +5,7 @@
 #include <list>
 #include <string>
 #include "SuperGraph.h"
-#include "MethodFactory.h"
+
 #include "WithParameter.h"
 
 /**
@@ -16,23 +16,15 @@
 class Clustering : public WithParameter
 { 
 public :
-  ///
   Clustering (ClusterContext context):superGraph(context.superGraph),pluginProgress(context.pluginProgress),dataSet(context.dataSet){}
-  ///
   virtual ~Clustering() {}
-  ///
   virtual bool run() = 0;
-  ///
-  virtual bool check(std::string &) = 0;
-  ///
-  virtual void reset() = 0;  
+  virtual bool check(std::string &) {return true;}
+  virtual void reset() {}  
 
 protected:
-  ///
   SuperGraph *superGraph;
-  ///
   PluginProgress *pluginProgress;
-  ///
   DataSet *dataSet;
 };
 /*@}*/
