@@ -12,6 +12,10 @@
 #ifndef TULIP_COLORS_H
 #define TULIP_COLORS_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "Types.h"
 #include "Property.h"
 class PropertyContext;
@@ -20,7 +24,7 @@ class ColorsProxy;
 /** \addtogroup plugins */ 
 /*@{*/
 /// Interface for colors plug-ins
-class Colors:public Property< ColorType , ColorType >
+class TLP_SCOPE Colors:public Property< ColorType , ColorType >
 { 
   ///
   friend class ColorsProxy;
