@@ -13,7 +13,7 @@
 #include "Iterator.h"
 #include "SuperGraph.h"
 #include "SuperGraphImpl.h"
-
+#include <set>
 #if (__GNUC__ < 3)
 #include <hash_map>
 #else
@@ -48,9 +48,9 @@ private:
 template<class itType> class FactorIterator:public Iterator<itType> {
  protected:
   SuperGraph *_parentGraph;
-  SelectionProxy *_selectionProxy;
+  const MutableContainer<bool>& _selectionProxy;
  public:
-  FactorIterator(const SuperGraph *sG,SelectionProxy *filter):
+  FactorIterator(const SuperGraph *sG,const MutableContainer<bool>& filter):
     _parentGraph(sG->getFather()),
     _selectionProxy(filter)
   {}
@@ -64,7 +64,7 @@ class SGraphNodeIterator:public FactorIterator<node> {
   bool _hasnext;
 
  public:
-  SGraphNodeIterator(const SuperGraph *sG,SelectionProxy *filter);
+  SGraphNodeIterator(const SuperGraph *sG, const MutableContainer<bool>& filter);
   ~SGraphNodeIterator();
   node next();
   bool hasNext();
@@ -75,7 +75,7 @@ class OutNodesIterator:public FactorIterator<node> {
  private:
   Iterator<edge> *it;
  public:
-  OutNodesIterator(const SuperGraph *sG,SelectionProxy *filter,node n);
+  OutNodesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter, node n);
   ~OutNodesIterator();
   node next();
   bool hasNext();
@@ -86,7 +86,7 @@ class InNodesIterator:public FactorIterator<node> {
  private:
   Iterator<edge> *it;
  public:
-  InNodesIterator(const SuperGraph *sG,SelectionProxy *filter,node n);
+  InNodesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter ,node n);
   ~InNodesIterator();
   node next();
   bool hasNext();
@@ -99,7 +99,7 @@ class InOutNodesIterator:public FactorIterator<node> {
   node n;
 
  public:
-  InOutNodesIterator(const SuperGraph *sG,SelectionProxy *filter,node n);
+  InOutNodesIterator(const SuperGraph *sG,const MutableContainer<bool>& filter,node n);
   ~InOutNodesIterator();
   node next();
   bool hasNext();
@@ -114,7 +114,7 @@ class SGraphEdgeIterator:public FactorIterator<edge>
   bool _hasnext;
 
  public:
-  SGraphEdgeIterator(const SuperGraph *sG,SelectionProxy *filter);
+  SGraphEdgeIterator(const SuperGraph *sG, const MutableContainer<bool>& filter);
   ~SGraphEdgeIterator();
   edge next();
   bool hasNext();
@@ -128,7 +128,7 @@ class OutEdgesIterator:public FactorIterator<edge> {
   bool _hasnext;
 
  public:
-  OutEdgesIterator(const SuperGraph *sG,SelectionProxy *filter,node n);
+  OutEdgesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter, node n);
   ~OutEdgesIterator();
   edge next();
   bool hasNext();
@@ -142,7 +142,7 @@ class InEdgesIterator:public FactorIterator<edge> {
   bool _hasnext;
 
  public:
-  InEdgesIterator(const SuperGraph *sG,SelectionProxy *filter,node n);
+  InEdgesIterator(const SuperGraph *sG,const MutableContainer<bool>& filter,node n);
   ~InEdgesIterator();
   edge next();
   bool hasNext();
@@ -156,7 +156,7 @@ class InOutEdgesIterator:public FactorIterator<edge> {
   bool _hasnext;
 
  public:
-  InOutEdgesIterator(const SuperGraph *sG,SelectionProxy *filter,node n);
+  InOutEdgesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter, node n);
   ~InOutEdgesIterator();
   edge next();
   bool hasNext();
@@ -232,6 +232,7 @@ class xOutEdgesIterator:public Iterator<edge> {
   node n;
   edge curEdge;
   SuperGraphImpl *spG;
+  std::set<edge> loop;
  public:
   xOutEdgesIterator(const SuperGraph *sG,const node n);
   ~xOutEdgesIterator();
@@ -245,6 +246,7 @@ class xInEdgesIterator:public Iterator<edge> {
   node n;
   edge curEdge;
   SuperGraphImpl *spG;
+  std::set<edge> loop;
  public:
   xInEdgesIterator(const SuperGraph *sG,const node n);
   ~xInEdgesIterator();
