@@ -1,6 +1,11 @@
 //-*-c++-*-
 #ifndef _TLPGRAPHTOOLS_H
 #define _TLPGRAPHTOOLS_H
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <tulip/Node.h>
 #include <tulip/Edge.h>
 #include <set>
@@ -19,11 +24,11 @@ namespace tlp {
   };
 
 
-  void makeAcyclic(SuperGraph* graph,std::set<edge> &reversed,std::list<tlp::SelfLoops> &selfLoops);
+  TLP_SCOPE void makeAcyclic(SuperGraph* graph,std::set<edge> &reversed,std::list<tlp::SelfLoops> &selfLoops);
 
-  node makeSimpleSource(SuperGraph* superGraph);
+  TLP_SCOPE node makeSimpleSource(SuperGraph* superGraph);
 
-  void makeProperDag(SuperGraph* superGraph,std::list<node> &addedNodes, 
+  TLP_SCOPE void makeProperDag(SuperGraph* superGraph,std::list<node> &addedNodes, 
 		     stdext::hash_map<edge,edge> &replacedEdges,IntProxy *edgeLength);
 
 };
