@@ -18,6 +18,22 @@
 class IdManagerIterator;
 
 class IdManager {
+public:
+  IdManager();
+  bool is_free(unsigned int);
+  /**
+     Free the id given in parameter. This id
+     will be accessible by a the get function.
+  */
+  void free(const unsigned int);
+  /**
+     Return a new id, the returned id is choosen to minimize
+     the memory space of the free list, and the fragmetation
+     of the ids.
+  */
+  unsigned int get();
+  Iterator<unsigned int>* getUsedId() const;
+  
   friend std::ostream& operator<<(std::ostream &,const IdManager &);
   friend class IdManagerIterator;
 
@@ -25,25 +41,8 @@ private:
   std::set<unsigned int> freeIds;  
   unsigned int maxId;
   unsigned int minId;
-
-public:
-  IdManager():maxId(0),minId(1){}
-  bool is_free(unsigned int);
-  /**
-     Free the id given in parameter. This id
-     will be accessible by a the get function.
-  */
-  void IdManager::free(const unsigned int);
-  /**
-     Return a new id, the returned id is choosen to minimize
-     the memory space of the free list, and the fragmetation
-     of the ids.
-  */
-  unsigned int get();
-  
-  Iterator<unsigned int>* getUsedId() const;
 };
-
+//======================================================
 class IdManagerIterator:public Iterator<unsigned int>  {
 public:
   IdManagerIterator(const IdManager &idMan);
