@@ -13,6 +13,10 @@
 #ifndef TULIP_INT_H
 #define TULIP_INT_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "Types.h"
 #include "Property.h"
 class PropertyContext;
@@ -22,7 +26,7 @@ class IntProxy;
 /*@{*/
 
 /// Interface for int plug-ins
-class Int:public Property<IntType , IntType>
+class TLP_SCOPE Int:public Property<IntType , IntType>
 { 
   ///
   friend class IntProxy;
