@@ -12,6 +12,10 @@
 #ifndef _LAYOUT_H
 #define _LAYOUT_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "Types.h"
 #include "Property.h"
 class PropertyContext;
@@ -22,7 +26,7 @@ class LayoutProxy;
  */ 
 /*@{*/
 ///Interface for layout plug-ins
-class Layout:public Property<PointType , LineType> {
+class TLP_SCOPE Layout:public Property<PointType , LineType> {
   ///
   friend class LayoutProxy;
 public:
