@@ -2,21 +2,25 @@
 #ifndef TULIP_LAYOUTPROXY_H
 #define TULIP_LAYOUTPROXY_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "PropertyProxy.h"
 #include "MethodFactory.h"
 #include "TemplateFactory.h"
+#include "Layout.h"
 
 class PropertyContext;
 class SuperGraph;
 
 /** \addtogroup properties */ 
 /*@{*/
-class LayoutProxy:public PropertyProxy<PointType,LineType> {
+class TLP_SCOPE LayoutProxy:public PropertyProxy<PointType, LineType, Layout> {
   friend class Layout;
 
 public:
   LayoutProxy (SuperGraph *);
-  LayoutProxy ();
   ~LayoutProxy();
 
   PProxy* clonePrototype(SuperGraph *, std::string );
@@ -30,19 +34,12 @@ public:
 
   //============================================
   //Functions for layout modification
-  void center();
-  void normalize() _DEPRECATED;
+  void translate(const tlp::Vector<float,3>& v, SuperGraph *graph=0);
+  void scale(const tlp::Vector<float,3>& v, SuperGraph *graph=0);
+  void center(SuperGraph *graph = 0);
+  void normalize(SuperGraph *graph = 0);
   void perfectAspectRatio();
-  void reset_handler();
-  void recompute_handler();
   void resetBoundingBox();
-  void clone_handler(PropertyProxy<PointType,LineType> &);
-  
-  virtual void setNodeValue_handler(const node n);
-  virtual void setEdgeValue_handler(const edge e);
-  virtual void setAllNodeValue_handler();
-  virtual void setAllEdgeValue_handler();
-
   //==============================================================
   // Set of function in order to measure the quality of the Layout
   //==============================================================
@@ -76,6 +73,15 @@ public:
    */
   unsigned int crossingNumber();
 
+protected:
+  void recompute_handler();
+  void reset_handler();
+  void clone_handler(PropertyProxy<PointType,LineType> &);
+  virtual void setNodeValue_handler(const node n);
+  virtual void setEdgeValue_handler(const edge e);
+  virtual void setAllNodeValue_handler();
+  virtual void setAllEdgeValue_handler();
+
 private:
   stdext::hash_map<int,Coord> max,min;
   stdext::hash_map<int,bool> minMaxOk;
