@@ -10,6 +10,7 @@
 */
 #include <tulip/Iterator.h>
 #include <tulip/SuperGraph.h>
+#include <tulip/tulipconf.h>
 #include <list>
 
 #ifndef TULIP_NODEMAPITERATOR_H
@@ -18,10 +19,14 @@
 /** \addtogroup graphs */ 
 /*@{*/
 
+
+namespace tlp {
+  TLP_SCOPE edge nextFaceEdge(SuperGraph* g, edge e, node n);
+}
 /**
  *
  */
-struct NodeMapIterator : public Iterator<node> {
+struct TLP_SCOPE NodeMapIterator : public Iterator<node> {
   ///
   NodeMapIterator(SuperGraph *sg, node source, node target);
   ~NodeMapIterator();
@@ -38,7 +43,7 @@ private :
 /**
  *
  */
-struct EdgeMapIterator : public Iterator<edge> {
+struct TLP_SCOPE EdgeMapIterator : public Iterator<edge> {
   ///
   EdgeMapIterator(SuperGraph *sg, edge source, node target);
   ///
@@ -49,8 +54,11 @@ struct EdgeMapIterator : public Iterator<edge> {
   bool hasNext();
   
 private :
-  std::list<edge> cloneIt;
-  std::list<edge>::iterator itStl;
+  std::vector<edge> adj;
+  edge start;
+  int treat;
+  unsigned int pos;
+  bool finished;
 };
 /*@}*/
 #endif
