@@ -17,7 +17,8 @@
 
 class PropertyContext;
 class MetaGraphProxy;
-
+/** \addtogroup plugins */ 
+/*@{*/
 
 /// Interface for metric plug-ins
 class MetaGraph:public Property<MetaGraphType , MetaGraphType>
@@ -30,10 +31,11 @@ public:
   MetaGraphProxy *metaGraphProxy;
 protected:
   ///
-  MetaGraph (PropertyContext  *context);
+  MetaGraph (const PropertyContext & context);
   ///
   virtual ~MetaGraph(){}
 };
 
+/*@}*/
 #endif
 
