@@ -2,6 +2,10 @@
 #ifndef TULIP_METAGRAPHPROXY_H
 #define TULIP_METAGRAPHPROXY_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "PropertyProxy.h"
 #include "MethodFactory.h"
 #include "TemplateFactory.h"
@@ -10,8 +14,7 @@ class PropertyContext;
 
 /** \addtogroup properties */ 
 /*@{*/
-class MetaGraphProxy:public PropertyProxy<MetaGraphType,MetaGraphType> { 
-
+class TLP_SCOPE MetaGraphProxy:public PropertyProxy<MetaGraphType,MetaGraphType> { 
   friend class MetaGraph;
 
 public :
@@ -20,9 +23,6 @@ public :
   PProxy* clonePrototype(SuperGraph *, std::string );
   void copy( const node, const node, PProxy * );
   void copy( const edge, const edge, PProxy * );
-  void reset_handler();
-  void recompute_handler();
-  void clone_handler(PropertyProxy<MetaGraphType,MetaGraphType> &);
 };
 /*@}*/
 #endif
