@@ -11,6 +11,11 @@
 #ifndef METHODFACTORY_H
 #define METHODFACTORY_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+
 #include <string>
 
 #include "Plugin.h"
@@ -33,7 +38,7 @@
 /** \addtogroup plugins */ 
 /*@{*/
 
-template <class T> class PropertyFactory:public Plugin {
+template <class T> class TLP_SCOPE PropertyFactory:public Plugin {
 public:
   PropertyFactory(){}
   virtual ~PropertyFactory() {}
@@ -41,7 +46,6 @@ public:
 };
 
 
-
 // Macro for factorization of source code
 #define PROPERTYPLUGINFACTORY(T,C,N,A,D,I,V,R)          \
 class C##T##Factory:public PropertyFactory<T>           \
@@ -131,11 +135,3 @@ extern "C" {                                            \
 #define CLUSTERINGPLUGIN(C,N,A,D,I,V,R) SUPERGRAPHPLUGINFACTORY(Clustering,C,N,A,D,I,V,R)
 /*@}*/
 #endif
-
-
-
-
-
-
-
-
