@@ -12,6 +12,10 @@
 #ifndef _METRIC_H
 #define _METRIC_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "Types.h"
 #include "Property.h"
 
@@ -20,7 +24,7 @@ class MetricProxy;
 /** \addtogroup plugins */ 
 /*@{*/
 /// Interface for metric plug-ins
-class Metric:public Property<DoubleType , DoubleType> { 
+class TLP_SCOPE Metric:public Property<DoubleType , DoubleType> { 
   ///
   friend class MetricProxy;
 public:
