@@ -5,12 +5,17 @@
 #include "PropertyProxy.h"
 #include "MethodFactory.h"
 #include "TemplateFactory.h"
+#include "Metric.h"
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 class PropertyContext;
 
 /** \addtogroup properties */ 
 /*\@{*/
-class MetricProxy:public PropertyProxy<DoubleType,DoubleType> { 
+class TLP_SCOPE MetricProxy:public PropertyProxy<DoubleType,DoubleType,Metric> { 
 
   friend class Metric;
 
@@ -25,6 +30,8 @@ public :
   void copy( const node, const node, PProxy * );
   void copy( const edge, const edge, PProxy * );
   void uniformQuantification(unsigned int);
+
+protected:
   virtual void setNodeValue_handler(const node n);
   virtual void setEdgeValue_handler(const edge e);
   virtual void setAllNodeValue_handler();
