@@ -18,19 +18,20 @@ struct node {
   explicit node(unsigned int j):id(j){}
   bool operator!=(const node n) const {return id!=n.id;}
   bool operator==(const node n) const {return id==n.id;}
+  bool isValid() const {return id!=UINT_MAX;}
 };
 /*@}*/
 namespace stdext {
-  struct hash<node> {
+  template<> struct hash<node> {
     size_t operator()(const node n) const {return n.id;}
   };
 }
 
 namespace std {
-  struct equal_to<node> {
+  template<> struct equal_to<node> {
     size_t operator()(const node n,const node n2) const {return n.id==n2.id;}
   };
-  struct less<node>{
+  template<> struct less<node>{
     size_t operator()(const node n,const node n2) const {return n.id<n2.id;}
   };
 }
