@@ -1,5 +1,12 @@
 #ifndef OBSERVABLE_H
 #define OBSERVABLE_H
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <tulip/tulipconf.h>
+
 #include <list>
 #include <map>
 #include <set>
@@ -32,7 +39,7 @@ typedef std::map<Observer *,std::set<Observable *> > ObserverMap;
  *par une instance de la classe Observer. 
  *@see Observer
  */
-class Observable {
+class TLP_SCOPE Observable {
  public:
   virtual ~Observable() {}
   /**
