@@ -13,10 +13,9 @@
 #define TULIPPLUGIN_H
 #include <string>
 /**Common interface for plug-ins.*/
-class Plugin
-{
+class Plugin {
 public:
-  /**Return the name of the plug-in, becareful, 
+  /**Return the name of the plug-in, be careful, 
      this name must be unique, if two plug-ins have the same name
      only the latest loaded will be available*/
   virtual  std::string getName() const=0;
