@@ -13,6 +13,10 @@
 #ifndef TULIP_PROPERTY_H
 #define TULIP_PROPERTY_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "PluginContext.h"
 #include "SuperGraph.h"
 #include "Reflect.h"
@@ -25,7 +29,7 @@ class PropertyManager;
  */ 
 /*@{*/
 
-class PProperty:public WithParameter{
+class TLP_SCOPE PProperty:public WithParameter{
 public:
   ///
   virtual ~PProperty(){}
@@ -37,16 +41,15 @@ public:
   virtual void reset() = 0;
 };
 
-
 ///
-template <typename Tnode, typename Tedge> class Property:public PProperty {
+template <typename Tnode, typename Tedge> 
+class TLP_SCOPE Property: public PProperty {
 public :
   ///
-  Property(const PropertyContext & context) {
-      superGraph = context.superGraph;
-      //      propertyProxy = context->propertyProxy;
-      pluginProgress = context.pluginProgress;
-      dataSet= context.dataSet;
+  Property(const PropertyContext & context) :
+    superGraph(context.superGraph),
+    pluginProgress(context.pluginProgress),
+    dataSet(context.dataSet) {
   }
   ///
   virtual ~Property(){}
@@ -55,20 +58,15 @@ public :
   ///
   virtual typename Tedge::RealType getEdgeValue(const edge ) {return Tedge::defaultValue();}
   ///
-  bool run() {return true;}
+  virtual bool run() {return true;}
   ///
-  bool check(std::string &) {return true;}
+  virtual bool check(std::string &) {return true;}
   ///
-  void reset() {}
+  virtual void reset() {}
 
 protected:
-  ///
   SuperGraph *superGraph;
-  ///
-  //  PProxy *propertyProxy;
-  ///
   PluginProgress *pluginProgress;
-  ///
   DataSet *dataSet;
 };
 /*@}*/
