@@ -11,10 +11,8 @@
 #ifndef TULIP_PROPERTIESPROXY_H
 #define TULIP_PROPERTIESPROXY_H
 
-#if (__GNUC__ < 3)
-#include <hash_map>
-#else
-#include <ext/hash_map>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
 #endif
 
 #include "Observable.h"
@@ -27,14 +25,12 @@
 #include "MethodFactory.h"
 #include "TemplateFactory.h"
 
-
-
 /**
  * \addtogroup properties
  */ 
 /*@{*/
 //=============================================================
-class PProxy: public Observable {
+class TLP_SCOPE PProxy: public Observable {
 public:
   virtual ~PProxy(){}
   virtual void erase(const node)=0;
@@ -42,7 +38,6 @@ public:
   virtual void copy(const node, const node, PProxy *)=0;
   virtual void copy(const edge, const edge, PProxy *)=0;
   virtual PProxy* clonePrototype(SuperGraph *, std::string)=0;
-
   //=================================================================================
   // Returns a string describing the type of the proxy.
   // i.e. "metagraph", "metric", "layout", "string", "int", "color", "size", ...
@@ -54,11 +49,12 @@ public:
   virtual std::string getEdgeDefaultStringValue() = 0;
   virtual std::string getNodeStringValue( const node n ) = 0;
   virtual std::string getEdgeStringValue( const edge e ) = 0;
-  virtual bool		  setNodeStringValue( const node n, const std::string & v ) = 0;
-  virtual bool		  setEdgeStringValue( const edge e, const std::string & v ) = 0;
-  virtual bool		  setAllNodeStringValue( const std::string & v ) = 0;
-  virtual bool		  setAllEdgeStringValue( const std::string & v ) = 0;
+  virtual bool setNodeStringValue( const node n, const std::string & v ) = 0;
+  virtual bool setEdgeStringValue( const edge e, const std::string & v ) = 0;
+  virtual bool setAllNodeStringValue( const std::string & v ) = 0;
+  virtual bool setAllEdgeStringValue( const std::string & v ) = 0;
 };
+
 /**
  * This class is used to store a property of a graph.
  * A property is a couple of two functions:
@@ -70,31 +66,13 @@ public:
  * In the second case it is only a memory area for storing data.
  * A PropertyProxy is an observable, so it can be observed by others objects.
  */
-template <class Tnode, class Tedge> class PropertyProxy:public PProxy {
+template <class Tnode, class Tedge, class TPROPERTY = Property<Tnode,Tedge> > class TLP_SCOPE PropertyProxy:public PProxy {
   friend class SuperGraphView;
 
-
 public:
-  static TemplateFactory< PropertyFactory<Property<Tnode,Tedge> >, Property<Tnode,Tedge>, PropertyContext > factory;
+  static TemplateFactory< PropertyFactory<TPROPERTY>, TPROPERTY, PropertyContext > factory;
   PropertyProxy(SuperGraph *);
   ~PropertyProxy() ;
-
-  /**
-   * Reset the proxy and notify the observers, if the property is
-   * a data property (not connected to a plug-in) all elements receive
-   * the default value of the property else the value will be recomputed
-   * from the plug-in.
-   */
-  void reset();
-  /**
-   * Handler function for inherited PropertyProxy. This function
-   * is called after a reset operation.
-   */
-  virtual void reset_handler(){};
-  /**
-   * Return the name of this property
-   */
-  std::string getName();
   /** 
    * Return the node default value of the property proxy
    * warnning: If the type is a pointer it can produce big memory
@@ -129,67 +107,69 @@ public:
    * a node n, the plug-in won't be call for n.
    */
   virtual void setNodeValue(const node n,const typename Tnode::RealType v);
-  /**
-   * Handler function for inherited PropertyProxy. This function
-   * is called after a setNodeValue operation.
-   */
-  virtual void setNodeValue_handler(const node n){};
-  //=============================================================
   /**
    * Set the value of an edge and notify the observers of a modification.
    * Warning : When using computed property (plug-in), if one sets the value of
    * a edge e, the plug-in won't be call for e.
    */
   void setEdgeValue(const edge e,const typename Tedge::RealType v);
-  /**
-   * Handler function for inherited PropertyProxy. This function
-   * is called after a setEdgeValue operation.
-   */
-  virtual void setEdgeValue_handler(const edge e){};
-  //=============================================================
   /**
    * Set the value of all nodes and notify the observers
    */
   void setAllNodeValue(const typename Tnode::RealType v);
+  /**
+   * Set the value of all edges and notify the observers
+   */
+  void setAllEdgeValue(const typename Tedge::RealType v);
+  //=================================================================================
+  void erase(const node n);
+  //=================================================================================
+  void erase(const edge e);
+  //=================================================================================
+  virtual PropertyProxy<Tnode,Tedge,TPROPERTY>& operator =(PropertyProxy<Tnode,Tedge,TPROPERTY> &proxy);
+  //=================================================================================
+  bool compute(const std::string &algorithm, std::string &msg, const PropertyContext&);
+  //=================================================================================
+  virtual std::string getTypename();
+  // Untyped accessors
+  virtual std::string getNodeDefaultStringValue();
+  virtual std::string getEdgeDefaultStringValue();
+  virtual std::string getNodeStringValue( const node n );
+  virtual std::string getEdgeStringValue( const edge e );
+  virtual bool setNodeStringValue( const node n, const std::string & v );
+  virtual bool setEdgeStringValue( const edge e, const std::string & v );
+  virtual bool setAllNodeStringValue( const std::string & v );
+  virtual bool setAllEdgeStringValue( const std::string & v );
+
+protected:
+  /**
+   * Handler function for inherited PropertyProxy. This function
+   * is called after a reset operation.
+   */
+  virtual void reset_handler(){};
+  //=================================================================================
+  ///Enable to clone part of sub_class
+  virtual void clone_handler(PropertyProxy<Tnode,Tedge,TPROPERTY> &){};
   /**
    * Handler function for inherited PropertyProxy. This function
    * is called after a setAllNodeValue operation.
    */
   virtual void setAllNodeValue_handler(){};
-  /**
-   * Set the value of all edges and notify the observers
-   */
-  void setAllEdgeValue(const typename Tedge::RealType v);
   /**
    * Handler function for inherited PropertyProxy. This function
    * is called after a setAllEdgeValue operation.
    */
   virtual void setAllEdgeValue_handler(){};
-  //=================================================================================
-  void erase(const node n);
-  //=================================================================================
-  void erase(const edge e);
-  //=================================================================================
-  virtual PropertyProxy<Tnode,Tedge>& operator =(PropertyProxy<Tnode,Tedge> &proxy);
-  //=================================================================================
-  ///Enable to clone part of sub_class
-  virtual void clone_handler(PropertyProxy<Tnode,Tedge> &){};
-  //=================================================================================
-  bool compute(const std::string &algorithm, std::string &msg, const PropertyContext&);
-
-  //=================================================================================
-  virtual std::string getTypename();
-
-  // Untyped accessors
-  virtual std::string getNodeDefaultStringValue();
-  virtual std::string getEdgeDefaultStringValue();
-  virtual std::string getNodeStringValue( const node n );
-  virtual std::string getEdgeStringValue( const edge e );
-  virtual bool		  setNodeStringValue( const node n, const std::string & v );
-  virtual bool		  setEdgeStringValue( const edge e, const std::string & v );
-  virtual bool		  setAllNodeStringValue( const std::string & v );
-  virtual bool		  setAllEdgeStringValue( const std::string & v );
-
+  /**
+   * Handler function for inherited PropertyProxy. This function
+   * is called after a setEdgeValue operation.
+   */
+  virtual void setEdgeValue_handler(const edge e){};
+  /**
+   * Handler function for inherited PropertyProxy. This function
+   * is called after a setNodeValue operation.
+   */
+  virtual void setNodeValue_handler(const node n){};
 protected:
   MutableContainer<bool> nodeComputed;
   MutableContainer<typename Tnode::RealType> nodeProperties;
@@ -199,9 +179,14 @@ protected:
   typename Tedge::RealType edgeDefaultValue;
   Property< Tnode , Tedge > *currentProperty;
   SuperGraph *superGraph;
-  //=============================================================
+  bool circularCall;
+private:
+  /**
+   * Reset the proxy and notify the observers, all value are set to default
+   * Property is deleted, all value are set to unbuffered
+   */
+  void reset();
 };
 /*@}*/
 #include "./cxx/PropertyProxy.cxx"
 #endif
-
