@@ -1,6 +1,10 @@
 #ifndef _TULIPREFLECT
 #define _TULIPREFLECT
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+#include <tulip/tulipconf.h>
 #include <iostream>
 #include <string>
 #include <cassert>
@@ -11,7 +15,7 @@
 struct SuperGraph;
 
 
-struct DataType {
+struct TLP_SIMPLE_SCOPE DataType {
   DataType(){}
   DataType(void *value,const std::string typeName):value(value),typeName(typeName){}
   void * value;
@@ -21,7 +25,7 @@ struct DataType {
 
 /**  A container which allows insertion of different type.
      The inserted data must have a copy-constructor well done */
-struct DataSet {
+struct TLP_SIMPLE_SCOPE DataSet {
   /**Return a copy of the value of the variable with name str.
      Type are checked in Debug Mode.
      If the variable str doesn't exist return false else true. */
@@ -44,7 +48,7 @@ private:
 
 
 //This class enables to define a structure
-struct StructDef {
+struct TLP_SIMPLE_SCOPE StructDef {
   //Add the variable of type T and name str in the structure.
   template<typename T> void add(	std::string str,
   									const char * inHelp = 0,
