@@ -12,6 +12,10 @@
 #ifndef _SELECTION_H
 #define _SELECTION_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "Types.h"
 #include "Property.h"
 
@@ -24,7 +28,7 @@ class SelectionProxy;
 /*@{*/
 
 /// Interface for selection plug-ins
-class Selection:public Property<BooleanType , BooleanType>
+class TLP_SCOPE Selection:public Property<BooleanType , BooleanType>
 { 
   ///
   friend class SelectionProxy;
