@@ -2,14 +2,19 @@
 #ifndef TULIP_SELECTIONPROXY_H
 #define TULIP_SELECTIONPROXY_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "PropertyProxy.h"
 #include "MethodFactory.h"
 #include "TemplateFactory.h"
+#include "Selection.h"
 
 class PropertyContext;
 /** \addtogroup properties */ 
 /*@{*/
-class SelectionProxy:public PropertyProxy<BooleanType,BooleanType> { 
+class TLP_SCOPE SelectionProxy:public PropertyProxy<BooleanType,BooleanType, Selection> { 
   friend class Selection;
 
 public :
@@ -18,13 +23,12 @@ public :
   PProxy* clonePrototype(SuperGraph *, std::string );
   void copy( const node, const node, PProxy * );
   void copy( const edge, const edge, PProxy * );
-  bool reCompute(std::string &erreurMsg);
-  void reset_handler();
-  void recompute_handler();  
-  ///Effectue un not sur tous les élément visible du proxy
   void reverse();
   ///reverse all the direction of edges of the visible graph which are true in this Selection Proxy
   void reverseEdgeDirection();
+
+protected:
+  void reset_handler();
 };
 /*@}*/
 #endif
