@@ -12,6 +12,10 @@
 #ifndef TULIP_SIZES_H
 #define TULIP_SIZES_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "Types.h"
 #include "Property.h"
 class PropertyContext;
@@ -22,7 +26,7 @@ class SizesProxy;
  */ 
 /*@{*/
 /// Interface for sizes plug-ins
-class Sizes:public Property< SizeType , SizeType >
+class TLP_SCOPE Sizes:public Property< SizeType , SizeType >
 { 
   ///
   friend class SizesProxy;
