@@ -2,31 +2,37 @@
 #ifndef TULIP_SIZESPROXY_H
 #define TULIP_SIZESPROXY_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "PropertyProxy.h"
 #include "MethodFactory.h"
 #include "TemplateFactory.h"
+#include "Sizes.h"
 
 class PropertyContext;
 /**
  * \defgroup properties
  */ 
 /*@{*/
-class SizesProxy:public PropertyProxy<SizeType,SizeType> { 
+class TLP_SCOPE SizesProxy:public PropertyProxy<SizeType,SizeType, Sizes> { 
 
   friend class Sizes;
 
 public :
   SizesProxy (SuperGraph *);
   ~SizesProxy();
-  void reset_handler();
-  void recompute_handler();
+
   Size getMax(SuperGraph *sg=0);
   Size getMin(SuperGraph *sg=0);
   PProxy* clonePrototype(SuperGraph *, std::string );
   void copy( const node, const node, PProxy * );
   void copy( const edge, const edge, PProxy * );
+  void scale( const tlp::Vector<float,3>&, SuperGraph *graph=0 );
 
 protected:
+  void reset_handler();
   void resetMinMax();
   virtual void setNodeValue_handler(const node n);
   virtual void setEdgeValue_handler(const edge e);
