@@ -11,10 +11,11 @@
 #ifndef TULIP_STABLEITERATOR_H
 #define TULIP_STABLEITERATOR_H
 #include <tulip/Iterator.h>
+#include <tulip/tulipconf.h>
 #include <vector>
 
 ///Interface of StableIterator,
-template<class itType> struct StableIterator : public Iterator<itType> {
+template<class itType> struct TLP_SCOPE StableIterator : public Iterator<itType> {
   StableIterator(Iterator<itType> *itIn) {
     for (;itIn->hasNext();) {
       cloneIt.push_back(itIn->next());
