@@ -13,16 +13,36 @@
 #include <map>
 #include "Iterator.h"
 
+
+
+template<typename VALUE, typename ITERATOR> 
+struct StlIterator:public Iterator< VALUE  > {
+  StlIterator(ITERATOR startIt, ITERATOR endIt):
+    it(startIt),
+    itEnd(endIt)
+  {}
+  VALUE next() {
+    VALUE tmp=*it;
+    ++it;
+    return tmp;
+  }
+  bool hasNext() {
+    return (itEnd!=it);
+  }
+private:
+  ITERATOR it, itEnd;
+};
+
 template<typename KEY, typename VALUE> 
 struct StlMapIterator:public Iterator< std::pair<KEY,VALUE> > {
-  StlMapIterator(typename std::map<KEY,VALUE>::iterator startIt, typename std::map<KEY,VALUE>::iterator endIt):
+  StlMapIterator(typename std::map<KEY,VALUE>::const_iterator startIt, typename std::map<KEY,VALUE>::const_iterator endIt):
     it(startIt),
     itEnd(endIt)
   {}
   std::pair<KEY,VALUE> next();
   bool hasNext();
 private:
-  typename std::map<KEY,VALUE>::iterator it, itEnd;
+  typename std::map<KEY,VALUE>::const_iterator it, itEnd;
 };
 //=================================================
 //StlMapIterator implemetation
