@@ -13,6 +13,10 @@
 #ifndef TULIP_STRING_H
 #define TULIP_STRING_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "Types.h"
 #include "Property.h"
 
@@ -23,7 +27,7 @@ class StringProxy;
 /*@{*/
 
 /// Interface for String plug-ins
-class String:public Property<StringType , StringType>
+class TLP_SCOPE String:public Property<StringType , StringType>
 { 
   ///
   friend class StringProxy;
