@@ -2,14 +2,18 @@
 #ifndef TULIP_STRINGPROXY_H
 #define TULIP_STRINGPROXY_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "PropertyProxy.h"
 #include "MethodFactory.h"
 #include "TemplateFactory.h"
-
+#include "String.h"
 class PropertyContext;
 /** \addtogroup properties */ 
 /*\@{*/
-class StringProxy:public PropertyProxy<StringType,StringType>{ 
+class TLP_SCOPE StringProxy:public PropertyProxy<StringType,StringType, String>{ 
 
   friend class String;
 
@@ -19,6 +23,8 @@ public :
   PProxy* clonePrototype(SuperGraph *, std::string );
   void copy( const node, const node, PProxy * );
   void copy( const edge, const edge, PProxy * );
+
+protected:
   void reset_handler();
   void recompute_handler();  
 };
