@@ -11,6 +11,10 @@
 #ifndef Tulip_SUPERGRAPH_H
 #define Tulip_SUPERGRAPH_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <iostream>
 #include <string>
 
@@ -45,7 +49,7 @@ namespace tlp {
 /**
  * The class SuperGraph is the interface of a Graph in the Tulip Library.
  */
-class SuperGraph : public ObservableGraph {
+class TLP_SIMPLE_SCOPE SuperGraph : public ObservableGraph {
 
 public:  
   SuperGraph() {
@@ -112,6 +116,7 @@ public:
   /**
    * Delete a node in the graph. this node is also removed in all 
    * the sub-graph of the graph to maintain the sub-graph relation between graphs.
+   * Warning : One can't add an existing node to the root graph
    */
   virtual void delNode(const node)=0;
   /**
@@ -129,18 +134,19 @@ public:
    * the super-graph of the graph to maintain the sub-graph relation between graphs.
    * Warning, the edge must be element of the graph hierarchy, thus it must be 
    * element of the root graph.
+   * Warning : One can't add an existing edge to the root graph
    */
   virtual void addEdge(const edge )=0;
   /**
    * Delete an edge in the graph. this edge is also removed in all 
    * the sub-graph of the graph to maintain the sub-graph relation between graphs.
-   * If the second parameter is true the ordering of edges will be preserved.
+   * The ordering of edges is preserved.
    */
   virtual  void delEdge(const edge )=0;
   /**
    * Delete an edge in all the hierarchy of graphs. 
-   * Warning : the ordering of edges around the node
-   * can be change due to this operation.
+   * The ordering of edges around the node
+   * is preserved.
    */
   virtual  void delAllEdge(const edge)=0;
   /**
@@ -163,6 +169,8 @@ public:
   //================================================================================
   //Iterators on the graph structure.
   //================================================================================
+  /// Return an existing node of the graph
+  virtual node getOneNode() const =0;
   ///Return an iterator on the nodes.
   virtual Iterator<node>* getNodes() const =0;
   /// Return the ith successor of a node
@@ -177,12 +185,14 @@ public:
   virtual Iterator<node>* getInOutNodes(const node) const =0;
   /// Return an iterator on the edges.
   virtual Iterator<edge>* getEdges() const =0;
-  /// Return an iterator on the in-edges of a node.
-  virtual Iterator<edge>* getInEdges(const node) const =0;
+  /// Return an existing edge of the graph
+  virtual edge getOneEdge() const =0;
   /// Return an iterator on the out-edges of a node.
   virtual Iterator<edge>* getOutEdges(const node) const =0;
   /// Return an iterator on the in-out-edges of a node.
   virtual Iterator<edge>* getInOutEdges(const node) const =0;
+  /// Return an iterator on the in--edges of a node.
+  virtual Iterator<edge>* getInEdges(const node) const =0;
   //================================================================================
   // Graph, nodes and adges informations about the graph stucture
   //================================================================================
@@ -208,10 +218,11 @@ public:
   virtual bool isElement(const node )=0;
   /// Return true if the edge is element of the graph.
   virtual bool isElement(const edge )=0;
-  /** Return true if it exists an edge between two node 
+  /** Return the edge if it exists an edge between two node 
    *  sens of the edge is not taken into account)
+   *  If no edge is found return an invalid edge.
    */
-  virtual bool existEdge(const node , const node)const =0;
+  virtual edge existEdge(const node , const node)const =0;
   //================================================================================
   // Access to the graph attributes and to the node/edge property.
   //================================================================================
@@ -300,21 +311,22 @@ private:
 };
 
 ///Print the graph (only nodes and edges) in ostream, in the tulip format
-std::ostream& operator<< (std::ostream &,const SuperGraph *);
+TLP_SCOPE std::ostream& operator<< (std::ostream &,const SuperGraph *);
 /*@}*/
 //================================================================================
 // Specilization of some template class
 //================================================================================
 namespace stdext {
-  struct hash<const SuperGraph *> {
+  template <>
+  struct TLP_SCOPE hash<const SuperGraph *> {
     size_t operator()(const SuperGraph *s) const {return size_t(s->getId());}
   };
-  struct hash<SuperGraph *> {
+  template <>
+  struct TLP_SCOPE hash<SuperGraph *> {
     size_t operator()(SuperGraph *s) const {return size_t(s->getId());}
   };
 }
 
-
 //include the template code
 #include "cxx/SuperGraph.cxx"
 #endif
