@@ -33,7 +33,7 @@ class SuperGraphImpl:public SuperGraphAbstract {
 public:
   SuperGraphImpl();
   ~SuperGraphImpl();
-  
+  void clear();
   //=========================================================================
   bool isElement(const node );
   bool isElement(const edge );
@@ -73,8 +73,6 @@ private :
   typedef SimpleVector<edge> EdgeContainer;
   typedef std::vector<EdgeContainer> Nodes;
   typedef std::vector<std::pair< node , node > > Edges;
-  SuperGraph *_superGraph;
-  //IntProxy *outDegree;
   MutableContainer<unsigned int> outDegree;
   mutable Edges edges;
   mutable Nodes nodes;
