@@ -13,7 +13,8 @@
 #ifndef Tulip_SUPERGRAPHVIEW_H
 #define Tulip_SUPERGRAPHVIEW_H
 
-#include "SuperGraphAbstract.h"
+#include "tulip/SuperGraphAbstract.h"
+#include "tulip/MutableContainer.h"
 
 
 /**
@@ -36,11 +37,16 @@ public:
   void delAllEdge(const edge);
   void setEdgeOrder(const node,const std::vector<edge> & );
   void swapEdgeOrder(const node,const edge , const edge );
+  //  void reverse(const edge);
   //=========================================================================
   bool isElement(const node );
   bool isElement(const edge );
   unsigned int numberOfNodes()const;
   unsigned int numberOfEdges()const;
+    //=========================================================================
+  /*  unsigned int deg(const node) const;
+  unsigned int indeg(const node) const;
+  unsigned int outdeg(const node) const;*/
   //=========================================================================
   Iterator<node>* getNodes()const;
   Iterator<node>* getInNodes(const node)const;
@@ -53,9 +59,10 @@ public:
   //=========================================================================
 
 private:
-  SuperGraph *_superGraph;
-
-  SelectionProxy *adaptativeFilter;
+  MutableContainer<bool> nodeAdaptativeFilter;
+  MutableContainer<bool> edgeAdaptativeFilter;
+  //  MutableContainer<unsigned int> outDegree;
+  //  MutableContainer<unsigned int> inDegree;
   mutable int nNodes;
   mutable int nEdges;
 };
