@@ -12,6 +12,10 @@
 #ifndef TULIP_TREETEST_H
 #define TULIP_TREETEST_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #if (__GNUC__ < 3)
 #include <hash_set>
 #else
@@ -24,7 +28,7 @@ class SelectionProxy;
 
 /** \addtogroup graph_test */ 
 /*@{*/
-class TreeTest : public GraphObserver {
+class TLP_SCOPE TreeTest : private GraphObserver {
 public:
   static bool isTree(SuperGraph *graph);
 
