@@ -1,10 +1,14 @@
 #ifndef _TULIPWITHPARAMETER
 #define _TULIPWITHPARAMETER
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "Reflect.h"
 /** \addtogroup plugins */ 
 /*@{*/
-struct WithParameter {
+struct TLP_SCOPE WithParameter {
   ///
   StructDef getParameters();
   ///
