@@ -1,7 +1,4 @@
 //-*-c++-*-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include "tulip/Types.h"
 #include "tulip/Colors.h"
