@@ -8,16 +8,16 @@
 #include "tulip/SelectionProxy.h"
 
 //============================================================
-SGraphNodeIterator::SGraphNodeIterator(const SuperGraph *sG,SelectionProxy *filter):FactorIterator<node>(sG,filter) {
+SGraphNodeIterator::SGraphNodeIterator(const SuperGraph *sG, const MutableContainer<bool>& filter):FactorIterator<node>(sG,filter) {
   it=_parentGraph->getNodes();
   _hasnext=false;
   if (it->hasNext()) {
     curNode=it->next();
-    while (_selectionProxy->getNodeValue(curNode)!=true) {
+    while (_selectionProxy.get(curNode.id)!=true) {
       if (!it->hasNext()) break;
       curNode=it->next();
     }
-    if (_selectionProxy->getNodeValue(curNode)) _hasnext=true;
+    if (_selectionProxy.get(curNode.id)) _hasnext=true;
   }
 }
 SGraphNodeIterator::~SGraphNodeIterator() {
@@ -28,11 +28,11 @@ node SGraphNodeIterator::next() {
   _hasnext=false;
   if (it->hasNext()) {
     curNode=it->next();
-    while (_selectionProxy->getNodeValue(curNode)!=true) {
+    while (_selectionProxy.get(curNode.id)!=true) {
       if (!it->hasNext()) break;
       curNode=it->next();
     }
-    if (_selectionProxy->getNodeValue(curNode)) _hasnext=true;
+    if (_selectionProxy.get(curNode.id)) _hasnext=true;
   }
   return tmp;
 }
@@ -40,7 +40,7 @@ bool SGraphNodeIterator::hasNext(){
   return (_hasnext);
 }
 //===================================================================
-OutNodesIterator::OutNodesIterator(const SuperGraph *sG,SelectionProxy *filter,node n):FactorIterator<node>(sG,filter) {
+OutNodesIterator::OutNodesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter,node n):FactorIterator<node>(sG,filter) {
   it=new OutEdgesIterator(sG,filter,n);
 }
 OutNodesIterator::~OutNodesIterator() {
@@ -55,7 +55,7 @@ bool OutNodesIterator::hasNext() {
   return (it->hasNext());
 }
 //===================================================================
-InNodesIterator::InNodesIterator(const SuperGraph *sG,SelectionProxy *filter,node n):FactorIterator<node>(sG,filter),
+InNodesIterator::InNodesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter, node n):FactorIterator<node>(sG,filter),
 										   it(new InEdgesIterator(sG,filter,n)) {
 }
 InNodesIterator::~InNodesIterator() { 
@@ -70,7 +70,7 @@ bool InNodesIterator::hasNext() {
   return (it->hasNext());
 }
 //===================================================================
-InOutNodesIterator::InOutNodesIterator(const SuperGraph *sG,SelectionProxy *filter,node n):FactorIterator<node>(sG,filter),
+InOutNodesIterator::InOutNodesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter,node n):FactorIterator<node>(sG,filter),
 											 it(new InOutEdgesIterator(sG,filter,n)),
 											 n(n) {
 }
@@ -84,16 +84,16 @@ bool InOutNodesIterator::hasNext() {
   return (it->hasNext());
 }
 //===============================================================
-SGraphEdgeIterator::SGraphEdgeIterator(const SuperGraph *sG,SelectionProxy *filter):FactorIterator<edge>(sG,filter) {
+SGraphEdgeIterator::SGraphEdgeIterator(const SuperGraph *sG, const MutableContainer<bool>& filter):FactorIterator<edge>(sG,filter) {
   it=_parentGraph->getEdges();
   _hasnext=false;
   if (it->hasNext()) {
     curEdge=it->next();
-    while (_selectionProxy->getEdgeValue(curEdge)!=true) {
+    while (_selectionProxy.get(curEdge.id)!=true) {
       if (!it->hasNext()) break;
       curEdge=it->next();
     }
-    if (_selectionProxy->getEdgeValue(curEdge)) _hasnext=true;
+    if (_selectionProxy.get(curEdge.id)) _hasnext=true;
   }
 }
 SGraphEdgeIterator::~SGraphEdgeIterator() {
@@ -104,11 +104,11 @@ edge SGraphEdgeIterator::next() {
   _hasnext=false;
   if (it->hasNext()){
     curEdge=it->next();
-    while (_selectionProxy->getEdgeValue(curEdge)!=true) {
+    while (_selectionProxy.get(curEdge.id)!=true) {
       if (!it->hasNext()) break;
       curEdge=it->next();
     }
-    if (_selectionProxy->getEdgeValue(curEdge)) _hasnext=true;
+    if (_selectionProxy.get(curEdge.id)) _hasnext=true;
   }
   return tmp;
 }
@@ -116,17 +116,17 @@ bool SGraphEdgeIterator::hasNext() {
   return (_hasnext);
 }
 //===================================================================
-OutEdgesIterator::OutEdgesIterator(const SuperGraph *sG,SelectionProxy *filter,node n):FactorIterator<edge>(sG,filter) {
+OutEdgesIterator::OutEdgesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter,node n):FactorIterator<edge>(sG,filter) {
   assert(_selectionProxy->getNodeValue(n)==true);
   it=_parentGraph->getOutEdges(n);
   _hasnext=false;
   if (it->hasNext()){
     curEdge=it->next();
-    while (_selectionProxy->getEdgeValue(curEdge)!=true) {
+    while (_selectionProxy.get(curEdge.id)!=true) {
       if (!it->hasNext()) break;
       curEdge=it->next();
     }
-    if (_selectionProxy->getEdgeValue(curEdge))	_hasnext=true;
+    if (_selectionProxy.get(curEdge.id))	_hasnext=true;
   }
 }
 OutEdgesIterator::~OutEdgesIterator() {
@@ -137,11 +137,11 @@ edge OutEdgesIterator::next() {
   _hasnext=false;
   if (it->hasNext()) {
       curEdge=it->next();
-      while (_selectionProxy->getEdgeValue(curEdge)!=true) {
+      while (_selectionProxy.get(curEdge.id)!=true) {
 	  if (!it->hasNext()) break;
 	  curEdge=it->next();
 	}
-      if (_selectionProxy->getEdgeValue(curEdge))
+      if (_selectionProxy.get(curEdge.id))
 	_hasnext=true;
     }
   return tmp;
@@ -150,17 +150,17 @@ bool OutEdgesIterator::hasNext() {
   return (_hasnext);
 }
 //===================================================================
-InEdgesIterator::InEdgesIterator(const SuperGraph *sG,SelectionProxy *filter,node n):FactorIterator<edge>(sG,filter){
+InEdgesIterator::InEdgesIterator(const SuperGraph *sG, const MutableContainer<bool>& filter, node n):FactorIterator<edge>(sG,filter){
   assert(_selectionProxy->getNodeValue(n)==true);
   it=_parentGraph->getInEdges(n);
   _hasnext=false;
   if (it->hasNext()){
     curEdge=it->next();
-    while (_selectionProxy->getEdgeValue(curEdge)!=true){
+    while (_selectionProxy.get(curEdge.id)!=true){
       if (!it->hasNext()) break;
       curEdge=it->next();
     }
-    if (_selectionProxy->getEdgeValue(curEdge)) _hasnext=true;
+    if (_selectionProxy.get(curEdge.id)) _hasnext=true;
   }
 }
 InEdgesIterator::~InEdgesIterator() {
@@ -171,11 +171,11 @@ edge InEdgesIterator::next() {
   _hasnext=false;
   if (it->hasNext()) {
     curEdge=it->next();
-    while (_selectionProxy->getEdgeValue(curEdge)!=true) {
+    while (_selectionProxy.get(curEdge.id)!=true) {
       if (!it->hasNext()) break;
       curEdge=it->next();
     }
-    if (_selectionProxy->getEdgeValue(curEdge)) _hasnext=true;
+    if (_selectionProxy.get(curEdge.id)) _hasnext=true;
   }  
   return tmp;
 }
@@ -183,17 +183,17 @@ bool InEdgesIterator::hasNext() {
   return (_hasnext);
 }
 //===================================================================
-InOutEdgesIterator::InOutEdgesIterator(const SuperGraph *sG,SelectionProxy *filter,node n):FactorIterator<edge>(sG,filter){
+InOutEdgesIterator::InOutEdgesIterator(const SuperGraph *sG,const MutableContainer<bool>& filter, node n):FactorIterator<edge>(sG,filter){
   assert(_selectionProxy->getNodeValue(n)==true);
   it=_parentGraph->getInOutEdges(n);
   _hasnext=false;
   if (it->hasNext()) {
     curEdge=it->next();
-    while (_selectionProxy->getEdgeValue(curEdge)!=true) {
+    while (_selectionProxy.get(curEdge.id)!=true) {
       if (!it->hasNext()) break;
       curEdge=it->next();
     }
-    if (_selectionProxy->getEdgeValue(curEdge)) _hasnext=true;
+    if (_selectionProxy.get(curEdge.id)) _hasnext=true;
   }
 }
 InOutEdgesIterator::~InOutEdgesIterator() {
@@ -204,11 +204,11 @@ edge InOutEdgesIterator::next() {
   _hasnext=false;
   if (it->hasNext()) {
     curEdge=it->next();
-    while (_selectionProxy->getEdgeValue(curEdge)!=true) {
+    while (_selectionProxy.get(curEdge.id)!=true) {
       if (!it->hasNext()) break;
       curEdge=it->next();
     }
-    if (_selectionProxy->getEdgeValue(curEdge)) _hasnext=true;
+    if (_selectionProxy.get(curEdge.id)) _hasnext=true;
   }
   return tmp;
 }
@@ -292,10 +292,25 @@ xOutEdgesIterator::xOutEdgesIterator(const SuperGraph *sG,const node n):
   n(n), spG((SuperGraphImpl *)sG) {
   if (it!=itEnd) {
     curEdge=*it;
-    while (spG->edges[curEdge.id].first!=n) {
-      ++it;
+    while(1) {
+      while (spG->edges[curEdge.id].first!=n) {
+	++it;
+	if (it==itEnd) break;
+	curEdge=*it;
+      }
       if (it==itEnd) break;
-      curEdge=*it;
+      if (spG->edges[curEdge.id].second == n) {
+	if (loop.find(curEdge)==loop.end()) {
+	  loop.insert(curEdge);
+	  break;
+	}
+	else {
+	  ++it;
+	  if (it==itEnd) break;
+	  curEdge=*it;
+	}
+      }
+      else break;
     }
   }
 }
@@ -307,10 +322,25 @@ edge xOutEdgesIterator::next() {
   ++it;
   if (it!=itEnd) {
     curEdge=*it;
-    while (spG->edges[curEdge.id].first!=n) {
-      ++it;
+    while(1) {
+      while (spG->edges[curEdge.id].first!=n) {
+	++it;
+	if (it==itEnd) break;
+	curEdge=*it;
+      }
       if (it==itEnd) break;
-      curEdge=*it;
+      if (spG->edges[curEdge.id].second == n) {
+	if (loop.find(curEdge)==loop.end()) {
+	  loop.insert(curEdge);
+	  break;
+	}
+	else {
+	  ++it;
+	  if (it==itEnd) break;
+	  curEdge=*it;
+	}
+      }
+      else break;
     }
   }
   return tmp;
@@ -325,10 +355,25 @@ xInEdgesIterator::xInEdgesIterator(const SuperGraph *sG,const node n):
   n(n), spG((SuperGraphImpl *)sG) {
   if (it!=itEnd) {
     curEdge=*it;
-    while (spG->edges[curEdge.id].second!=n) {
-      ++it;
+    while(1) {
+      while (spG->edges[curEdge.id].second!=n) {
+	++it;
+	if (it==itEnd) break;
+	curEdge=*it;
+      }
       if (it==itEnd) break;
-      curEdge=*it;
+      if (spG->edges[curEdge.id].first == n) {
+	if (loop.find(curEdge) == loop.end()) {
+	  loop.insert(curEdge);
+	  ++it;
+	  if (it == itEnd) break;
+	  curEdge = *it;
+	}
+	else {
+	  break;
+	}
+      }
+      else break;
     }
   }
 }
@@ -340,10 +385,25 @@ edge xInEdgesIterator::next() {
   ++it;
   if (it!=itEnd) {
     curEdge=*it;
-    while (spG->edges[curEdge.id].second!=n) {
-      ++it;
+    while(1) {
+      while (spG->edges[curEdge.id].second!=n) {
+	++it;
+	if (it==itEnd) break;
+	curEdge=*it;
+      }
       if (it==itEnd) break;
-      curEdge=*it;
+      if (spG->edges[curEdge.id].first == n) {
+	if (loop.find(curEdge)==loop.end()) {
+	  loop.insert(curEdge);
+	  ++it;
+	  if (it==itEnd) break;
+	  curEdge=*it;
+	}
+	else {
+	  break;
+	}
+      }
+      else break;
     }
   }
   return tmp;
