@@ -15,7 +15,11 @@ Iterator<node> *getIt(SuperGraph *graph, node n, int direction) {
     return graph->getInNodes(n);
   case 2:
     return graph->getInOutNodes(n);
+  default:
+    cerr << __PRETTY_FUNCTION__ << "serious bug...";
+    return 0;
   }
+  return NULL;
 }
 Iterator<node> *getAncIt(SuperGraph *graph, node n, int direction) {
   switch(direction) {
@@ -25,7 +29,11 @@ Iterator<node> *getAncIt(SuperGraph *graph, node n, int direction) {
     return graph->getInNodes(n);
   case 2:
     return graph->getInOutNodes(n);
+  default:
+    cerr << __PRETTY_FUNCTION__ << "serious bug...";
+    return 0;
   }
+  return NULL;
 }
 
 unsigned int tlp::maxDistance(SuperGraph *graph, node n, MutableContainer<unsigned int> &distance, int direction) {
