@@ -1,10 +1,6 @@
 //-*-c++-*-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include "tulip/Layout.h"
-#include "tulip/TemplateFactory.h"
 #include "tulip/SuperGraph.h"
 #include "tulip/PluginContext.h"
 #include "tulip/LayoutProxy.h"
