@@ -7,7 +7,6 @@
 #include "tulip/SuperGraph.h"
 #include "tulip/MetaGraphProxy.h"
 
-MetaGraph::MetaGraph (PropertyContext *context):Property<MetaGraphType , MetaGraphType>(context)
-{
-  metaGraphProxy=(MetaGraphProxy *)propertyProxy;
+MetaGraph::MetaGraph (const PropertyContext &context):Property<MetaGraphType , MetaGraphType>(context) {
+  metaGraphProxy=(MetaGraphProxy *)context.propertyProxy;
 }
