@@ -1,8 +1,4 @@
 //-*-c++-*-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "tulip/Metric.h"
 #include "tulip/SuperGraph.h"
 #include "tulip/MetricProxy.h"
