@@ -1,7 +1,3 @@
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <cassert>
 #include <iostream>
 #include "tulip/Observable.h"
@@ -9,13 +5,19 @@
 
 using namespace std;
 
+#ifdef _WIN32 
+#ifdef DLL_EXPORT
 int Observable::holdCounter=0;
-
 ObserverMap Observable::holdMap;
+#endif
+#else
+int Observable::holdCounter=0;
+ObserverMap Observable::holdMap;
+#endif
+
 static bool unholdLock=false;
 
-void Observable::notifyObservers()
-{
+void Observable::notifyObservers() {
   if (unholdLock) {
     cerr << "Cannot notifyObservers during unholdings" << endl;
     return;
@@ -26,25 +28,22 @@ void Observable::notifyObservers()
   if (holdCounter)
     for (itlObs=observersList.begin();itlObs!=observersList.end();++itlObs)
       holdMap[*itlObs].insert(this);
-  else
-    {
-      set<Observable *> tmpSet;
-      std::list<Observer*> tmpList(observersList);
-      tmpSet.insert(this);
-      for (itlObs=tmpList.begin();itlObs!=tmpList.end();++itlObs)
-	(*itlObs)->update(tmpSet.begin(),tmpSet.end());
-    }
+  else {
+    set<Observable *> tmpSet;
+    std::list<Observer*> tmpList(observersList);
+    tmpSet.insert(this);
+    for (itlObs=tmpList.begin();itlObs!=tmpList.end();++itlObs)
+      (*itlObs)->update(tmpSet.begin(),tmpSet.end());
+  }
 }
 
-void Observable::holdObservers()
-{
+void Observable::holdObservers() {
   //  cerr << __PRETTY_FUNCTION__ << " :=> " << holdCounter << endl;
   assert(holdCounter>=0);
   holdCounter++;
 }
 
-void Observable::unholdObservers()
-{
+void Observable::unholdObservers() {
   assert(holdCounter>=0);
   //  cerr << __PRETTY_FUNCTION__ << " :=> " << holdCounter << endl;
   holdCounter--;
@@ -60,14 +59,3 @@ void Observable::unholdObservers()
   }
   unholdLock=false;
 }
-
-
-
-
-
-
-
-
-
-
-
