@@ -1,7 +1,4 @@
 //-*-c++-*-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include <float.h>
 #include "tulip/SizesProxy.h"
@@ -15,18 +12,36 @@ using namespace std;
 
 //==============================
 SizesProxy::SizesProxy (SuperGraph *graph):
-  PropertyProxy<SizeType,SizeType>(graph) {
-  //  propertyProxy=this;
+  PropertyProxy<SizeType,SizeType, Sizes>(graph) {
 }
 //==============================
 SizesProxy::~SizesProxy() {
 }    
 //====================================================================
 void SizesProxy::reset_handler() {
+  resetMinMax();
 }
 //=============================================================================
-void SizesProxy::recompute_handler() {
-  //  superGraph->getPropertyManager()->currentPropertyProxy=this;
+void SizesProxy::scale( const tlp::Vector<float,3>& v, SuperGraph *graph ) {
+  if (graph==0) graph = superGraph;
+  if (graph->numberOfNodes()==0) return;
+  Observable::holdObservers();
+  Iterator<node> *itN = graph->getNodes();
+  while (itN->hasNext()) {
+    node itn = itN->next();
+    Size tmpSize(getNodeValue(itn));
+    tmpSize *= v;
+    setNodeValue(itn,tmpSize);
+  } delete itN;
+  Iterator<edge> *itE = graph->getEdges();
+  while (itE->hasNext()) {
+    edge ite=itE->next();
+    Size tmpSize(getEdgeValue(ite));
+    tmpSize *= v;
+    setEdgeValue(ite,tmpSize);
+  } delete itE;
+  resetMinMax();
+  Observable::unholdObservers();
 }
 //=============================================================================
 Size SizesProxy::getMax(SuperGraph *sg) {
@@ -46,13 +61,8 @@ Size  SizesProxy::getMin(SuperGraph *sg) {
 }
 //=============================================================================
 void SizesProxy::computeMinMax(SuperGraph *sg) {
-#ifndef NDEBUG
-  cerr << "SizeqProxy::computeMinMax begin" << endl;
-#endif
-
   Size tmpSize;
   Size maxS,minS;
-
   Iterator<node> *itN=sg->getNodes();
   if  (itN->hasNext()) {
     node itn=itN->next();
@@ -66,24 +76,20 @@ void SizesProxy::computeMinMax(SuperGraph *sg) {
     node itn=itN->next();
     tmpSize=getNodeValue(itn);
     for (int i=0;i<3;++i) {
-      maxS[i]=maxS[i]>?tmpSize[i];
-      minS[i]=minS[i]<?tmpSize[i];
+      maxS[i] >?= tmpSize[i];
+      minS[i] <?= tmpSize[i];
     }
   }delete itN;
-
-  if (sg==0) sg=superGraph;
   int sgi=(int)sg;
-
   minMaxOk[sgi]=true;  
   min[sgi]=minS;
   max[sgi]=maxS;
-  //  cerr << "SizesProxy::computeMinMax end" << endl;
 }
 //=============================================================================
 void SizesProxy::resetMinMax() {
-  stdext::hash_map<int,bool>::iterator it;
-  for (it=minMaxOk.begin();it!=minMaxOk.end();++it)
-    it->second=false;
+  minMaxOk.clear();
+  min.clear();
+  max.clear();
 }
 //=============================================================================
 void SizesProxy::setNodeValue_handler(const node n){resetMinMax();}
@@ -94,34 +100,28 @@ void SizesProxy::setAllNodeValue_handler(){resetMinMax();}
 //=============================================================================
 void SizesProxy::setAllEdgeValue_handler(){resetMinMax();}
 //=============================================================================
-
-//=================================================================================
-PProxy* SizesProxy::clonePrototype(SuperGraph * g, std::string n)
-{
-	if( !g )
-		return 0;
-	SizesProxy * p = g->getLocalProperty<SizesProxy>( n );
-	p->setAllNodeValue( getNodeDefaultValue() );
-	p->setAllEdgeValue( getEdgeDefaultValue() );
-	return p;
+PProxy* SizesProxy::clonePrototype(SuperGraph * g, std::string n) {
+  if( !g )
+    return 0;
+  SizesProxy * p = g->getLocalProperty<SizesProxy>( n );
+  p->setAllNodeValue( getNodeDefaultValue() );
+  p->setAllEdgeValue( getEdgeDefaultValue() );
+  return p;
 }
 //=============================================================
-void SizesProxy::copy( const node n0, const node n1, PProxy * p )
-{
-	if( !p )
-		return;
-	SizesProxy * tp = dynamic_cast<SizesProxy*>(p);
-	assert( tp );
-	setNodeValue( n0, tp->getNodeValue(n1) );
+void SizesProxy::copy( const node n0, const node n1, PProxy * p ) {
+  if( !p )
+    return;
+  SizesProxy * tp = dynamic_cast<SizesProxy*>(p);
+  assert( tp );
+  setNodeValue( n0, tp->getNodeValue(n1) );
 }
 //=============================================================
-void SizesProxy::copy( const edge e0, const edge e1, PProxy * p )
-{
-	if( !p )
-		return;
-	SizesProxy * tp = dynamic_cast<SizesProxy*>(p);
-	assert( tp );
-	setEdgeValue( e0, tp->getEdgeValue(e1) );
+void SizesProxy::copy( const edge e0, const edge e1, PProxy * p ) {
+  if( !p )
+    return;
+  SizesProxy * tp = dynamic_cast<SizesProxy*>(p);
+  assert( tp );
+  setEdgeValue( e0, tp->getEdgeValue(e1) );
 }
-
-
+//=============================================================
