@@ -1,7 +1,4 @@
 //-*-c++-*-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include "tulip/String.h"
 #include "tulip/SuperGraph.h"
