@@ -1,7 +1,4 @@
 //-*-c++-*-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include "tulip/MethodFactory.h"
 #include "tulip/StringProxy.h"
@@ -12,7 +9,7 @@
 
 using namespace std;
 
-StringProxy::StringProxy (SuperGraph *graph):PropertyProxy<StringType,StringType>(graph) {
+StringProxy::StringProxy (SuperGraph *graph):PropertyProxy<StringType,StringType, String>(graph) {
   //  propertyProxy=this;
 }
   
