@@ -20,9 +20,67 @@
 
 using namespace std;
 
+/* 
+ * function to test if an edge e exist in the adjacency of a node
+ */
+bool existEdgeE(SuperGraph *g, const node n1, const node n2, edge e) {
+  Iterator<edge> *it = g->getOutEdges(n1);
+  while (it->hasNext()) {
+    edge e1(it->next());
+    if (e == e1) {
+      delete it;
+      return true;
+    }
+  } delete it;
+  return false;
+}
+/* 
+ * function to test the integrity of the graph structure
+ */
+bool integrityTest(SuperGraph *graph) {
+  Iterator<edge> *itE = graph->getEdges();
+  set<edge> edgesTest;
+  while(itE->hasNext()) {
+    edge e = itE->next();
+    edgesTest.insert(e);
+    if (!existEdgeE(graph, graph->source(e), graph->target(e), e)) {
+      cerr << "edge do not exist in neighbood" << endl;
+      delete itE;
+      return false;
+    }
+  }
+  delete itE;
+  Iterator<node> *itN = graph->getNodes();
+  while(itN->hasNext()) {
+    node n(itN->next());
+    unsigned int degree = 0;
+    Iterator<edge> *it = graph->getInOutEdges(n);
+    while (it->hasNext()) {
+      edge e = it->next();
+      bool found = edgesTest.find(e)!=edgesTest.end();
+      if (graph->isElement(e)!=found) {
+	cerr << "isElment function not valid" << endl;
+	delete it;
+	delete itN;
+	return false;
+      }
+      if (!graph->isElement(e)) {
+	cerr << "Adjacency edges are not valid" << endl;
+	delete it;
+	delete itN;
+	return false;
+      }
+      degree++;
+    } delete it;
+    if (graph->deg(n) != degree) {
+      cerr << "degree failed" << endl;
+      return false;
+    }
+  }delete itN;
+  return true;
+}
 //----------------------------------------------------------------
 SuperGraphImpl::SuperGraphImpl():SuperGraphAbstract(this) {
-  _superGraph=this;
   nbNodes=0;
   nbEdges=0;
   outDegree.setAll(0);
@@ -30,30 +88,33 @@ SuperGraphImpl::SuperGraphImpl():SuperGraphAbstract(this) {
 //----------------------------------------------------------------
 SuperGraphImpl::~SuperGraphImpl() {
   notifyDestroy(this);
-#ifndef NDEBUG
-  cerr << "SuperGraphImpl::~SuperGraphImpl delete proxyContainer" << endl;
-#endif
-#ifndef NDEBUG
-  cerr << "SuperGraphImpl::~SuperGraphImpl Ok..." << endl;
-#endif
+  removeObservers();
   for (Nodes::iterator i=nodes.begin();i!=nodes.end();++i) {
     i->deallocateAll();
   }
 }
+void SuperGraphImpl::clear() {
+  SuperGraphAbstract::clear();
+  nbNodes=0;
+  nbEdges=0;
+  outDegree.setAll(0);
+}
 //----------------------------------------------------------------
-bool SuperGraphImpl::isElement(const node n) 
-{return !nodeIds.is_free(n.id);}
+bool SuperGraphImpl::isElement(const node n) {
+  return !nodeIds.is_free(n.id);
+}
 //----------------------------------------------------------------
-bool SuperGraphImpl::isElement(const edge e) {return !edgeIds.is_free(e.id);}
+bool SuperGraphImpl::isElement(const edge e) {
+  return !edgeIds.is_free(e.id);
+}
 //----------------------------------------------------------------
 node SuperGraphImpl::addNode() {
   node newNode(nodeIds.get());
-  outDegree.set(newNode.id,0);
+  outDegree.set(newNode.id, 0);
   while (nodes.size()<=newNode.id){
     nodes.push_back(EdgeContainer());
   }
   assert(nodes[newNode.id].empty());
-  assert(nodes[newNode.id].empty());
   nbNodes++;
   notifyAddNode(this,newNode);
   return newNode;
@@ -68,12 +129,12 @@ void SuperGraphImpl::addNode(const node n) {
 edge SuperGraphImpl::addEdge(const node s,const node t) {
   assert(isElement(s) && isElement(t));
   pair< node , node > tmp(s,t);
-  outDegree.set(s.id,1+outDegree.get(s.id));
+  outDegree.set(s.id, outDegree.get(s.id) + 1);
   edge newEdge(edgeIds.get());
   while (edges.size()<=newEdge.id){
     edges.push_back(tmp);
   }
-  edges[newEdge.id]=tmp;
+  edges[newEdge.id] = tmp;
   nodes[s.id].push_back(newEdge);
   nodes[t.id].push_back(newEdge);
   nbEdges++;
@@ -91,32 +152,40 @@ void SuperGraphImpl::delNode(const node n) {
   //Warning, the current implementation doesn't manage the 
   //updating of properties for upper_subgraph in the case of 
   //Super Graph Implementation
+  notifyDelNode(this, n);
   externRemove(n);
-  for(EdgeContainer::iterator i=nodes[n.id].begin();i!=nodes[n.id].end();++i) {
-    externRemove(*i);
-    node s=opposite(*i,n);
-    removeEdge(nodes[s.id],*i);
-    if (s==edges[(*i).id].first)
-      outDegree.set(s.id,outDegree.get(s.id)-1);
+  unsigned int loopcount = 0;
+  for(EdgeContainer::iterator i=nodes[n.id].begin(); i!=nodes[n.id].end(); ++i) {
     notifyDelEdge(this,*i);
+    externRemove(*i); //del in all subgraph/properties and free the id
+    node s = opposite(*i, n);
+    if (s!=n) {
+      removeEdge(nodes[s.id], *i);
+      if (s == edges[(*i).id].first)
+	outDegree.set(s.id,outDegree.get(s.id)-1);
+    }
+    else {
+      loopcount++;
+    }
   }
+  nbEdges += loopcount / 2;
   nodes[n.id].clear();
-  notifyDelNode(this,n);
-  //  cout << "Nodes ID" << endl << nodeIds << endl;
-  //  nodes.erase(n);
 }
 //----------------------------------------------------------------
 void SuperGraphImpl::delEdge(const edge e) {
+  notifyDelEdge(this,e);
+  assert(existEdgeE(this, source(e),target(e), e));
+  if (!isElement(e)) {
+    return;
+  }
   //Warning, the current implementation doesn't manage the updating of 
   //properties for upper_subgraph in the case of Super Graph Implementation
+  node s = source(e);
+  node t = target(e);
+  outDegree.set(s.id, outDegree.get(s.id)-1);
   externRemove(e);
-  node s=edges[e.id].first;
-  node t=edges[e.id].second;
-  outDegree.set(s.id,outDegree.get(s.id)-1);
-  removeEdge(nodes[s.id],e);
-  removeEdge(nodes[t.id],e);
-  notifyDelEdge(this,e);
-  //cout << "Edges ID" << endl << edgeIds << endl;
+  removeEdge(nodes[s.id], e);
+  removeEdge(nodes[t.id], e);
 }
 //----------------------------------------------------------------
 void SuperGraphImpl::delAllNode(const node n){delNode(n);}
@@ -126,29 +195,20 @@ void SuperGraphImpl::delAllEdge(const edge e){delEdge(e);}
 void SuperGraphImpl::setEdgeOrder(const node n,const vector<edge> &v ) {
   //  cerr << __PRETTY_FUNCTION__ << "not tested function" << endl;
   if (v.size()==0) return;
-
-  MutableContainer<unsigned int> elements;
-  elements.setAll(0);
+  MutableContainer<int> isEle;
+  isEle.setAll(0); 
   for (vector<edge>::const_iterator it=v.begin();it!=v.end();++it) {
-    elements.set(it->id,elements.get(it->id)+1);
+    isEle.set(it->id, isEle.get(it->id)+1);
   }
-
-  vector<edge> tmp;
-  EdgeContainer adjacency=nodes[n.id];
-  for (unsigned int i=0;i<v.size();++i) {
-    if (elements.get(adjacency[i].id)>0) {
-      elements.set(adjacency[i].id,elements.get(adjacency[i].id)-1);
-    } else {
-      tmp.push_back(adjacency[i]);
+  vector<edge>::const_iterator it2=v.begin();
+  EdgeContainer currentOrder = nodes[n.id];
+  for (unsigned int i=0; i<currentOrder.size(); ++i) {
+    if ( isEle.get(currentOrder[i].id)>0 ) {
+      isEle.set(currentOrder[i].id, isEle.get(currentOrder[i].id) -1);
+      currentOrder[i] = *it2;
+      ++it2;
     }
-    adjacency[i]=v[i];
   }
-
-  unsigned int i=v.size();
-  for (vector<edge>::const_iterator it=tmp.begin();it!=tmp.end();++it,++i) {
-    adjacency[i]=*it;
-  }
-  
 }
 //----------------------------------------------------------------
 void SuperGraphImpl::swapEdgeOrder(const node n,const edge e1 , const edge e2) {
@@ -202,11 +262,12 @@ node SuperGraphImpl::target(const edge e)const{return edges[e.id].second;}
 //----------------------------------------------------------------
 void SuperGraphImpl::reverse(const edge e) {
   assert(isElement(e));
-  node s=edges[e.id].first;
-  edges[e.id].first=edges[e.id].second;
-  edges[e.id].second=s;
-  outDegree.set(s.id,outDegree.get(s.id)-1);
-  outDegree.set(edges[e.id].first.id,outDegree.get(edges[e.id].first.id)+1);
+  node src = edges[e.id].first;
+  node tgt = edges[e.id].second;
+  edges[e.id].first  = tgt;
+  edges[e.id].second = src;
+  outDegree.set(src.id, outDegree.get(src.id) - 1);
+  outDegree.set(tgt.id, outDegree.get(tgt.id) + 1);
   notifyReverseEdge(this,e);
 }
 //----------------------------------------------------------------
@@ -215,19 +276,27 @@ unsigned int SuperGraphImpl::numberOfEdges()const{return nbEdges;}
 unsigned int SuperGraphImpl::numberOfNodes()const{return nbNodes;}
 //----------------------------------------------------------------
 void SuperGraphImpl::removeEdge(EdgeContainer &c, const edge e) {
-  edge e1=c.back();
+  bool copy = false;
+  EdgeContainer::iterator previous;
+  for (EdgeContainer::iterator i=c.begin(); i!=c.end(); ++i) {
+    edge e1 = *i;
+    if (copy)
+      *previous = e1;
+    previous = i;
+    if (e1 == e)  
+      copy = true;
+  }
   c.pop_back();
-  if (e!=e1)
-    for (EdgeContainer::iterator i=c.begin();i!=c.end();++i)
-      if (*i==e) { *i=e1; break; }
 }
 //----------------------------------------------------------------
 void SuperGraphImpl::externRemove(const edge e) {
   assert(isElement(e));
   Iterator<SuperGraph *>*itS=getSubGraphs();
-  while (itS->hasNext())
-    itS->next()->delEdge(e);
-  delete itS;
+  while (itS->hasNext()) {
+    SuperGraph *subgraph = itS->next();
+    assert(subgraph != this);
+    subgraph->delEdge(e);
+  } delete itS;
   getPropertyManager()->erase(e);
   edgeIds.free(e.id);
   nbEdges--;
@@ -236,9 +305,11 @@ void SuperGraphImpl::externRemove(const edge e) {
 void SuperGraphImpl::externRemove(const node n) {
   assert(isElement(n));
   Iterator<SuperGraph *>*itS=getSubGraphs();
-  while (itS->hasNext())
-    itS->next()->delNode(n);
-  delete itS;
+  while (itS->hasNext()) {
+    SuperGraph *subgraph = itS->next();
+    assert(subgraph != this);
+    subgraph->delNode(n);
+  } delete itS;
   getPropertyManager()->erase(n);
   nodeIds.free(n.id);
   nbNodes--;
