@@ -23,54 +23,101 @@ using namespace std;
 //----------------------------------------------------------------
 SuperGraphView::SuperGraphView(SuperGraph *father,SelectionProxy *filter):
   SuperGraphAbstract(father),
-  _superGraph(father->getRoot()),
   nNodes(0),
-  nEdges(0)
-{
-  adaptativeFilter =new SelectionProxy(this);
-  adaptativeFilter->setAllNodeValue(false);
-  adaptativeFilter->setAllEdgeValue(false);
-  Iterator<node> *iteN=getFather()->getNodes();
+  nEdges(0) {
+  nodeAdaptativeFilter.setAll(false);
+  edgeAdaptativeFilter.setAll(false);
+  //  inDegree.setAll(0);
+  //  outDegree.setAll(0);
+  if (filter == 0) return;
+  Iterator<unsigned int> *it=0;
+  try {
+    it = filter->nodeProperties.findAll(true);
+  } catch (ImpossibleOperation &e) {
+    it=0;
+  }
+  Iterator<node> *iteN;
+  if (it==0)
+    iteN =getFather()->getNodes();
+  else
+    iteN = new UINTIterator<node>(it);
+  
   while (iteN->hasNext()) {
     node n=iteN->next();
     if (filter->getNodeValue(n)) addNode(n);
   } delete iteN;
-  Iterator<edge> *iteE=getFather()->getEdges();
+
+  try {
+    it = filter->edgeProperties.findAll(true);
+  } catch (ImpossibleOperation &e) {
+    it=0;
+  }
+  Iterator<edge> *iteE;
+  if (it==0)
+    iteE = getFather()->getEdges();
+  else
+    iteE = new UINTIterator<edge>(it);
+
   while (iteE->hasNext()) {
     edge e=iteE->next();
     if (filter->getEdgeValue(e)) addEdge(e);
   } delete iteE;
 }
-
 //----------------------------------------------------------------
 SuperGraphView::~SuperGraphView() {
   notifyDestroy(this);
-  //  cerr << "SuperGraphView::~SuperGraphView" << endl;
-  delete adaptativeFilter;
-  //  cerr << "SuperGraphView::~SuperGraphView Ok......" << endl;
 }
 //----------------------------------------------------------------
 bool SuperGraphView::isElement(const node n) 
-{return adaptativeFilter->getNodeValue(n);}
+{return nodeAdaptativeFilter.get(n.id);}
 //----------------------------------------------------------------
-bool SuperGraphView::isElement(const edge e) 
-{return adaptativeFilter->getEdgeValue(e);}
+bool SuperGraphView::isElement(const edge e)  {
+  return edgeAdaptativeFilter.get(e.id);
+}
+//----------------------------------------------------------------
+//unsigned int SuperGraphView::deg(const node n) const {
+//  return inDegree.get(n.id)+outDegree.get(n.id);
+//}
+//----------------------------------------------------------------
+//unsigned int SuperGraphView::indeg(const node n) const {
+//  return inDegree.get(n.id);
+//}
+//----------------------------------------------------------------
+//unsigned int SuperGraphView::outdeg(const node n) const {
+//  return outDegree.get(n.id);
+//}
+//----------------------------------------------------------------
+/*
+  void SuperGraphView::reverse(const edge e) {
+  notifyReverseEdge(this,e);
+  node src = source(e);
+  node tgt = target(e);
+  outDegree.set(src.id, outDegree.get(src.id)-1);
+  inDegree.set(tgt.id, inDegree.get(tgt.id)-1);
+  inDegree.set(src.id, inDegree.get(src.id)+1);
+  outDegree.set(tgt.id, outDegree.get(tgt.id)+1);
+  getFather()->reverse(e);
+  }
+*/
 //----------------------------------------------------------------
 node SuperGraphView::addNode() {
-  _superGraph=getFather();
-  node tmp=_superGraph->addNode();
-  adaptativeFilter->setNodeValue(tmp,true);
-  if (nNodes>0) nNodes++;
+  node tmp=getFather()->addNode();
+  nodeAdaptativeFilter.set(tmp.id,true);
+  ++nNodes;
+  //  inDegree.set(tmp.id,0);
+  //  outDegree.set(tmp.id,0);
   notifyAddNode(this, tmp);
   return tmp;
 }
 //----------------------------------------------------------------
 void SuperGraphView::addNode(const node n) {
+  assert(getRoot()->isElement(n));
   if (!isElement(n)) {
-    _superGraph=getFather();
-    if (!_superGraph->isElement(n)) _superGraph->addNode(n);
-    adaptativeFilter->setNodeValue(n,true);
-    if (nNodes>0) nNodes++;
+    if (!getFather()->isElement(n)) getFather()->addNode(n);
+    nodeAdaptativeFilter.set(n.id,true);
+    ++nNodes;
+    //    inDegree.set(n.id,0);
+    //    outDegree.set(n.id,0);
     notifyAddNode(this, n);
   }
 }
@@ -78,55 +125,56 @@ void SuperGraphView::addNode(const node n) {
 edge SuperGraphView::addEdge(const node n1,const node n2) {
   assert(isElement(n1));
   assert(isElement(n2));
-  _superGraph=getFather();
-  edge tmp=_superGraph->addEdge(n1,n2);
-  adaptativeFilter->setEdgeValue(tmp,true);
-  if (nEdges>0) nEdges++;
+  edge tmp = getFather()->addEdge(n1,n2);
+  edgeAdaptativeFilter.set(tmp.id,true);
+  ++nEdges;
+  //  outDegree.set(n1.id, outDegree.get(n1.id)+1);
+  //  inDegree.set(n2.id, inDegree.get(n2.id)+1);
   notifyAddEdge(this, tmp);
   return tmp;
 }
 //----------------------------------------------------------------
 void SuperGraphView::addEdge(const edge e) {
-  //  assert(!isElement(e));
-  if (!adaptativeFilter->getEdgeValue(e)) {
-    _superGraph=getFather();
-    if (!_superGraph->isElement(e)) _superGraph->addEdge(e);
-    adaptativeFilter->setEdgeValue(e,true);
-    if (nEdges>0) nEdges++;
+  assert(getRoot()->isElement(e));
+  assert(isElement(source(e)));
+  assert(isElement(target(e)));
+  if (!edgeAdaptativeFilter.get(e.id)) {
+    if (!getFather()->isElement(e)) getFather()->addEdge(e);
+    edgeAdaptativeFilter.set(e.id,true);
+    ++nEdges;
+    //    outDegree.set(source(e).id, outDegree.get(source(e).id)+1);
+    //    inDegree.set(target(e).id, inDegree.get(target(e).id)+1);
     notifyAddEdge(this, e);
   }
 }
 //----------------------------------------------------------------
 void SuperGraphView::delNode(const node n) {
   if (isElement(n)) {
-    Iterator<SuperGraph *>*itS=getSubGraphs();
-    for (;itS->hasNext();)
+    notifyDelNode(this, n);
+    Iterator<SuperGraph *>*itS = getSubGraphs();
+    while (itS->hasNext())
       itS->next()->delNode(n);
     delete itS;
-    set<edge> tmpSet;
-    Iterator<edge> *itE=getInOutEdges(n);
-    for (;itE->hasNext();) 
-      tmpSet.insert(itE->next());
-    delete itE;
-    for (set<edge>::const_iterator ite=tmpSet.begin();ite!=tmpSet.end();++ite)
-      delEdge(*ite);
-    adaptativeFilter->setNodeValue(n,false);
+    StableIterator<edge> itE(getInOutEdges(n));
+    while (itE.hasNext()) delEdge(itE.next());
+    nodeAdaptativeFilter.set(n.id,false);
     getPropertyManager()->erase(n);
-    if (nNodes>0) nNodes--;
-    notifyDelNode(this, n);
+    --nNodes;
   }
 }
 //----------------------------------------------------------------
 void SuperGraphView::delEdge(const edge e) {
   if (isElement(e)) {
+    notifyDelEdge(this,e);
     Iterator<SuperGraph *>*itS=getSubGraphs();
-    for (;itS->hasNext();)
+    while (itS->hasNext()) 
       itS->next()->delEdge(e);
     delete itS;
-    adaptativeFilter->setEdgeValue(e,false);
+    edgeAdaptativeFilter.set(e.id,false);
     getPropertyManager()->erase(e);
-    if (nEdges>0) nEdges--;
-    notifyDelEdge(this,e);
+    --nEdges;
+    //    outDegree.set(source(e).id, outDegree.get(source(e).id)-1);
+    //    inDegree.set(target(e).id, inDegree.get(target(e).id)-1);
   }
 }
 //----------------------------------------------------------------
@@ -149,58 +197,54 @@ void SuperGraphView::swapEdgeOrder(const node n,const edge e1 , const edge e2) {
 Iterator<node>* SuperGraphView::getNodes() const {
   Iterator<unsigned int> *it=0;
   try {
-    it=adaptativeFilter->nodeProperties.findAll(true);
+    it = nodeAdaptativeFilter.findAll(true);
   } catch (ImpossibleOperation &e) {
     it=0;
+    //    if (numberOfNodes()<getFather()->numberOfNodes() / 2)
+    //      cerr << "SuperGraphView : Optimization problem: " << numberOfNodes() << "/" << getFather()->numberOfNodes() << endl;
   }
   if (it==0)
-    return (new SGraphNodeIterator(this,adaptativeFilter));
+    return (new SGraphNodeIterator(this, nodeAdaptativeFilter));
   else
     return (new UINTIterator<node>(it));
 }
 //----------------------------------------------------------------
 Iterator<node>* SuperGraphView::getInNodes(const node n) const 
-{return (new InNodesIterator(this,adaptativeFilter,n));}
+{return (new InNodesIterator(this, edgeAdaptativeFilter,n));}
 //----------------------------------------------------------------
 Iterator<node>* SuperGraphView::getOutNodes(const node n)const 
-{return (new OutNodesIterator(this,adaptativeFilter,n));}
+{return (new OutNodesIterator(this, edgeAdaptativeFilter,n));}
 //----------------------------------------------------------------
 Iterator<node>* SuperGraphView::getInOutNodes(const node n)const 
-{return (new InOutNodesIterator(this,adaptativeFilter,n));}
+{return (new InOutNodesIterator(this, edgeAdaptativeFilter,n));}
 //----------------------------------------------------------------
 Iterator<edge>* SuperGraphView::getEdges()const {
   Iterator<unsigned int> *it=0;
   try {
-    it=adaptativeFilter->edgeProperties.findAll(true);
+    it = edgeAdaptativeFilter.findAll(true);
   } catch (ImpossibleOperation &e) {
     it=0;
   }
   if (it==0)
-    return (new SGraphEdgeIterator(this,adaptativeFilter));
+    return (new SGraphEdgeIterator(this, edgeAdaptativeFilter));
   else
     return (new UINTIterator<edge>(it));
 }
 //----------------------------------------------------------------
 Iterator<edge>* SuperGraphView::getInEdges(const node n)const 
-{return (new InEdgesIterator(this,adaptativeFilter,n));}
+{return (new InEdgesIterator(this, edgeAdaptativeFilter,n));}
 //----------------------------------------------------------------
 Iterator<edge>* SuperGraphView::getOutEdges(const node n)const 
-{return (new OutEdgesIterator(this,adaptativeFilter,n));}
+{return (new OutEdgesIterator(this, edgeAdaptativeFilter,n));}
 //----------------------------------------------------------------
 Iterator<edge>* SuperGraphView::getInOutEdges(const node n)const
-{return (new InOutEdgesIterator(this,adaptativeFilter,n));}
+{return (new InOutEdgesIterator(this, edgeAdaptativeFilter,n));}
 //----------------------------------------------------------------
 unsigned int SuperGraphView::numberOfNodes()const {
-  if (nNodes<=0) 
-    return (nNodes=this->SuperGraphAbstract::numberOfNodes());
-  else
-    return nNodes;
+  return nNodes;
 }
 //----------------------------------------------------------------
 unsigned int SuperGraphView::numberOfEdges() const {
-  if (nEdges<=0) 
-    return (nEdges=this->SuperGraphAbstract::numberOfEdges());
-  else
-    return nEdges;
+  return nEdges;
 }
 //----------------------------------------------------------------
