@@ -1,7 +1,3 @@
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <dirent.h>
 
 #include "thirdparty/gzstream/gzstream.h"
@@ -10,24 +6,25 @@
 #include "tulip/SuperGraphImpl.h"
 #include "tulip/Reflect.h"
 
+#include "tulip/PluginsCreation.h"
+
 using namespace std;
 
 #ifndef _TULIP_LIB_DIR
 #define _TULIP_LIB_DIR "/usr/local/lib/"
 #endif
 
-static const char PATH_DELIMITER=':';
 static const char *TULIP_PLUGINS_PATH_VARIABLE="TULIP_PLUGINS_PATH";
 
 string tlp::TulipLibDir;
 string tlp::TulipPluginsPath;
-
+const char tlp::PATH_DELIMITER = ':';
 //=========================================================
 void tlp::initTulipLib() {
   char *getEnvTlp;
   getEnvTlp=getenv("TLPDIR");
   if (getEnvTlp==0)
-    TulipLibDir=string(_TULIP_LIB_DIR);
+   	   TulipLibDir=string(_TULIP_LIB_DIR);
   else
     TulipLibDir=string(getEnvTlp);
   getEnvTlp=getenv(TULIP_PLUGINS_PATH_VARIABLE);
@@ -64,50 +61,19 @@ SuperGraph * tlp::newSuperGraph(){
   return new SuperGraphImpl();
 }
 //=========================================================
-SuperGraph * tlp::inducedSubGraph(SuperGraph *sg, const std::set<node> &setNode,string name) {
-  SelectionProxy *sel1 =sg->getLocalProperty<SelectionProxy>("sub graph build tmp");
-  sel1->setAllNodeValue(false);
-  sel1->setAllEdgeValue(false);
-  Iterator<node> *itN=sg->getNodes();
-  for (;itN->hasNext();) {
-    node itn=itN->next();
-    if (setNode.find(itn)!=setNode.end()) {
-      sel1->setNodeValue(itn,true);
-    }
-  }delete itN;
-  Iterator<edge> *itE=sg->getEdges();
-  for (;itE->hasNext();) {
-    edge ite=itE->next();
-    if (setNode.find(sg->source(ite))!=setNode.end() && setNode.find(sg->target(ite))!=setNode.end()) {
-      sel1->setEdgeValue(ite,true);
-    }
-  }delete itE;
-  SuperGraph * tmpSuperGraph;
-  tmpSuperGraph = sg->addSubGraph(sel1);
-  sg->delLocalProperty("sub graph build tmp");
-  return tmpSuperGraph;
-}
-//=========================================================
 SuperGraph * tlp::newSubGraph(SuperGraph *sg,string name) {
-  SelectionProxy *sel1 =sg->getLocalProperty<SelectionProxy>("sub graph build tmp");
-  sel1->setAllNodeValue(false);
-  sel1->setAllEdgeValue(false);
-  SuperGraph * tmpSuperGraph;
-  tmpSuperGraph = sg->addSubGraph(sel1);
-  sg->delLocalProperty("sub graph build tmp");
-  tmpSuperGraph->setAttribute("name",name);
-  cerr << "Subgraph name : " << tmpSuperGraph->getAttribute<string>("name");
-  return tmpSuperGraph;
+  SuperGraph *newGraph = sg->addSubGraph();
+  newGraph->setAttribute("name", name);
+  return newGraph;
 }
 //=========================================================
-SuperGraph * tlp::newCloneSubGraph(SuperGraph *sg,string name) {
-  SelectionProxy *sel1 =sg->getLocalProperty<SelectionProxy>("sub graph build tmp");
-  sel1->setAllNodeValue(true);
-  sel1->setAllEdgeValue(true);
-  SuperGraph * tmpSuperGraph;
-  tmpSuperGraph = sg->addSubGraph(sel1);
-  sg->delLocalProperty("sub graph build tmp");
-  return tmpSuperGraph;
+SuperGraph * tlp::newCloneSubGraph(SuperGraph *sg, string name) {
+  SelectionProxy sel1(sg);
+  sel1.setAllNodeValue(true);
+  sel1.setAllEdgeValue(true);
+  SuperGraph *newGraph = sg->addSubGraph(&sel1);
+  newGraph->setAttribute("name", name);
+  return newGraph;
 }
 //=========================================================
 SuperGraph * tlp::load(const string &filename) {
@@ -130,7 +96,6 @@ bool tlp::save(SuperGraph *graph, const string &filename) {
   return result;
 }
 //=========================================================
-//<<<<<<< TlpTools.cpp
 SuperGraph * tlp::importGraph(const string &alg, DataSet &dataSet, PluginProgress *plugProgress,SuperGraph *newSuperGraph){
 
   if (!tlp::importFactory.exists(alg)) {
@@ -150,7 +115,7 @@ SuperGraph * tlp::importGraph(const string &alg, DataSet &dataSet, PluginProgres
   PluginProgress *tmpProgress;
   bool deletePluginProgress=false;
   if (plugProgress==0) {
-    tmpProgress=new PluginProgressDefault();
+    tmpProgress=new PluginProgress();
     deletePluginProgress=true;
   }
   else tmpProgress=plugProgress;
@@ -170,9 +135,6 @@ SuperGraph * tlp::importGraph(const string &alg, DataSet &dataSet, PluginProgres
     return newSuperGraph;
 }
 //=========================================================
-//<<<<<<< TlpTools.cpp
-//bool TlpTools::exportGraph(SuperGraph *sg,ostream &os, const string &alg, DataSet &dataSet, PluginProgress *plugProgress) {
-//=======
 bool tlp::exportGraph(SuperGraph *sg,ostream &os, const string &alg,
                            DataSet &dataSet, PluginProgress *plugProgress) {
   if (!tlp::exportFactory.exists(alg)) {
@@ -188,7 +150,7 @@ bool tlp::exportGraph(SuperGraph *sg,ostream &os, const string &alg,
   tmp.dataSet=&dataSet;
   PluginProgress *tmpProgress=NULL;
   if (plugProgress==0) {
-    tmpProgress=new PluginProgressDefault();
+    tmpProgress=new PluginProgress();
     deletePluginProgress=true;
   }
   else tmpProgress=plugProgress;
@@ -202,8 +164,6 @@ bool tlp::exportGraph(SuperGraph *sg,ostream &os, const string &alg,
   return result;
 }
 //=========================================================
-//<<<<<<< TlpTools.cpp
-//=======
 bool tlp::clusterizeGraph(SuperGraph *sg,string &errorMsg,DataSet *dataSet,
                                const string &alg, PluginProgress *plugProgress) {
   if (!tlp::clusteringFactory.exists(alg)) {
@@ -219,7 +179,7 @@ bool tlp::clusterizeGraph(SuperGraph *sg,string &errorMsg,DataSet *dataSet,
   tmp.dataSet=dataSet;
   PluginProgress *tmpProgress;
   if (plugProgress==0) {
-    tmpProgress=new PluginProgressDefault();
+    tmpProgress=new PluginProgress();
     deletePluginProgress=true;
   }
   else tmpProgress=plugProgress;
@@ -231,7 +191,6 @@ bool tlp::clusterizeGraph(SuperGraph *sg,string &errorMsg,DataSet *dataSet,
   if (deletePluginProgress) delete tmpProgress;
   return result;
 }
-
 //=========================================================
 static void loadPlugins(string dir,PluginLoader *plug) {
   SizesProxy::factory.load(dir + "sizes", "Sizes",plug);
@@ -245,7 +204,7 @@ static void loadPlugins(string dir,PluginLoader *plug) {
   tlp::importFactory.load(dir + "import" , "Import Module",plug);
   tlp::exportFactory.load(dir + "export" , "Export Module",plug);
 }
-
+//=========================================================
 void tlp::loadPlugins(PluginLoader *plug) {
   string::const_iterator begin=TulipPluginsPath.begin();
   string::const_iterator end=begin;
@@ -260,7 +219,54 @@ void tlp::loadPlugins(PluginLoader *plug) {
   if (begin!=end) 
     loadPlugins(string(begin,end)+"/",plug);
 }
-
+//=========================================================
+void tlp::loadPlugin(const string & filename, PluginLoader *plug) {
+  func createObj = getCreationFunc(filename, plug);
+  if(createObj) {
+    Plugin *tmpObjectFactory = (Plugin *)createObj();
+    if(dynamic_cast< PropertyFactory<Selection>* >(tmpObjectFactory) != 0) {  
+      SelectionProxy::factory.createObj = createObj;
+      SelectionProxy::factory.getPluginParameters(plug);
+    }
+    else if(dynamic_cast< PropertyFactory<Layout>* >(tmpObjectFactory) != 0) {
+      LayoutProxy::factory.createObj = createObj;
+      LayoutProxy::factory.getPluginParameters(plug);
+    }
+    else if(dynamic_cast< PropertyFactory<Metric>* >(tmpObjectFactory) != 0) {
+      MetricProxy::factory.createObj = createObj;
+      MetricProxy::factory.getPluginParameters(plug);
+    }
+    else if(dynamic_cast< PropertyFactory<Colors>* >(tmpObjectFactory) != 0) {
+      ColorsProxy::factory.createObj = createObj;
+      ColorsProxy::factory.getPluginParameters(plug);
+    }
+    else if(dynamic_cast< PropertyFactory<Int>* >(tmpObjectFactory) != 0) {
+      IntProxy::factory.createObj = createObj;
+      IntProxy::factory.getPluginParameters(plug);
+    }
+    else if(dynamic_cast< PropertyFactory<String>* >(tmpObjectFactory) != 0) {
+      StringProxy::factory.createObj = createObj;
+      StringProxy::factory.getPluginParameters(plug);
+    }
+    else if(dynamic_cast< PropertyFactory<Sizes>* >(tmpObjectFactory) != 0) {
+      SizesProxy::factory.createObj = createObj;
+      SizesProxy::factory.getPluginParameters(plug);
+    }
+    else if(dynamic_cast< ClusteringFactory * >(tmpObjectFactory) != 0) {
+      clusteringFactory.createObj =createObj;
+      clusteringFactory.getPluginParameters(plug);
+    }
+    else if(dynamic_cast< ImportModuleFactory* >(tmpObjectFactory) != 0) {
+      importFactory.createObj = createObj;
+      importFactory.getPluginParameters(plug);
+    }
+    else if(dynamic_cast< ExportModuleFactory* >(tmpObjectFactory) != 0) {
+      exportFactory.createObj = createObj;
+      exportFactory.getPluginParameters(plug);
+    }
+  }
+}
+//=========================================================
 bool tlp::getSource(SuperGraph *superGraph, node &n) {
   Iterator<node> *it=superGraph->getNodes();
   while (it->hasNext()) {
@@ -273,152 +279,143 @@ bool tlp::getSource(SuperGraph *superGraph, node &n) {
   return false;
 }
 //=========================================================
+void tlp::removeFromGraph(SuperGraph *ioG, SelectionProxy *inSel) {
+  if( !ioG )
+    return;
 
+  vector<node>	nodeA;
+  vector<edge>	edgeA;
 
-void tlp::removeFromGraph(	SuperGraph *	ioG,
-							SelectionProxy*	inSel )
-{
-	if( !ioG )
-		return;
+  // Get edges
+  Iterator<edge> * edgeIt = ioG->getEdges();
+  while( edgeIt->hasNext() ) {
+    edge e = edgeIt->next();
+    if( !inSel || inSel->getEdgeValue(e) ) {
+      // selected edge -> remove it !
+      edgeA.push_back( e );
+    } else {
+      // unselected edge -> don't remove node ends !
+      node n0 = ioG->source( e );
+      node n1 = ioG->target( e );
+      assert( inSel );
+      inSel->setNodeValue( n0, false );
+      inSel->setNodeValue( n1, false );
+    }
+  }
+  delete edgeIt;
 
-	vector<node>	nodeA;
-	vector<edge>	edgeA;
+  // Get nodes
+  Iterator<node> * nodeIt = ioG->getNodes();
+  while( nodeIt->hasNext() ) {
+    node n = nodeIt->next();
+    if( !inSel || inSel->getNodeValue(n) )
+      nodeA.push_back( n );
+  }
+  delete nodeIt;
 
-	// Get edges
-	Iterator<edge> * edgeIt = ioG->getEdges();
-	while( edgeIt->hasNext() ) {
-		edge e = edgeIt->next();
-		if( !inSel || inSel->getEdgeValue(e) ) {
-			// selected edge -> remove it !
-			edgeA.push_back( e );
-		} else {
-			// unselected edge -> don't remove node ends !
-			node n0 = ioG->source( e );
-			node n1 = ioG->target( e );
-			assert( inSel );
-			inSel->setNodeValue( n0, false );
-			inSel->setNodeValue( n1, false );
-		}
-	}
-	delete edgeIt;
+  // Clean properties
+  Iterator<std::string> * propIt = ioG->getProperties();
+  while( propIt->hasNext() ) {
+    std::string n = propIt->next();
+    PProxy * p = ioG->getProperty( n );
+    for( unsigned int in = 0 ; in < nodeA.size() ; in++ )
+      p->erase( nodeA[in] );
+    for( unsigned int ie = 0 ; ie < edgeA.size() ; ie++ )
+      p->erase( edgeA[ie] );
+  }
+  delete propIt;
 
-	// Get nodes
-	Iterator<node> * nodeIt = ioG->getNodes();
-	while( nodeIt->hasNext() ) {
-		node n = nodeIt->next();
-		if( !inSel || inSel->getNodeValue(n) )
-			nodeA.push_back( n );
-	}
-	delete nodeIt;
+  // Remove edges
+  for( unsigned int ie = 0 ; ie < edgeA.size() ; ie++ )
+    ioG->delEdge( edgeA[ie] );
 
-	// Clean properties
-	Iterator<std::string> * propIt = ioG->getProperties();
+  // Remove nodes
+  for( unsigned int in = 0 ; in < nodeA.size() ; in++ )
+    ioG->delNode( nodeA[in] );
+}
+
+void tlp::copyToGraph (	SuperGraph *outG, SuperGraph *	inG, SelectionProxy *inSel, SelectionProxy* outSel) {
+  if( outSel ) {
+    outSel->setAllNodeValue( false );
+    outSel->setAllEdgeValue( false );
+  }
+
+  if( !outG || !inG )
+    return;
+
+  // extend the selection to edge ends
+  if( inSel ) {
+    Iterator<edge> * edgeIt = inG->getEdges();
+    while( edgeIt->hasNext() ) {
+      edge e = edgeIt->next();
+      if( inSel->getEdgeValue(e) ) {
+	node n0 = inG->source( e );
+	node n1 = inG->target( e );
+	inSel->setNodeValue( n0, true );
+	inSel->setNodeValue( n1, true );
+      }
+    }
+    delete edgeIt;
+  }
+	
+  // copy selected nodes
+  MutableContainer<node> nodeTrl;
+  {
+    Iterator<node> * nodeIt = inG->getNodes();
+    while( nodeIt->hasNext() ) {
+      node n0 = nodeIt->next();
+      if( !inSel || inSel->getNodeValue(n0) ) {
+	node n1 = outG->addNode();
+	      
+	// select appended node
+	if( outSel )
+	  outSel->setNodeValue( n1, true );
+	      
+	// add to translation tab
+	nodeTrl.set( n0.id, n1 );
+	      
+	// copy node properties
+	Iterator<std::string> * propIt = inG->getProperties();
 	while( propIt->hasNext() ) {
-		std::string n = propIt->next();
-		PProxy * p = ioG->getProperty( n );
-		for( uint in = 0 ; in < nodeA.size() ; in++ )
-			p->erase( nodeA[in] );
-		for( uint ie = 0 ; ie < edgeA.size() ; ie++ )
-			p->erase( edgeA[ie] );
+	  std::string n = propIt->next();
+	  PProxy * src = inG->getProperty( n );
+	  if(dynamic_cast<MetaGraphProxy *>(src) == 0) {
+	    PProxy *dst = outG->existProperty(n) ? outG->getProperty(n) : src->clonePrototype(outG,n);
+	    dst->copy( n1, n0, src );
+	  }
 	}
 	delete propIt;
-
-	// Remove edges
-	for( uint ie = 0 ; ie < edgeA.size() ; ie++ )
-		ioG->delEdge( edgeA[ie] );
-
-	// Remove nodes
-	for( uint in = 0 ; in < nodeA.size() ; in++ )
-		ioG->delNode( nodeA[in] );
+      }
+    }
+    delete nodeIt;
+  }
+	
+  // copy selected edges
+  {
+    Iterator<edge> * edgeIt = inG->getEdges();
+    while( edgeIt->hasNext() ) {
+      edge e0    = edgeIt->next();
+      if( !inSel || inSel->getEdgeValue(e0) ) {
+	node e0_n0 = inG->source(e0);
+	node e0_n1 = inG->target(e0);
+	edge e1 = outG->addEdge( nodeTrl.get(e0_n0.id),
+				 nodeTrl.get(e0_n1.id) );
+	      
+	// select appended edge
+	if( outSel )
+	  outSel->setEdgeValue( e1, true );
+	      
+	// copy edge properties
+	Iterator<std::string> * propIt = inG->getProperties();
+	while( propIt->hasNext() ) {
+	  std::string n = propIt->next();
+	  PProxy * src = inG->getProperty( n ),
+	    * dst = outG->existProperty(n) ? outG->getProperty(n) : src->clonePrototype(outG,n);
+	  dst->copy( e1, e0, src );
+	}
+	delete propIt;
+      }
+    }
+    delete edgeIt;
+  }
 }
-
-void tlp::copyToGraph	(	SuperGraph *	outG,
-							SuperGraph *	inG,
-							SelectionProxy*	inSel,
-							SelectionProxy* outSel	)
-{
-	if( outSel ) {
-		outSel->setAllNodeValue( false );
-		outSel->setAllEdgeValue( false );
-	}
-
-	if( !outG || !inG )
-		return;
-
-	// extend the selection to edge ends
-	if( inSel ) {
-		Iterator<edge> * edgeIt = inG->getEdges();
-		while( edgeIt->hasNext() ) {
-			edge e = edgeIt->next();
-			if( inSel->getEdgeValue(e) ) {
-				node n0 = inG->source( e );
-				node n1 = inG->target( e );
-				inSel->setNodeValue( n0, true );
-				inSel->setNodeValue( n1, true );
-			}
-		}
-		delete edgeIt;
-	}
-
-	// copy selected nodes
-	MutableContainer<node> nodeTrl;
-	{
-		Iterator<node> * nodeIt = inG->getNodes();
-		while( nodeIt->hasNext() ) {
-			node n0 = nodeIt->next();
-			if( !inSel || inSel->getNodeValue(n0) ) {
-				node n1 = outG->addNode();
-
-				// select appended node
-				if( outSel )
-					outSel->setNodeValue( n1, true );
-
-				// add to translation tab
-				nodeTrl.set( n0.id, n1 );
-
-				// copy node properties
-				Iterator<std::string> * propIt = inG->getProperties();
-				while( propIt->hasNext() ) {
-					std::string n = propIt->next();
-					PProxy * src = inG->getProperty( n ),
-						   * dst = outG->existProperty(n) ? outG->getProperty(n) : src->clonePrototype(outG,n);
-					dst->copy( n1, n0, src );
-				}
-				delete propIt;
-			}
-		}
-		delete nodeIt;
-	}
-
-	// copy selected edges
-	{
-		Iterator<edge> * edgeIt = inG->getEdges();
-		while( edgeIt->hasNext() ) {
-			edge e0    = edgeIt->next();
-			if( !inSel || inSel->getEdgeValue(e0) ) {
-				node e0_n0 = inG->source(e0);
-				node e0_n1 = inG->target(e0);
-				edge e1 = outG->addEdge( nodeTrl.get(e0_n0.id),
-										 nodeTrl.get(e0_n1.id) );
-
-				// select appended edge
-				if( outSel )
-					outSel->setEdgeValue( e1, true );
-
-				// copy edge properties
-				Iterator<std::string> * propIt = inG->getProperties();
-				while( propIt->hasNext() ) {
-					std::string n = propIt->next();
-					PProxy * src = inG->getProperty( n ),
-						   * dst = outG->existProperty(n) ? outG->getProperty(n) : src->clonePrototype(outG,n);
-					dst->copy( e1, e0, src );
-				}
-				delete propIt;
-			}
-		}
-		delete edgeIt;
-	}
-}
-
-
-
