@@ -1,7 +1,3 @@
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "tulip/WithParameter.h"
 #include "tulip/Reflect.h"
 StructDef WithParameter::getParameters(){return parameters;}
