@@ -31,7 +31,7 @@ double g(int k,double width,double amplitude) {
   }
 }
 //================================================================================
-int getInterval(int d,vector<int> &ranges) {
+int getInterval(int d,const vector<int> &ranges) {
   for (unsigned int i=0;i<ranges.size()-1;++i) {
     if ((d>=ranges[i]) && (d<ranges[i+1])) return i;
   }
@@ -51,8 +51,8 @@ void ConvolutionClustering::getParameters(int &histosize,int &threshold,int &wid
 }
 //================================================================================
 list<int> ConvolutionClustering::getLocalMinimum() {
-  vector<double> &discretHisto=*getHistogram();
-  list <int> localMinimum;
+  vector<double> &discretHisto = *getHistogram();
+  list<int> localMinimum;
   localMinimum.push_back(0);
   bool slopeSens; //false descent
   if (discretHisto[0]>discretHisto[1]) slopeSens=false; else slopeSens=true;
@@ -77,17 +77,16 @@ list<int> ConvolutionClustering::getLocalMinimum() {
 }
 //================================================================================
 void ConvolutionClustering::autoSetParameter() {
+
   map<double,int> histo;
   Iterator<node> *itN=superGraph->getNodes();
-  for (;itN->hasNext();) {
+  while (itN->hasNext()) {
     node itn=itN->next();
-    double tmp=metric->getNodeValue(itn);
-    if (histo.find(tmp)==histo.end()) {
+    double tmp = metric->getNodeValue(itn);
+    if (histo.find(tmp)==histo.end())
       histo[tmp]=1;
-    }
-    else {
+    else 
       histo[tmp]+=1;
-    }
   }delete itN;
 
   if (histo.empty()) return;
@@ -108,14 +107,15 @@ void ConvolutionClustering::autoSetParameter() {
     lastValue=(*itMap).first;
   }
   histosize=(int)((metric->getNodeMax()-metric->getNodeMin())/deltaXMin);
-  if (histosize>32768) histosize=32768;
-  if (histosize<64) histosize=64;
+  histosize = histosize <? 16384;
+  histosize = histosize >? 64;
+
   //===============================================================================
   //Find good with for the convolution function
   //We take the maximum width of the biggest hole
   //width=(int)(deltaXMax*histosize/(metric->getNodeMax()-metric->getNodeMin()));
   //width=(int)(deltaXMin*histosize/(metric->getNodeMax()-metric->getNodeMin()));
-  deltaSum/=histo.size();
+  deltaSum /= histo.size();
   width=(int)(deltaSum*histosize/(metric->getNodeMax()-metric->getNodeMin()));
   //===============================================================================
   //Find good threshold
@@ -140,103 +140,103 @@ void ConvolutionClustering::autoSetParameter() {
   threshold=(int)(sum/nbElement);
 }
 //================================================================================
-vector <double> *ConvolutionClustering::getHistogram() {
+vector<double> *ConvolutionClustering::getHistogram() {
   //building of the histogram of values
   histogramOfValues.clear();
   Iterator<node> *itN=superGraph->getNodes();
-  for (;itN->hasNext();) {
+  while (itN->hasNext()) {
     node itn=itN->next();
-    int tmp=(int)( (metric->getNodeValue(itn) - metric->getNodeMin() ) * (double)histosize / (metric->getNodeMax()-metric->getNodeMin())) ;
-    if (histogramOfValues.find(tmp)==histogramOfValues.end()) {
+    int tmp=(int)( (metric->getNodeValue(itn) - metric->getNodeMin() ) * (double)histosize / 
+		   (metric->getNodeMax() - metric->getNodeMin()));
+    if (histogramOfValues.find(tmp) == histogramOfValues.end())
       histogramOfValues[tmp]=1;
-    }
-    else {
+    else
       histogramOfValues[tmp]+=1;
-    }
-  }delete itN;
+  } delete itN;
 
   //Apply the convolution on the histogram of values
   //Convolution parameter, this version work only with integer
   smoothHistogram.clear();
   smoothHistogram.resize(histosize);
-  for (int pos=0;pos<histosize;++pos) smoothHistogram[pos]=0;
+  for (int pos=0; pos<histosize; ++pos) smoothHistogram[pos]=0;
   map<int,int>::iterator itMap;
-  for (itMap=histogramOfValues.begin();itMap!=histogramOfValues.end();++itMap) {
+  for (itMap=histogramOfValues.begin(); itMap!=histogramOfValues.end(); ++itMap) {
     double value=itMap->second;
     int index=itMap->first;
     for (int i=-width;i<=width;++i) {
       if ((index+i)>=0 && (index+i)<histosize)
-	smoothHistogram[index+i]+=value*g(i,width,1);
+	smoothHistogram[index+i] += value*g(i,width,1);
     }
   }
   return &smoothHistogram;
 }
 //================================================================================
+void ConvolutionClustering::buildSubGraphs(const vector<int>& ranges){
+  //  cerr << __PRETTY_FUNCTION__ << "...." << flush;
+  //build the empty graphs 
+  char str[100];
+  vector<SuperGraph *> newGraphs(ranges.size()-1);
+  for (unsigned int i=0; i< ranges.size()-1; ++i) {
+    sprintf(str,"Cluster_%05i",i);
+    newGraphs[i] = tlp::newSubGraph(superGraph,string(str));
+  }
+  
+  //Fill the graphs with nodes
+  Iterator<node> *itN=superGraph->getNodes();
+  while (itN->hasNext()) {
+    node itn=itN->next();
+    int tmp = getInterval((int)( (metric->getNodeValue(itn) - metric->getNodeMin() ) * 
+				 (double)histosize / (metric->getNodeMax()-metric->getNodeMin()))
+			  ,ranges);
+    newGraphs[tmp]->addNode(itn);
+  } delete itN;
+  
+  //Fill the graphs with edges
+  for (unsigned int i=0; i< ranges.size()-1; ++i) {
+    Iterator<edge> *itE=superGraph->getEdges();
+    while (itE->hasNext()) {
+      edge ite=itE->next();
+      if (newGraphs[i]->isElement(superGraph->source(ite)) && newGraphs[i]->isElement(superGraph->target(ite)) ) 
+	newGraphs[i]->addEdge(ite);
+    } delete itE;
+  }
+  for (unsigned int i=0; i< ranges.size()-1; ++i) {
+    if (newGraphs[i]->numberOfNodes()==0) {
+      superGraph->delSubGraph(newGraphs[i]);
+    }
+  }
+  //  cerr << " end." << endl;
+}
+//================================================================================
 bool ConvolutionClustering::run() {
   histosize=128;
   string tmp1,tmp2;
   metric=superGraph->getProperty<MetricProxy>("viewMetric");
   autoSetParameter();
   getHistogram();
-  ConvolutionClusteringSetup *mysetup=new ConvolutionClusteringSetup(this);
-  bool setupResult=mysetup->exec();
+  ConvolutionClusteringSetup *mysetup = new ConvolutionClusteringSetup(this);
+  bool setupResult = mysetup->exec();
   delete mysetup;
   if (setupResult==QDialog::Rejected) return false;
-  vector<int> temporaryRanges;
-  bool state=false; //indicate if we are above the threshold or not;
-  list<int> localMinimum=getLocalMinimum();
-  while (!localMinimum.empty()) {
-    temporaryRanges.push_back(localMinimum.front());
-    localMinimum.pop_front();
-  }
-  temporaryRanges.push_back(histosize);
-  //Ensure that there is elements inside each intervals.
   vector<int> ranges;
   ranges.push_back(0);
-  unsigned int curRanges=0;
-  map<int,int>::iterator itMap;
-  itMap=histogramOfValues.begin();
-  while (temporaryRanges[curRanges]<histosize) {
-    if (itMap==histogramOfValues.end()) {
-      ranges.push_back(histosize);
-      break;
-    }
-    else
-      ranges.push_back(temporaryRanges[curRanges]);
-  }
-  //build the empty graphs 
-  char str[100];
-  vector<SuperGraph *> newGraphs(ranges.size()-1);
-  for (unsigned int i=0; i< ranges.size()-1;++i) {
-    sprintf(str,"Cluster_%05i",i);
-    newGraphs[i]=tlp::newSubGraph(superGraph,string(str));
-  }
-  //Fill the graphs with nodes
-  Iterator<node> *itN=superGraph->getNodes();
-  for (;itN->hasNext();) {
-    node itn=itN->next();
-    int tmp=getInterval((int)( (metric->getNodeValue(itn) - metric->getNodeMin() ) * (double)histosize / (metric->getNodeMax()-metric->getNodeMin())),ranges);
-    newGraphs[tmp]->addNode(itn);
-  }delete itN;  
-  //Fill the graphs with edges
-  for (unsigned int i=0; i< ranges.size()-1; ++i) {
-    Iterator<edge> *itE=superGraph->getEdges();
-    for(;itE->hasNext();) {
-      edge ite=itE->next();
-      if (newGraphs[i]->isElement(superGraph->source(ite)) && newGraphs[i]->isElement(superGraph->target(ite)) ) newGraphs[i]->addEdge(ite);
-    }delete itE;
+  list<int> localMinimum = getLocalMinimum();
+  while (!localMinimum.empty()) {
+    ranges.push_back(localMinimum.front());
+    localMinimum.pop_front();
   }
+  ranges.push_back(histosize);
+  //Ensure that there is elements inside each intervals.
+  buildSubGraphs(ranges);
   return true;
 }
 //================================================================================
-bool ConvolutionClustering::check(string &erreurMsg)
-{
+bool ConvolutionClustering::check(string &erreurMsg) {
   erreurMsg="";
   return true;
 }
 //================================================================================
-void ConvolutionClustering::reset()
-{
+void ConvolutionClustering::reset() {
 }
 //================================================================================
 
