@@ -5,6 +5,7 @@
 #include <tulip/SuperGraph.h>
 #include <tulip/MetaGraphProxy.h>
 #include <tulip/TlpTools.h>
+#include <tulip/DrawingTools.h>
 
 #include "QuotientClustering.h"
 
@@ -13,13 +14,14 @@ CLUSTERINGPLUGIN(QuotientClustering,"QuotientClustering","David Auber","13/06/20
 
 using namespace std;
 
-struct edgeS {
-  unsigned  source,target;
+struct Edge {
+  unsigned int source,target;
 };
 
 namespace std {
-  struct less<edgeS> {
-    bool operator()(const edgeS &c,const edgeS &d) const {
+  template<>
+  struct less<Edge> {
+    bool operator()(const Edge &c,const Edge &d) const {
       if (c.source<d.source) return true;
       if (c.source>d.source) return false;
       if (c.target<d.target) return true;
@@ -32,18 +34,11 @@ namespace std {
 QuotientClustering::QuotientClustering(ClusterContext context):Clustering(context) {}
 //================================================================================
 QuotientClustering::~QuotientClustering(){}
-
-namespace stdext {
-  struct hash<double> {
-    size_t operator()(const double s) const { return (size_t)s; }
-  };
-};
 //===============================================================================
 bool QuotientClustering::run() {
-  SuperGraph *quotientGraph=tlp::newSubGraph(superGraph->getRoot());
-  MetaGraphProxy *meta=quotientGraph->getProperty<MetaGraphProxy>("viewMetaGraph");
-  //parcourir tous les sous graphe du graphe courant.
-  //et construit les metanoeud dans le quotient graphe.
+  SuperGraph *quotientGraph = tlp::newSubGraph(superGraph->getRoot());
+  MetaGraphProxy *meta = quotientGraph->getProperty<MetaGraphProxy>("viewMetaGraph");
+  //Create one metanode for each subgraph(cluster) of current graph.
   SuperGraph *graph= superGraph;
   map<SuperGraph*,node> mapping;
   Iterator<SuperGraph *> *itS=graph->getSubGraphs();
@@ -55,8 +50,8 @@ bool QuotientClustering::run() {
       mapping[its]=n;
     }
   } delete itS;
-
-  set<edgeS> myQuotientGraph;
+  //
+  set<Edge> myQuotientGraph;
   Iterator<edge>*itE=superGraph->getEdges();
   while (itE->hasNext()) {
     edge ite=itE->next();
@@ -75,12 +70,13 @@ bool QuotientClustering::run() {
 	if (tmp->isElement(target)) clusterTarget.push_back(its);
       }
     } delete itS;
+    
     for (std::list<SuperGraph *>::iterator it1=clusterSource.begin(); it1!=clusterSource.end(); ++it1)
       for (std::list<SuperGraph *>::iterator it2=clusterTarget.begin(); it2!=clusterTarget.end(); ++it2) {
-	edgeS tmp;
+	Edge tmp;
 	tmp.source=mapping[*it1].id;
 	tmp.target=mapping[*it2].id;
-	if ( ((*it1)!=(*it2)) && (myQuotientGraph.find(tmp)==myQuotientGraph.end()) ) {
+	if ( (tmp.source!=tmp.target) && (myQuotientGraph.find(tmp)==myQuotientGraph.end()) ) {
 	  myQuotientGraph.insert(tmp);
 	  quotientGraph->addEdge(mapping[*it1],mapping[*it2]);
 	}
@@ -88,7 +84,6 @@ bool QuotientClustering::run() {
   } delete itE;
 
   //compute layout according to the layouts of subgraphs
-  LayoutProxy *layout  = quotientGraph->getProperty<LayoutProxy>("viewLayout");
   SizesProxy *size  = quotientGraph->getProperty<SizesProxy>("viewSize");
   Iterator<node> *itN = quotientGraph->getNodes();
   while (itN->hasNext()) {
@@ -96,19 +91,13 @@ bool QuotientClustering::run() {
     SuperGraph * graph = meta->getNodeValue(n);
     LayoutProxy * graphlayout = graph->getProperty<LayoutProxy>("viewLayout");
     SizesProxy * graphsize = graph->getProperty<SizesProxy>("viewSize");
-    Coord max = graphlayout->getMax(graph);
-    Coord min = graphlayout->getMin(graph);
+    pair<Coord, Coord> bboxe = tlp::computeBoundingBox(graph, graphlayout, graphsize);
+    Coord max = bboxe.first;
+    Coord min = bboxe.second;
     Coord center = (max + min) / 2.0;
     graphlayout->setNodeValue(n, center);
-    tlp::Vector<float, 3> maxSize = graphsize->getMax(graph) / 2.0;
-
     Coord nodeSize = (max - min);
-    Size tmp;
-    tmp[0] = nodeSize[0] + maxSize[0];
-    tmp[1] = nodeSize[1] + maxSize[1];
-    tmp[2] = nodeSize[2] + maxSize[2];
-
-    size->setNodeValue(n, tmp);
+    size->setNodeValue(n, Size(nodeSize[0], nodeSize[1], nodeSize[2]));
   } delete itN;
 
   if (dataSet!=0) {
