@@ -94,7 +94,7 @@ bool SegmentRecClustering::DfsClustering (node currentNode,SelectionProxy *selec
 }
 //================================================================================
 bool SegmentRecClustering::run() {
-  bool cached,resultBool;
+  bool resultBool;
   string erreurMsg;
   node rootNode;
   mResult=QMessageBox::information( 0, QString("Tulip Interval"),
