@@ -71,19 +71,12 @@ double StrengthClustering::computeMQValue(vector<set<node> > partition) {
     }
   if (partition.size()>1)
     negative/=double(partition.size()*(partition.size()-1)/2.0);
-  //  cout << "positive :"<< positive << " , negative :" << negative << endl;
   return positive-negative;
 }
 //==============================================================================
 vector< set<node> > StrengthClustering::computeNodePartition(double threshold) {
-  cerr << __PRETTY_FUNCTION__ << endl;
-  bool cached,results;
+  //cerr << __PRETTY_FUNCTION__ << endl;
   string errMsg;
-  //  MetricProxy *values=superGraph->getLocalProperty<MetricProxy>("Strength",cached,results,errMsg);  
-  // double threshold=2;
-  // step One build a filtered subgraph
-  // All edges with a values less than the threshold are removed
-  //  cerr << "1" << endl << flush;
   SuperGraph *tmpGraph=tlp::newCloneSubGraph(superGraph);
   StableIterator<edge> itE(superGraph->getEdges());
   while (itE.hasNext()) {
@@ -93,11 +86,9 @@ vector< set<node> > StrengthClustering::computeNodePartition(double threshold) {
 	tmpGraph->delEdge(ite);
     }
   }
-  
 
-  set<node> singleton;
   // Select SubGraph singleton in superGraph
-  //  cerr << "2" << endl << flush;
+  set<node> singleton;
   StableIterator<node> itN(tmpGraph->getNodes());
   while (itN.hasNext()) {
     node itn=itN.next();
@@ -108,17 +99,17 @@ vector< set<node> > StrengthClustering::computeNodePartition(double threshold) {
   StableIterator<edge> itE2(superGraph->getEdges());
   while (itE2.hasNext()) {
     edge ite=itE2.next();
-    if (singleton.find(superGraph->source(ite))!=singleton.end() && singleton.find(superGraph->target(ite))!=singleton.end()) {
+    if (singleton.find(superGraph->source(ite))!=singleton.end() && 
+	singleton.find(superGraph->target(ite))!=singleton.end()) {
       tmpGraph->addEdge(ite);
     }
   }
 
   //Extract connected componnent
-  //  cerr << "5" << endl << flush;
   MetricProxy *connected= new MetricProxy(tmpGraph); 
   tmpGraph->computeProperty("Connected Component", connected, errMsg);
 
-  //Put individual nodes in the same cluster
+  //Put isolated nodes in the same cluster
   double val=-1;
   Iterator<node> *itN2 = tmpGraph->getNodes();
   while (itN2->hasNext()) {
@@ -153,10 +144,9 @@ vector< set<node> > StrengthClustering::computeNodePartition(double threshold) {
   superGraph->delAllSubGraphs(tmpGraph);
   return result;
 }
-
+//==============================================================================
 void drawGraph(SuperGraph *tmpg) {
-  cerr << __PRETTY_FUNCTION__ << endl;
-  bool cached,result;
+  //  cerr << __PRETTY_FUNCTION__ << endl;
   string errMsg;
   string layoutName;
   if (tmpg->numberOfNodes() > 300)
@@ -165,47 +155,102 @@ void drawGraph(SuperGraph *tmpg) {
     layoutName = "GEM (Frick)";
   string sizesName="Auto_sizing";
   tmpg->computeProperty(layoutName,tmpg->getLocalProperty<LayoutProxy>("viewLayout"),errMsg);
-  /*  *tmpg->getLocalProperty<LayoutProxy>("viewLayout") = *tmpg->getLocalProperty<LayoutProxy>(layoutName,
-										result, cached,
-										errMsg);*/
-  //  *tmpg->getLocalProperty<SizesProxy>("viewSize") = *tmpg->getLocalProperty<SizesProxy>(sizesName, result, cached,    errMsg);
   if (tmpg->numberOfNodes() < 300)
     tmpg->computeProperty(sizesName,tmpg->getLocalProperty<SizesProxy>("viewSize"),errMsg);
-  //  tmpg->delLocalProperty(layoutName);
-  //  tmpg->delLocalProperty(sizesName);
 }
-
 //==============================================================================
-bool StrengthClustering::run() {
-  cerr << __PRETTY_FUNCTION__ << endl;
-  //  cerr << __PRETTY_FUNCTION__ << " Start" << endl;
-  //  cout << "Average Path Length :" << TlpTools::averagePathLength(superGraph) << endl;
-  //  cout << "Average clustering :" <<  TlpTools::averageCluster(superGraph) << endl; 
-  bool cached,result;
-  string errMsg;
-  values = new MetricProxy(superGraph);
-  result = superGraph->computeProperty("Strength", values, errMsg);
-  double maxMQ=0;
-  int numberOfStep=10;
-  double threshold=0;
-  double deltaThreshold=(values->getEdgeMax(superGraph)-values->getEdgeMin(superGraph))/numberOfStep;
-  int debugI=1;
-  //cerr << debugI++ << " ....." << endl;
+double StrengthClustering::findBestThreshold(int numberOfSteps){
+  double maxMQ=-2;
+  double threshold=values->getEdgeMin(superGraph);
+  double deltaThreshold=(values->getEdgeMax(superGraph)-values->getEdgeMin(superGraph))/double(numberOfSteps);
   for (double i=values->getEdgeMin(superGraph);i<values->getEdgeMax(superGraph);i+=deltaThreshold) {
     vector< set<node > > tmp;
     tmp=computeNodePartition(i);
     double mq=computeMQValue(tmp);
-    //cerr << i << " , " << mq  << " , " << tmp.size() << endl;
     if (mq>maxMQ) {
       threshold=i;
       maxMQ=mq;
     }
   }
-  cout << " MQ value for clustering : " << maxMQ << endl << flush;
-  //  cerr << debugI++ << " ....." << endl;
+  cout << __PRETTY_FUNCTION__ << endl;
+  cout << "\t" <<" Nb try : " << numberOfSteps << endl;
+  cout << "\t" <<" Max MQ : " << maxMQ << endl << flush;
+  cout << "\t" <<" Best threshold : " << threshold << endl << flush;
+  return threshold;
+}
+//==============================================================================
+SuperGraph* StrengthClustering::buildSubGraphs(const vector< set<node > > &partition){
+  if (partition.size()<2) return superGraph;
+  SuperGraph *tmpGraph=tlp::newCloneSubGraph(superGraph);
+  for (unsigned int i=0;i<partition.size();++i) {
+    tlp::inducedSubGraph(tmpGraph,partition[i]);
+  }
+  return tmpGraph;
+}
+//==============================================================================
+void StrengthClustering::recursiveCall(SuperGraph *rootGraph, map<SuperGraph *,SuperGraph *> &mapGraph) {
+  Iterator<SuperGraph*> *itS = rootGraph->getSubGraphs();
+  while(itS->hasNext()){
+    SuperGraph *graph=itS->next();
+    double avPath=tlp::averagePathLength(graph);
+    double avCluster=tlp::averageCluster(graph);
+    /*
+      cout << "Average Path Length :" << avPath << endl;
+      cout << "Average clustering  :" <<  avCluster << endl; 
+      cout << "Number of nodes     :" <<  tmpg->numberOfNodes() << endl; 
+      cout << "Number of edges     :" <<  tmpg->numberOfEdges() << endl; 
+    */
+    SuperGraph *tmpGr=graph;
+    if ( avPath>1 && avPath<4 && avCluster>0.25 && graph->numberOfNodes()>10) {
+      DataSet tmpData;
+      string errMsg;
+      tlp::clusterizeGraph(graph,errMsg,&tmpData,"Strength");
+      tmpData.get("strengthGraph",tmpGr);
+    }
+    mapGraph[graph]=tmpGr;
+    if (graph==tmpGr) {
+      drawGraph(graph);
+    }
+  } delete itS;
+}
+//==============================================================================
+SuperGraph* StrengthClustering::buildQuotientGraph(SuperGraph *graph) {
+  DataSet tmpData;
+  string errMsg;
+  tlp::clusterizeGraph(graph,errMsg,&tmpData,"QuotientClustering");
+  SuperGraph *quotientGraph;
+  tmpData.get<SuperGraph *>("quotientGraph",quotientGraph);
+  drawGraph(quotientGraph);
+  return quotientGraph;
+}
+//==============================================================================
+/**
+  Create a new metagraph property in order to have in the "viewMetagraph" the result
+  of recursive clustering, and in "strengthMetaGraph" the graphs before without recursive clustering.
+*/
+void StrengthClustering::adjustMetaGraphProtperty(SuperGraph *quotientGraph, map<SuperGraph *,SuperGraph *> &mapGraph) {
+  if (quotientGraph != superGraph) {
+    SuperGraph *rootGraph = superGraph->getRoot();
+    MetaGraphProxy *meta = rootGraph->getLocalProperty<MetaGraphProxy>("viewMetaGraph");
+    MetaGraphProxy *meta2 = rootGraph->getLocalProperty<MetaGraphProxy>("strengthMetaGraph");
+    Iterator<node> *itN = quotientGraph->getNodes();
+    while (itN->hasNext()) {
+      node itn=itN->next();
+      meta2->setNodeValue(itn,meta->getNodeValue(itn));
+      meta->setNodeValue(itn,mapGraph[meta->getNodeValue(itn)]);
+    } delete itN;
+  }
+}
+//==============================================================================
+bool StrengthClustering::run() {
+  bool result;
+  string errMsg;
+  values = new MetricProxy(superGraph);
+  result = superGraph->computeProperty("Strength", values, errMsg);
+  const unsigned int NB_TEST = 10;
+  double threshold = findBestThreshold(NB_TEST);
+
   vector< set<node > > tmp;
-  tmp.clear();
-  //  threshold=(values->getEdgeMax())*80/step;
   tmp = computeNodePartition(threshold);
   if (tmp.size()==1) {
     drawGraph(superGraph);
@@ -214,55 +259,18 @@ bool StrengthClustering::run() {
     }
     return true;
   }
-  SuperGraph *tmpGraph=tlp::newCloneSubGraph(superGraph);
-  //  cerr << debugI++ << " ....." << endl;
+
   map<SuperGraph *,SuperGraph *> mapGraph;
-  for (unsigned int i=0;i<tmp.size();++i) {
-    SuperGraph *tmpg=tlp::inducedSubGraph(tmpGraph,tmp[i]);
-    double avPath=tlp::averagePathLength(tmpg);
-    double avCluster=tlp::averageCluster(tmpg);
-    /*    cout << "Average Path Length :" << avPath << endl;
-    cout << "Average clustering  :" <<  avCluster << endl; 
-    cout << "Number of nodes     :" <<  tmpg->numberOfNodes() << endl; 
-    cout << "Number of edges     :" <<  tmpg->numberOfEdges() << endl; 
-    */
-    SuperGraph *tmpGr=tmpg;
-    if ( tmp.size()>1 && avPath>1 && avPath<4 && avCluster>0.25 && tmpg->numberOfNodes()>10) {
-      DataSet tmpData;
-      tlp::clusterizeGraph(tmpg,errMsg,&tmpData,"Strength");
-      tmpData.get("strengthGraph",tmpGr);
-    }
-    mapGraph[tmpg]=tmpGr;
-    if (tmpg==tmpGr) {
-      drawGraph(tmpg);
-    }
-    tmpg=tmpGr;
-  }
-  //  cerr << debugI++ << " ....." << endl;
-  DataSet tmpData;
-  tlp::clusterizeGraph(tmpGraph,errMsg,&tmpData,"QuotientClustering");
-  superGraph->delLocalProperty("Strength");
-  SuperGraph *quotientGraph;
-  tmpData.get<SuperGraph *>("quotientGraph",quotientGraph);
-  drawGraph(quotientGraph);
+  SuperGraph *tmpGraph, *quotientGraph;
+
+  tmpGraph = buildSubGraphs(tmp);
+  recursiveCall(tmpGraph, mapGraph);
+  quotientGraph = buildQuotientGraph(tmpGraph);
+  adjustMetaGraphProtperty(quotientGraph, mapGraph);
+
   if (dataSet!=0) {
     dataSet->set("strengthGraph",quotientGraph);
   }
-  if (quotientGraph!=superGraph) {
-    //  cerr << debugI++ << " .....A" << endl;
-    SuperGraph *rootGraph=superGraph->getRoot();
-    MetaGraphProxy *meta=rootGraph->getLocalProperty<MetaGraphProxy>("viewMetaGraph");
-    MetaGraphProxy *meta2=rootGraph->getLocalProperty<MetaGraphProxy>("strengthMetaGraph");
-    //  cerr << debugI++ << " .....B" << endl;
-    Iterator<node> *itN=quotientGraph->getNodes();
-    while (itN->hasNext()) {
-      node itn=itN->next();
-      meta2->setNodeValue(itn,meta->getNodeValue(itn));
-      meta->setNodeValue(itn,mapGraph[meta->getNodeValue(itn)]);
-    } delete itN;
-    //  cerr << __PRETTY_FUNCTION__ << " End" << endl;
-  }
-
   delete values;
   return true;
 }
