@@ -5,7 +5,7 @@
 #include <string>
 #include <set>
 #include <vector>
-
+#include <map>
 #include <tulip/TulipPlugin.h>
 
 class MetricProxy;
@@ -24,8 +24,13 @@ private:
   double e(std::set<node> &U,std::set<node> &V);
   double s(std::set<node> &U,std::set<node> &V);
   double s(std::set<node> &U);
-  double computeMQValue(std::vector< std::set<node> > partition);
   std::vector< std::set<node> > computeNodePartition(double threshold);
+  double computeMQValue(std::vector< std::set<node> > partition);
+  double findBestThreshold(int numberOfSteps);
+  SuperGraph* buildSubGraphs(const std::vector< std::set<node > > &);
+  void recursiveCall(SuperGraph *, std::map<SuperGraph *,SuperGraph *> &);
+  SuperGraph* buildQuotientGraph(SuperGraph *graph);
+  void adjustMetaGraphProtperty(SuperGraph *, std::map<SuperGraph *,SuperGraph *> &);
   MetricProxy * values;
 };
 /*@}*/
