@@ -8,7 +8,7 @@ using namespace std;
 
 const unsigned int MAX_SIZE = 10000;
 
-enum ValType { DOUBLE = 0, STRING = 1, NOVAL = 2, NOTHING = 3 };
+enum ValType { TLP_DOUBLE = 0, TLP_STRING = 1, TLP_NOVAL = 2, TLP_NOTHING = 3 };
 /** \addtogroup import */
 /*@{*/
 /// AdjacencyMatrixImport.cpp - Import a graph coded with matrix.
@@ -102,7 +102,7 @@ struct AdjacencyMatrixImport:public ImportModule {
       char line[MAX_SIZE];
       in.getline(line,MAX_SIZE);
       stringstream lines(line);
-      int curNode = 0;
+      unsigned int curNode = 0;
       while (lines.good()) {
 	string valString;
 	double valDouble;
@@ -112,11 +112,11 @@ struct AdjacencyMatrixImport:public ImportModule {
 	  char *res;
 	  double valDouble = strtod(start,&res);
 	  if (res!=start) 
-	    type = DOUBLE;
+	    type = TLP_DOUBLE;
 	  else {
-	    type = STRING;
-	    if (valString == "@")  type = NOVAL;
-	    if (valString == "#")  type = NOTHING;
+	    type = TLP_STRING;
+	    if (valString == "@")  type = TLP_NOVAL;
+	    if (valString == "#")  type = TLP_NOTHING;
 	  }
 
 	  if ( curNode >= nodes.size() || curLine >= nodes.size()) {
@@ -125,10 +125,10 @@ struct AdjacencyMatrixImport:public ImportModule {
 
 	  if (curNode == curLine) {  
 	    switch (type) {
-	    case DOUBLE:
+	    case TLP_DOUBLE:
 	      metric->setNodeValue(nodes[curNode],valDouble);
 	      break;
-	    case STRING:
+	    case TLP_STRING:
 	      stringP->setNodeValue(nodes[curNode],valString);
 	      break;
 	    }
@@ -136,15 +136,15 @@ struct AdjacencyMatrixImport:public ImportModule {
 	  else {
 	    edge e;
 	    switch (type) {
-	    case DOUBLE:
+	    case TLP_DOUBLE:
 	      e=superGraph->addEdge(nodes[curLine],nodes[curNode]);
 	      metric->setEdgeValue(e,valDouble);
 	      break;
-	    case STRING:
+	    case TLP_STRING:
 	      e=superGraph->addEdge(nodes[curLine],nodes[curNode]);
 	      stringP->setEdgeValue(e,valString);
 	      break;
-	    case NOVAL:
+	    case TLP_NOVAL:
 	      e=superGraph->addEdge(nodes[curLine],nodes[curNode]);
 	      break;
 	    }
