@@ -1,4 +1,3 @@
-#include<qinputdialog.h>
 #include <tulip/TulipPlugin.h>
 
 using namespace std;
@@ -43,7 +42,7 @@ struct CompleteGraph:public ImportModule {
     it1=superGraph->getNodes();
     int i=0;
     while (it1->hasNext()) {
-      if (!pluginProgress->progress(i,nbNodes)) 
+      if (pluginProgress->progress(i,nbNodes) != TLP_CONTINUE) 
 	return false;
       i++;
       node n1=it1->next();
