@@ -2,38 +2,66 @@
 #include <tulip/TulipPlugin.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+
+#ifdef _WIN32
+#include <windows.h>
+#else
 #include <dirent.h>
+#endif
 
 using namespace std;
 
-struct FileSystem:public ImportModule
-{
+struct FileSystem:public ImportModule {
   FileSystem(ClusterContext context):ImportModule(context) {}
   ~FileSystem(){}
 
   MetricProxy *size,*gid,*uid,*lastaccess,*lastmodif,*lastchange;
-
   IntProxy *type;
   StringProxy *label;
-  bool breaked;
   int progress;
 
 
-    bool readDir(node n,string directory) {
-    if (!pluginProgress->progress(progress,100)) { breaked=true; return false;}
+  ProgressState readDir(node n,string directory) {
+    if (pluginProgress->progress(progress,100)!=TLP_CONTINUE) { 
+      return pluginProgress->state();
+    }
     progress++;
-    progress=progress%100;
-    if (breaked) return false;
+    progress = progress%100;
+    #ifndef _WIN32
     DIR *dir=opendir(directory.c_str());
-    if (dir==0) return false;
+    if (dir == 0) {
+      pluginProgress->stop();
+      return pluginProgress->state();
+    }
     dirent *entry;
+    #else
+    HANDLE hFind; 
+  	WIN32_FIND_DATA FindData; 
+  	SetCurrentDirectory (directory.c_str()); 
+  	hFind=FindFirstFile ("*.*", &FindData); 
+  	bool endOfDirectory = (hFind == NULL) || (hFind == INVALID_HANDLE_VALUE);
+  	if(endOfDirectory) {
+    pluginProgress->stop();
+    return pluginProgress->state();
+  	}
+    #endif
     struct stat infoEntry;
-    int i=0;
+    #ifdef _WIN32
+     while (!endOfDirectory) {
+   	  if (!strcmp("..",FindData.cFileName) || !strcmp(".",FindData.cFileName)) {
+   	  	endOfDirectory = !(FindNextFile (hFind, &FindData));
+   	  	continue;
+   	  }
+      string entryName=FindData.cFileName;
+      string pathEntry=directory+entryName;
+	  stat(pathEntry.c_str(),&infoEntry);
+     #else
     while ((entry = readdir(dir))!=0) {
       if (!strcmp("..",entry->d_name) || !strcmp(".",entry->d_name)) continue;
       string entryName=entry->d_name;
       string pathEntry=directory+entryName;
       lstat(pathEntry.c_str(),&infoEntry);
+    #endif
       if (infoEntry.st_dev==true) continue;
       node newNode=superGraph->addNode();
       superGraph->addEdge(n,newNode);
@@ -50,7 +78,7 @@ struct FileSystem:public ImportModule
       
       if ((infoEntry.st_mode & S_IFMT) == S_IFDIR) {
 	type->setNodeValue(newNode,1);
-	if (!readDir(newNode,pathEntry+"/"))
+	if (readDir(newNode,pathEntry+"/") == TLP_CANCEL)
 	  superGraph->delNode(newNode);
 	else {
 	  double newSize=0;
@@ -63,14 +91,20 @@ struct FileSystem:public ImportModule
 	  size->setNodeValue(newNode,newSize/1024.0);
 	}
       }
+       #ifdef _WIN32
+      endOfDirectory = !(FindNextFile (hFind, &FindData));
+      #endif 
     } 
+    #ifdef _WIN32
+    FindClose (hFind); 
+    #else
     closedir(dir);
-    return true;
+    #endif
+    return TLP_CONTINUE;
   }
 
   bool import(const string &name) {
     bool ok;
-    breaked=false;
     size=superGraph->getProperty<MetricProxy>("size");
     uid=superGraph->getProperty<MetricProxy>("uid");
     gid=superGraph->getProperty<MetricProxy>("gid");
@@ -85,7 +119,11 @@ struct FileSystem:public ImportModule
     if (dirName.isNull()) return false;
 
     struct stat infoEntry;
+    #ifdef _WIN32
+    stat(dirName.ascii(),&infoEntry);
+    #else
     lstat(dirName.ascii(),&infoEntry);
+    #endif
     if (infoEntry.st_dev!=true)  {
       label->setNodeValue(newNode,dirName.ascii());
       if (infoEntry.st_size<1)
@@ -100,7 +138,7 @@ struct FileSystem:public ImportModule
     }
     readDir(newNode,string(dirName.ascii())+"/");
     double newSize=0;
-    if (!breaked) {
+    if (pluginProgress->state()!=TLP_CANCEL) {
       Iterator<node> *itN=superGraph->getOutNodes(newNode);
       while (itN->hasNext()) {
 	node itn=itN->next();
@@ -108,7 +146,7 @@ struct FileSystem:public ImportModule
       } delete itN;
       size->setNodeValue(newNode,newSize);
     }
-    return !breaked;
+    return pluginProgress->state()!=TLP_CANCEL;
   }
 };
 
