@@ -1,5 +1,4 @@
 #include <time.h>
-#include<qinputdialog.h> 
 #include <tulip/TulipPlugin.h>
 
 using namespace std;
@@ -9,6 +8,7 @@ struct edgeS {
 };
 
 namespace std {
+  template<>
   struct less<edgeS> {
     bool operator()(const edgeS &c,const edgeS &d) const {
       if (c.source<d.source) return true;
@@ -21,28 +21,24 @@ namespace std {
 };
 
 
-namespace
-{
-
-	const char * paramHelp[] =
-	{
-		// nodes
-		HTML_HELP_OPEN() \
-		HTML_HELP_DEF( "type", "int" ) \
-		HTML_HELP_DEF( "default", "5" ) \
-		HTML_HELP_BODY() \
-		"This parameter defines the amount of node used to build the randomized graph." \
-		HTML_HELP_CLOSE(),
-
-		// edges
-		HTML_HELP_OPEN() \
-		HTML_HELP_DEF( "type", "int" ) \
-		HTML_HELP_DEF( "default", "9" ) \
-		HTML_HELP_BODY() \
-		"This parameter defines the amount of edge used to build the randomized graph." \
-		HTML_HELP_CLOSE(),
-	};
+namespace {
+  const char * paramHelp[] = {
+    // nodes
+    HTML_HELP_OPEN() \
+    HTML_HELP_DEF( "type", "int" ) \
+    HTML_HELP_DEF( "default", "5" ) \
+    HTML_HELP_BODY() \
+    "This parameter defines the amount of node used to build the randomized graph." \
+    HTML_HELP_CLOSE(),
 
+    // edges
+    HTML_HELP_OPEN() \
+    HTML_HELP_DEF( "type", "int" ) \
+    HTML_HELP_DEF( "default", "9" ) \
+    HTML_HELP_BODY() \
+    "This parameter defines the amount of edge used to build the randomized graph." \
+    HTML_HELP_CLOSE(),
+  };
 }
 
 
@@ -62,12 +58,12 @@ struct RandomGraph:public ImportModule {
       dataSet->get("nodes", nbNodes);
       dataSet->get("edges", nbEdges);
     }
-
     int ite = nbNodes*nbEdges;
     int nbIteration = ite;
     set<edgeS> myGraph;
     while (ite>0) {
-      if (ite%nbNodes==1) if (!pluginProgress->progress(nbIteration-ite,nbIteration)) return false;
+      if (ite%nbNodes==1) if (pluginProgress->progress(nbIteration-ite,nbIteration)!=TLP_CONTINUE) 
+	return pluginProgress->state()!=TLP_CANCEL;
       edgeS tmp;
       tmp.source=rand()%nbNodes;
       tmp.target=rand()%nbNodes;
