@@ -1,5 +1,4 @@
 #include <time.h>
-#include<qinputdialog.h>
 #include <tulip/TulipPlugin.h>
 
 using namespace std;
@@ -9,6 +8,7 @@ struct edgeS {
 };
 
 namespace std {
+  template<>
   struct less<edgeS> {
     bool operator()(const edgeS &c,const edgeS &d) const {
       int cs,ct,ds,dt;
@@ -79,7 +79,8 @@ struct RandomSimpleGraph:public ImportModule {
     int nbIteration = ite;
     set<edgeS> myGraph;
     while (ite>0) {
-      if (ite%nbNodes==1) if (!pluginProgress->progress(nbIteration-ite,nbIteration)) return false;
+      if (ite%nbNodes==1) if (pluginProgress->progress(nbIteration-ite,nbIteration)!=TLP_CONTINUE) 
+	return pluginProgress->state()!=TLP_CANCEL;
       edgeS tmp;
       tmp.source=rand()%nbNodes;
       tmp.target=rand()%nbNodes;
