@@ -6,31 +6,28 @@ using namespace std;
 
 
 
-namespace
-{
+namespace {
 
-	const char * paramHelp[] =
-	{
-		// minsize
-		HTML_HELP_OPEN() \
-		HTML_HELP_DEF( "type", "int" ) \
-		HTML_HELP_DEF( "default", "100" ) \
-		HTML_HELP_BODY() \
-		"This parameter defines the minimal amount of node used to build the randomized tree." \
-		HTML_HELP_CLOSE(),
-
-		// maxsize
-		HTML_HELP_OPEN() \
-		HTML_HELP_DEF( "type", "int" ) \
-		HTML_HELP_DEF( "default", "1000" ) \
-		HTML_HELP_BODY() \
-		"This parameter defines the maximal amount of node used to build the randomized tree." \
-		HTML_HELP_CLOSE(),
-	};
+  const char * paramHelp[] =
+    {
+      // minsize
+      HTML_HELP_OPEN() \
+      HTML_HELP_DEF( "type", "int" ) \
+      HTML_HELP_DEF( "default", "100" ) \
+      HTML_HELP_BODY() \
+      "This parameter defines the minimal amount of node used to build the randomized tree." \
+      HTML_HELP_CLOSE(),
 
+      // maxsize
+      HTML_HELP_OPEN() \
+      HTML_HELP_DEF( "type", "int" ) \
+      HTML_HELP_DEF( "default", "1000" ) \
+      HTML_HELP_BODY() \
+      "This parameter defines the maximal amount of node used to build the randomized tree." \
+      HTML_HELP_CLOSE(),
+    };
 }
 
-
 struct RandomTree:public ImportModule {
   RandomTree(ClusterContext context):ImportModule(context) {
     addParameter<int>("minsize",paramHelp[0],"100");
@@ -57,7 +54,6 @@ struct RandomTree:public ImportModule {
 
   bool import(const string &name) {
     srand(clock()); 
-
     int minSize  = 100;
     int maxSize  = 1000;
     if (dataSet!=0) {
@@ -68,14 +64,14 @@ struct RandomTree:public ImportModule {
     bool ok=true;
     int i=0;
     while (ok) {
-      if (!pluginProgress->progress(i%100,100)) return false;
+      if (pluginProgress->progress(i%100,100)!=TLP_CONTINUE) break;
       i++;
       superGraph->clear();
       node n=superGraph->addNode();
       ok = !buildNode(n,maxSize);
       if (superGraph->numberOfNodes()<minSize-2) ok=true;
     }
-    return true;
+    return pluginProgress->progress(100,100)!=TLP_CANCEL;
   }
 };
 IMPORTPLUGIN(RandomTree,"Uniform Random Binary Tree","Auber","16/02/2001","0","0","1")
