@@ -1,46 +1,41 @@
 #include <time.h>
-#include <qinputdialog.h>
 #include <tulip/TulipPlugin.h>
+#include <math.h>
 
 using namespace std;
 
 
 
-namespace
-{
-
-	const char * paramHelp[] =
-	{
-		// minsize
-		HTML_HELP_OPEN() \
-		HTML_HELP_DEF( "type", "int" ) \
-		HTML_HELP_DEF( "default", "10" ) \
-		HTML_HELP_BODY() \
-		"This parameter defines the minimal amount of node used to build the randomized tree." \
-		HTML_HELP_CLOSE(),
-
-		// maxsize
-		HTML_HELP_OPEN() \
-		HTML_HELP_DEF( "type", "int" ) \
-		HTML_HELP_DEF( "default", "100" ) \
-		HTML_HELP_BODY() \
-		"This parameter defines the maximal amount of node used to build the randomized tree." \
-		HTML_HELP_CLOSE(),
-
-		// maxdegree
-		HTML_HELP_OPEN() \
-		HTML_HELP_DEF( "type", "int" ) \
-		HTML_HELP_DEF( "default", "5" ) \
-		HTML_HELP_BODY() \
-		"This parameter defines the maximal degree of node used to build the randomized tree." \
-		HTML_HELP_CLOSE(),
-	};
+namespace {
 
+  const char * paramHelp[] =
+    {
+      // minsize
+      HTML_HELP_OPEN() \
+      HTML_HELP_DEF( "type", "int" ) \
+      HTML_HELP_DEF( "default", "10" ) \
+      HTML_HELP_BODY() \
+      "This parameter defines the minimal amount of node used to build the randomized tree." \
+      HTML_HELP_CLOSE(),
+      // maxsize
+      HTML_HELP_OPEN() \
+      HTML_HELP_DEF( "type", "int" ) \
+      HTML_HELP_DEF( "default", "100" ) \
+      HTML_HELP_BODY() \
+      "This parameter defines the maximal amount of node used to build the randomized tree." \
+      HTML_HELP_CLOSE(),
+      // maxdegree
+      HTML_HELP_OPEN() \
+      HTML_HELP_DEF( "type", "int" ) \
+      HTML_HELP_DEF( "default", "5" ) \
+      HTML_HELP_BODY() \
+      "This parameter defines the maximal degree of node used to build the randomized tree." \
+      HTML_HELP_CLOSE(),
+    };
 }
 
 
 
-
 struct RandomTreeGeneral:public ImportModule {
   RandomTreeGeneral(ClusterContext context):ImportModule(context) {
     addParameter<int>("minsize",paramHelp[0],"10");
@@ -83,7 +78,7 @@ struct RandomTreeGeneral:public ImportModule {
     while (ok) {
       ++nbTest;
       if (nbTest%100 == 0) {
-	if (!pluginProgress->progress((i/100)%100,100)) return false;
+	if (pluginProgress->progress((i/100)%100,100)!=TLP_CONTINUE) break;
       }
       i++;
       superGraph->clear();
@@ -92,7 +87,7 @@ struct RandomTreeGeneral:public ImportModule {
       ok=false;
       if (superGraph->numberOfNodes()<sizeMin) ok=true;
     }
-    return true;
+    return pluginProgress->progress(100,100)!=TLP_CANCEL;
   }
 };
 IMPORTPLUGIN(RandomTreeGeneral,"Random General Tree","Auber","16/02/2001","0","0","1")
