@@ -360,11 +360,13 @@ struct TLPDisplayingPropertyBuilder : public TLPFalse
     if ((type==INT) && (token == 1)) {
       if (prop == "SupergraphId") {
 	int v;
-	if (displayingBuilder->graphBuilder->clusterIndex[val] != NULL) {
+	if (displayingBuilder->graphBuilder->clusterIndex.find(val) != displayingBuilder->graphBuilder->clusterIndex.end()) {
 	  v=displayingBuilder->graphBuilder->clusterIndex[val]->getId();
 	  data->set<int>(prop, v);
 	}
-	else cerr << "Import TLP: Warning: no cluster #" << val << " defined." << endl;
+	else {
+	  //	  cerr << "Import TLP: Warning: no cluster #" << val << " defined." << endl;
+	}
       }
       else {
 	data->set<int>(prop, val);
@@ -562,18 +564,23 @@ public:
     string filename;
     dataSet->get<string>("filename", filename);
     struct stat infoEntry;
+    #ifdef _WIN32
+    stat(filename.c_str(),&infoEntry);
+    #else
     lstat(filename.c_str(),&infoEntry);
+    #endif
     int size=infoEntry.st_size;
     istream *input;
-    if (filename.rfind(".gz") == (filename.length() - 3))
+    if (filename.rfind(".gz") == (filename.length() - 3)) {
       input = tlp::getIgzstream(filename.c_str());
+      size *= 4;
+    }
     else
       input = new ifstream(filename.c_str());
     
-    TLPParser<true> myParser(*input, new TLPGraphBuilder(superGraph, dataSet),pluginProgress,size);
+    TLPParser<false> myParser(*input, new TLPGraphBuilder(superGraph, dataSet),pluginProgress,size);
     bool result = myParser.parse();
     delete input;
-
     return result;
   }
 };
