@@ -164,7 +164,8 @@ struct TLPParser {
     TLPToken currentToken;
     TLPValue currentValue;
     while ((currentToken=tokenParser->nextToken(currentValue,curPos))!=ENDOFSTREAM) {
-	if (curPos%1000==1) if (!pluginProgress->progress(curPos,fileSize)) return false;
+	if (curPos%2000==1) if (pluginProgress->progress(curPos,fileSize)!=TLP_CONTINUE) 
+	  return pluginProgress->state()!=TLP_CANCEL;
 	switch (currentToken) {
 	  case OPENTOKEN:
 	    currentToken=tokenParser->nextToken(currentValue,curPos);
