@@ -719,7 +719,7 @@ bool DecodeColor	(	Color				&	outColor,
 	{
 		if( inValue.size() >= 7 && inValue[0] == '#' )
 		{
-			uint r, g, b;
+			unsigned int r, g, b;
 			int n = sscanf( inValue.c_str(), "#%02x%02x%02x", &r, &g, &b );
 			if( n == 3 ) {
 				outColor = Color(r,g,b);
@@ -734,7 +734,7 @@ bool DecodeColor	(	Color				&	outColor,
 		float r, g, b;
 		int n = sscanf( inValue.c_str(), "%f,%f,%f", &r, &g, &b );
 		if( n == 3 ) {
-			outColor = Color(uint(r*255.0f),uint(g*255.0f),uint(b*255.0f));
+			outColor = Color((unsigned int)(r*255.0f),(unsigned int)(g*255.0f),(unsigned int)(b*255.0f));
 			return true;
 		}
 	}
@@ -744,22 +744,22 @@ bool DecodeColor	(	Color				&	outColor,
 		float r, g, b;
 		int n = sscanf( inValue.c_str(), "%f %f %f", &r, &g, &b );
 		if( n == 3 ) {
-			outColor = Color(uint(r*255.0f),uint(g*255.0f),uint(b*255.0f));
+			outColor = Color((unsigned int)(r*255.0f),(unsigned int)(g*255.0f),(unsigned int)(b*255.0f));
 			return true;
 		}
 	}
 
 	// x11 name ?
 	{
-		uint N = sizeof(X11Clut) / sizeof(X11Color);
-		for( uint i = 0 ; i < N ; i++ ) {
+		unsigned int N = sizeof(X11Clut) / sizeof(X11Color);
+		for( unsigned int i = 0 ; i < N ; i++ ) {
 			if( strcasecmp(inValue.c_str(),X11Clut[i].name) == 0 ) {
 				float r,g,b;
 				HSBtoRGB(	float(X11Clut[i].h)/255.0f,
 							float(X11Clut[i].s)/255.0f,
 							float(X11Clut[i].b)/255.0f,
 							r, g ,b	);
-				outColor = Color(uint(r),uint(g),uint(b));
+				outColor = Color((unsigned int)(r),(unsigned int)(g),(unsigned int)(b));
 				return true;
 			}
 		}
