@@ -168,7 +168,7 @@ struct DOT_ATTR
 		STYLE		= (1<<11),
 	};
 
-	uint			mask;			// defined mask
+	unsigned int			mask;			// defined mask
 
 	Coord			layout;
 	int				shape;
@@ -264,8 +264,8 @@ struct DOT_ATTR
 			mask |= DEPTH;
 		}
 		else if( inId == "shape" ) {
-			uint N = sizeof(ShapeAttrA) / sizeof(ShapeAttr);
-			for( uint i = 0 ; i < N ; i++ ) {
+			unsigned int N = sizeof(ShapeAttrA) / sizeof(ShapeAttr);
+			for( unsigned int i = 0 ; i < N ; i++ ) {
 				if( !strcasecmp(ShapeAttrA[i].name,inValue.c_str()) ) {
 					shape = ShapeAttrA[i].idx;
 					mask |= SHAPE;
@@ -353,8 +353,8 @@ struct DOT_YY
 		EdgeA edgeA;
 		bool di = isStrict ? isDirected : ( inOp == "->" );
 		// produit cartesien A x B
-		for( uint i = 0 ; i < inA.size(); i++ ) {
-			for( uint j = 0 ; j < inB.size() ; j++ ) {
+		for( unsigned int i = 0 ; i < inA.size(); i++ ) {
+			for( unsigned int j = 0 ; j < inB.size() ; j++ ) {
 				edgeA.push_back( sg->addEdge(inA[i],inB[j]) );
 				if( !di )
 					edgeA.push_back( sg->addEdge(inB[j],inA[i]) );
@@ -400,7 +400,7 @@ struct DOT_YY
 
 		if( inAttr.mask & DOT_ATTR::LAYOUT ) {
 		    LayoutProxy * layoutP = sg->getProperty<LayoutProxy>(TLP_LAYOUT_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ )
+			for( unsigned int i = 0 ; i < inA.size() ; i++ )
 				layoutP->setNodeValue( inA[i], inAttr.layout );
 		}
 
@@ -409,7 +409,7 @@ struct DOT_YY
 		if( (inAttr.mask & DOT_ATTR::LABEL) && inAttr.label.size() ) {
 		    StringProxy * stringP  = sg->getProperty<StringProxy>(TLP_LABEL_PROXY_NAME);
 		    StringProxy * string2P = sg->getProperty<StringProxy>(TLP_EXTLABEL_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ ) {
+			for( unsigned int i = 0 ; i < inA.size() ; i++ ) {
 				stringP->setNodeValue( inA[i], inAttr.label );
 				string2P->setNodeValue( inA[i], inAttr.label );
 			}
@@ -423,7 +423,7 @@ struct DOT_YY
 		  	if( inAttr.mask & DOT_ATTR::HEIGHT )	s.setH( inAttr.size.getH() );
 		  	if( inAttr.mask & DOT_ATTR::DEPTH )		s.setD( inAttr.size.getD() );
 		    SizesProxy * sizeP = sg->getProperty<SizesProxy>(TLP_SIZE_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ )
+			for( unsigned int i = 0 ; i < inA.size() ; i++ )
 				sizeP->setNodeValue( inA[i], s );
 		}
 
@@ -431,7 +431,7 @@ struct DOT_YY
 
 	  	if( inAttr.mask & DOT_ATTR::COLOR )	{
 		    ColorsProxy * colP = sg->getProperty<ColorsProxy>(TLP_COLOR_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ )
+			for( unsigned int i = 0 ; i < inA.size() ; i++ )
 				colP->setNodeValue( inA[i], inAttr.color );
 		}
 
@@ -439,7 +439,7 @@ struct DOT_YY
 
 	  	{
 		    IntProxy * shapeP = sg->getProperty<IntProxy>(TLP_SHAPE_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ )
+			for( unsigned int i = 0 ; i < inA.size() ; i++ )
 				if( inAttr.mask & DOT_ATTR::SHAPE )
 					shapeP->setNodeValue( inA[i], inAttr.shape );
 				else
@@ -450,7 +450,7 @@ struct DOT_YY
 
 	  	if( inAttr.mask & DOT_ATTR::COMMENT ) {
 		    StringProxy * cmntP = sg->getProperty<StringProxy>(TLP_COMMENT_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ )
+			for( unsigned int i = 0 ; i < inA.size() ; i++ )
 				cmntP->setNodeValue( inA[i], inAttr.comment );
 		}
 
@@ -458,7 +458,7 @@ struct DOT_YY
 
 		if( (inAttr.mask & DOT_ATTR::URL) && inAttr.url.size() ) {
 		    StringProxy * urlP = sg->getProperty<StringProxy>(TLP_URL_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ )
+			for( unsigned int i = 0 ; i < inA.size() ; i++ )
 				urlP->setNodeValue( inA[i], inAttr.url );
 		}
 	}
@@ -473,7 +473,7 @@ struct DOT_YY
 		if( (inAttr.mask & DOT_ATTR::LABEL) && inAttr.label.size() ) {
 		    StringProxy * stringP = sg->getProperty<StringProxy>(TLP_LABEL_PROXY_NAME);
 		    StringProxy * string2P = sg->getProperty<StringProxy>(TLP_EXTLABEL_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ ) {
+			for( unsigned int i = 0 ; i < inA.size() ; i++ ) {
 				stringP->setEdgeValue( inA[i], inAttr.label );
 				string2P->setEdgeValue( inA[i], inAttr.label );
 			}
@@ -483,7 +483,7 @@ struct DOT_YY
 
 		if( (inAttr.mask & DOT_ATTR::HEAD_LABEL) && inAttr.headLabel.size() ) {
 		    StringProxy * labelP = sg->getProperty<StringProxy>(TLP_HEAD_LABEL_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ )
+			for( unsigned int i = 0 ; i < inA.size() ; i++ )
 				labelP->setEdgeValue( inA[i], inAttr.headLabel );
 		}
 
@@ -491,7 +491,7 @@ struct DOT_YY
 
 		if( (inAttr.mask & DOT_ATTR::TAIL_LABEL) && inAttr.tailLabel.size() ) {
 		    StringProxy * labelP = sg->getProperty<StringProxy>(TLP_TAIL_LABEL_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ )
+			for( unsigned int i = 0 ; i < inA.size() ; i++ )
 				labelP->setEdgeValue( inA[i], inAttr.tailLabel );
 		}
 
@@ -499,7 +499,7 @@ struct DOT_YY
 
 	  	if( inAttr.mask & DOT_ATTR::COLOR ) {
 		    ColorsProxy * colP = sg->getProperty<ColorsProxy>(TLP_COLOR_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ )
+			for( unsigned int i = 0 ; i < inA.size() ; i++ )
 				colP->setEdgeValue( inA[i], inAttr.color );
 		}
 
@@ -507,7 +507,7 @@ struct DOT_YY
 
 	  	if( inAttr.mask & DOT_ATTR::COMMENT ) {
 		    StringProxy * cmntP = sg->getProperty<StringProxy>(TLP_COMMENT_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ )
+			for( unsigned int i = 0 ; i < inA.size() ; i++ )
 				cmntP->setEdgeValue( inA[i], inAttr.comment );
 		}
 
@@ -515,7 +515,7 @@ struct DOT_YY
 
 		if( (inAttr.mask & DOT_ATTR::URL) && inAttr.url.size() ) {
 		    StringProxy * urlP = sg->getProperty<StringProxy>(TLP_URL_PROXY_NAME);
-			for( uint i = 0 ; i < inA.size() ; i++ )
+			for( unsigned int i = 0 ; i < inA.size() ; i++ )
 				urlP->setEdgeValue( inA[i], inAttr.url );
 		}
 	}
