@@ -25,12 +25,24 @@ bool Circular::run() {
   int i;
   double rayon;
   double sizeTm;
+
   layoutProxy->setAllEdgeValue(vector<Coord>(0));
+
   if (superGraph->numberOfNodes()<2) {
     rayon=0;
     resultSize.set(1,1,1);
   }
   else {
+    //compute circonference
+    Iterator<node> *itN=superGraph->getNodes();
+    while(itN->hasNext()) {
+      node itn=itN->next();
+      layoutProxy->setNodeValue(itn,Coord(rayon*cos(gamma*i)+rayon*2,rayon*sin(gamma*i)+rayon*2,0));
+      ++i;
+    } delete itN;
+
+
+
     rayon=100;
     gamma=2*M_PI/superGraph->numberOfNodes();
     double x1,y1,x2,y2;
@@ -55,5 +67,3 @@ bool Circular::run() {
 
 
 
-
-
