@@ -3,7 +3,8 @@
 #define _TREE3DLAYOUT_H
 
 #include <tulip/TulipPlugin.h>
-
+/** \addtogroup layout */
+/*@{*/
 /// ConeTree.h - An implementation of the Carierre and Kazman cone tree layout.
 /** This plugin is an implementation of the Cone tree layout
  *  algorithm first published as:
@@ -28,17 +29,17 @@
 class ConeTree:public Layout
 { 
 public:
-  ConeTree(PropertyContext *);
+  ConeTree(const PropertyContext &);
   ~ConeTree();
   bool run();
   bool check(std::string &);
   void reset();
 private:
-  double treePlace3D(node n, STL_EXT_NS::hash_map<node,double> *posRelX, STL_EXT_NS::hash_map<node,double> *posRelY);
-  void calcLayout(node n, STL_EXT_NS::hash_map<node,double> *px, STL_EXT_NS::hash_map<node,double> *py,
+  double treePlace3D(node n, stdext::hash_map<node,double> *posRelX, stdext::hash_map<node,double> *posRelY);
+  void calcLayout(node n, stdext::hash_map<node,double> *px, stdext::hash_map<node,double> *py,
 		  double x, double y, int level);
 };
-
+/*@}*/
 #endif
 
 
