@@ -16,15 +16,9 @@ float minRadius(float radius1,float alpha1,float radius2,float alpha2) {
   return sqrt(sqr(radius1+radius2)/(sqr(cos(alpha1)-cos(alpha2))+sqr(sin(alpha1)-sin(alpha2)))); 
 }
 
-static int progress=0;
-static bool breakAlgorithm=false;
-
 double ConeTreeExtended::treePlace3D(node n, 
 				     hash_map<node,double> *posRelX, 
 				     hash_map<node,double> *posRelY) {
-  if (breakAlgorithm) return 0;
-  progress++;
-  if (progress%100==0) breakAlgorithm=!pluginProgress->progress(progress,2*superGraph->numberOfNodes());
   (*posRelX)[n]=0;
   (*posRelY)[n]=0;
   if (superGraph->outdeg(n)==0) {return 1.0;}
@@ -59,7 +53,6 @@ double ConeTreeExtended::treePlace3D(node n,
     angle+=(subCircleRadius[i-1]+subCircleRadius[i])/radius;
     vangles[i]=angle;
   }
-
   // compute new radius
   newRadius=0;
   for (unsigned int i=0;i<subCircleRadius.size()-1;++i) {
@@ -67,7 +60,6 @@ double ConeTreeExtended::treePlace3D(node n,
       newRadius = newRadius >? minRadius(subCircleRadius[i],vangles[i],subCircleRadius[j],vangles[j]); 
     }
   }
-
   if (newRadius==0) newRadius=radius;
 
   //compute Circle Hull
@@ -91,9 +83,6 @@ double ConeTreeExtended::treePlace3D(node n,
 
 void ConeTreeExtended::calcLayout(node n, hash_map<node,double> *px, hash_map<node,double> *py,
 			double x, double y, int level) {
-  if (breakAlgorithm) return;
-  progress++;
-  if (progress%200==0) breakAlgorithm=!pluginProgress->progress(progress,2*superGraph->numberOfNodes());
   layoutProxy->setNodeValue(n,Coord(x+(*px)[n],level,y+(*py)[n]));
   Iterator<node> *it=superGraph->getOutNodes(n);
   for (;it->hasNext();) {
@@ -108,9 +97,6 @@ ConeTreeExtended::ConeTreeExtended(const PropertyContext &context):Layout(contex
 ConeTreeExtended::~ConeTreeExtended() {}
 
 bool ConeTreeExtended::run() {
-  breakAlgorithm=false;
-  progress=0;
-  breakAlgorithm=!pluginProgress->progress(0,2*superGraph->numberOfNodes());
   layoutProxy->setAllEdgeValue(vector<Coord>(0));
   hash_map<node,double> posX;
   hash_map<node,double> posY;
@@ -124,14 +110,10 @@ bool ConeTreeExtended::run() {
       startNode=itn;
       break;
     }
-  }delete itN;
-    
+  }delete itN;  
   treePlace3D(startNode,&posX,&posY);
   calcLayout(startNode,&posX,&posY,0,0,0);
-  if (!breakAlgorithm)
-    return true;
-  else
-    return false;
+  return true;
 }
 
 bool ConeTreeExtended::check(string &erreurMsg) {
