@@ -207,7 +207,8 @@ void GEM::insert() {
 
   startNode = -1;
   for (int i = 0; i < NodeCount; i++) {
-    if (!pluginProgress->progress(i,NodeCount)) return;
+    updateLayout();
+    if (pluginProgress->progress(i,NodeCount)!=TLP_CONTINUE) return;
     d = 0;
     for (int j = 0; j < NodeCount; j++)
       if (GemProp[j].in < d) {
@@ -351,12 +352,20 @@ void GEM::arrange() {
     Iteration        = 0;
     
     while (Temperature > stop_temperature && Iteration < stop_iteration) {
-      if (!pluginProgress->progress(Iteration,stop_iteration/2)) return;
+      updateLayout();
+      if (pluginProgress->progress(Iteration,stop_iteration/2)!=TLP_CONTINUE) return;
       this->a_round();
     }
 }
 
-
+void GEM::updateLayout(){
+  for (int i = 0; i < NodeCount; i++) {
+    GEMparam p = GemProp[ i ];
+    layoutProxy->setNodeValue(
+			      Invmap[i],
+			      Coord( p.pos.x, p.pos.y, 0 ) );
+  }
+}
 bool GEM::run() {
   node n;
   GEMparam p;
@@ -389,23 +398,19 @@ bool GEM::run() {
      
   if (i_finaltemp < i_starttemp)
     this->insert();
-  if (pluginProgress->progress(100,100)) 
+  if (pluginProgress->progress(100,100) == TLP_CONTINUE) 
     if (a_finaltemp < a_starttemp)
       this->arrange();
-  if (pluginProgress->progress(100,100)) 
-    for (int i = 0; i < NodeCount; i++) {
-      p = GemProp[ i ];
-      layoutProxy->setNodeValue(
-				Invmap[i],
-				Coord( p.pos.x, p.pos.y, 0 ) );
-    }       
+  if (pluginProgress->progress(100,100)==TLP_CONTINUE) 
+    updateLayout();
+
   delete [] GemProp;
   delete [] Invmap;
   delete [] Adjacent;
   if (Map) delete [] Map;
   if (Q) delete Q;
   
-  return pluginProgress->progress(100,100);
+  return pluginProgress->state()!=TLP_CANCEL;
 }
 
 
