@@ -87,7 +87,8 @@ public:
   void reset();
 
 private: 
- 
+
+  void updateLayout();
     typedef struct Vector {
       long int x, y;
       Vector(long int ix = 0, long int iy = 0):x(ix),y(iy){}
@@ -156,30 +157,30 @@ private:
      * GEM Defualt Parameter Values
      */
      
-    static const float IMAXTEMPDEF     = (float)1.0;
-    static const float ISTARTTEMPDEF   = (float)0.3;
-    static const float IFINALTEMPDEF   = (float)0.05;
+    static const float IMAXTEMPDEF     = 1.0;
+    static const float ISTARTTEMPDEF   = 0.3;
+    static const float IFINALTEMPDEF   = 0.05;
     static const int   IMAXITERDEF     = 10;
-    static const float IGRAVITYDEF     = (float)0.05;
-    static const float IOSCILLATIONDEF = (float)0.4;
-    static const float IROTATIONDEF    = (float)0.5;
-    static const float ISHAKEDEF       = (float)0.2;
-    static const float AMAXTEMPDEF     = (float)1.5;
-    static const float ASTARTTEMPDEF   = (float)1.0;
-    static const float AFINALTEMPDEF   = (float)0.02;
+    static const float IGRAVITYDEF     = 0.05;
+    static const float IOSCILLATIONDEF = 0.4;
+    static const float IROTATIONDEF    = 0.5;
+    static const float ISHAKEDEF       = 0.2;
+    static const float AMAXTEMPDEF     = 1.5;
+    static const float ASTARTTEMPDEF   = 1.0;
+    static const float AFINALTEMPDEF   = 0.02;
     static const int   AMAXITERDEF     = 3;
-    static const float AGRAVITYDEF     = (float)0.1;
-    static const float AOSCILLATIONDEF = (float)0.4;
-    static const float AROTATIONDEF    = (float)0.9;
-    static const float ASHAKEDEF       = (float)0.3;
-    static const float OMAXTEMPDEF     = (float)0.25;
-    static const float OSTARTTEMPDEF   = (float)1.0;
-    static const float OFINALTEMPDEF   = (float)1.0;
+    static const float AGRAVITYDEF     = 0.1;
+    static const float AOSCILLATIONDEF = 0.4;
+    static const float AROTATIONDEF    = 0.9;
+    static const float ASHAKEDEF       = 0.3;
+    static const float OMAXTEMPDEF     = 0.25;
+    static const float OSTARTTEMPDEF   = 1.0;
+    static const float OFINALTEMPDEF   = 1.0;
     static const int   OMAXITERDEF     = 3;
-    static const float OGRAVITYDEF     = (float)0.1;
-    static const float OOSCILLATIONDEF = (float)0.4;
-    static const float OROTATIONDEF    = (float)0.9;
-    static const float OSHAKEDEF       = (float)0.3;
+    static const float OGRAVITYDEF     = 0.1;
+    static const float OOSCILLATIONDEF = 0.4;
+    static const float OROTATIONDEF    = 0.9;
+    static const float OSHAKEDEF       = 0.3;
     
     /*
      * Following parameters can be initialised in the original GEM
