@@ -3,7 +3,6 @@
 #define Tulip_GeneralGraph3D_H
 #include <tulip/TulipPlugin.h>
 
-
 class SelfLoops
 {
 public:
@@ -27,21 +26,24 @@ struct LR
   int L;
   int R;
 };
+
+/** \addtogroup layout */
+/*@{*/
 ///
-class GeneralGraph3D:public Layout
-{ 
+class GeneralGraph3D:public Layout { 
 
 public:
-  GeneralGraph3D(PropertyContext *);
-  ~GeneralGraph3D();
-  
+  GeneralGraph3D(const PropertyContext &);
+  ~GeneralGraph3D();  
   bool run();
-  void DagLevelSpanningTree(SuperGraph* ,node n);
-  void makeAcyclic(SuperGraph*,set<edge> &,list<SelfLoops> &);
-  node makeSimpleSource(SuperGraph* superGraph);
-  void makeProperDag(SuperGraph* superGraph,list<node> &,hash_map<edge,edge> &);
-};
 
+private:
+  void DagLevelSpanningTree(SuperGraph* ,node n);
+  void makeAcyclic(SuperGraph*,std::set<edge> &,std::list<SelfLoops> &);
+  node makeSimpleSource(SuperGraph* superGraph);
+  void makeProperDag(SuperGraph* superGraph, std::list<node> &, stdext::hash_map<edge,edge> &);
+};
+/*@}*/
 #endif
 
 
