@@ -4,7 +4,8 @@
 #include <cmath>
 #include <tulip/TulipPlugin.h>
 
-
+/** \addtogroup layout */
+/*@{*/
 /// Tutte.h - An implementation of a 3-Connected graph layout.
 /** This plugin is an implementation of the Tutte layout
  *  algorithm first published as:
@@ -39,12 +40,12 @@
 */
 class Tutte:public Layout {
 public:
-  Tutte(PropertyContext *);
+  Tutte(const PropertyContext &);
   ~Tutte();
   
   bool run();
   bool check(std::string &);
   void reset();
 };
-
+/*@}*/
 #endif
