@@ -2,7 +2,7 @@
 
 METRICPLUGIN(ArityMetric,"Arity","David Auber","04/10/2001","Stable","0","1");
 
-ArityMetric::ArityMetric(PropertyContext *context):Metric(context) 
+ArityMetric::ArityMetric(const PropertyContext &context):Metric(context) 
 {}
 
 ArityMetric::~ArityMetric() {}
