@@ -4,7 +4,8 @@
 
 METRICPLUGIN(IdMetric,"Id","David Auber","06/04/2000","Alpha","0","1");
 
-IdMetric::IdMetric(const PropertyContext &context):Metric(context) {}
+IdMetric::IdMetric(const PropertyContext &context):Metric(context) {
+}
 
 IdMetric::~IdMetric() {}
 
