@@ -17,7 +17,7 @@
 class PathLengthMetric:public Metric
 { 
 public:
-  PathLengthMetric(PropertyContext *);
+  PathLengthMetric(const PropertyContext &);
   ~PathLengthMetric();
   double getNodeValue(const node n);
   bool check(std::string &);
