@@ -17,7 +17,7 @@
 class RandomMetric:public Metric
 { 
 public:
-  RandomMetric(PropertyContext *);
+  RandomMetric(const PropertyContext &);
   ~RandomMetric();
   double getNodeValue(const node n);
 };
