@@ -12,7 +12,7 @@
 class SegmentMetric:public Metric
 { 
 public:
-  SegmentMetric(PropertyContext *);
+  SegmentMetric(const PropertyContext &);
   ~SegmentMetric();
   double getNodeValue(const node n);
   int segNode(node,int &,int &);
