@@ -56,5 +56,5 @@ bool SpreadingActivationMetric::run()
     metricProxy->setNodeValue(itn,(*inBuf)[itn]);
   }delete it;
 
-  return pluginProgress->progress(100,100);
+  return pluginProgress->state()!=TLP_CANCEL;
 }
