@@ -17,7 +17,7 @@
 class SpreadingActivationMetric:public Metric
 { 
 public:
-  SpreadingActivationMetric(PropertyContext *);
+  SpreadingActivationMetric(const PropertyContext &);
   ~SpreadingActivationMetric();
   bool run();
 };
