@@ -94,7 +94,7 @@ struct SpreadingInterpolation: public Metric {
 
     delete spreading;
     delete strongComponnentDecomposition;
-    return true;
+    return pluginProgress->state()!=TLP_CANCEL;
   }
 };
 
