@@ -8,29 +8,25 @@ METRICPLUGIN(StrahlerAllMetric,"StrahlerAllGeneral","David Auber","06/04/2000","
 using namespace std;
 
 namespace std {
-  struct couple
-  {
+  struct couple {
     int p,r;
-    bool operator ==(const couple&d)
-    {
+    bool operator ==(const couple&d) {
       if ((p==d.p) && (r==d.r)) return true;
       return false;
     }
   };
-
-  struct equal_to<couple>
-  {
-    bool operator()(const couple &c,const couple &d)
-    {
+  
+  template<>
+  struct equal_to<couple> {
+    bool operator()(const couple &c,const couple &d) {
       if ((c.r==d.r) && (c.p==d.p)) return true;
       return false;
     }
   };
-
-  struct less<couple>
-  {
-    bool operator()(const couple &c,const couple &d)
-    {
+  
+  template<>
+  struct less<couple> {
+    bool operator()(const couple &c,const couple &d) {
       if (c.r<d.r) return true;
       if (c.r>d.r) return false;
       if (c.p<d.p) return true;
@@ -45,25 +41,20 @@ static int crossEdge=0;
 static int descentEdge=0;
 static int normalEdge=0;
 
-int max(int i1,int i2)
-{
+int max(int i1,int i2) {
   if (i1>i2) return i1; else return i2;
 }
 
-int min(int i1,int i2)
-{
+int min(int i1,int i2) {
   if (i1<i2) return i1; else return i2;
 }
-struct StackEval
-{
+struct StackEval {
   StackEval(int f,int u):freeS(f),usedS(u){}
   int freeS,usedS;
 };
 
-struct GreaterStackEval
-{
-  bool operator()(const StackEval e1,const StackEval e2)
-  {
+struct GreaterStackEval {
+  bool operator()(const StackEval e1,const StackEval e2) {
     return (e1.freeS>e2.freeS);
   }
 };
@@ -159,31 +150,29 @@ Strahler StrahlerAllMetric::topSortStrahler(node n, int &curPref,
   tmpEval.sort(gSE);
   result.stacks=0;
   result.usedStack=0;
-  for (list<StackEval>::iterator it=tmpEval.begin();it!=tmpEval.end();++it)
-    {
-      result.usedStack+=it->usedS;
-      result.stacks=max(result.stacks,it->freeS+it->usedS);//tmpValue.stacks-tmpValue.usedStack+tofree[n]);
-      result.stacks-=it->usedS;
-    }
+  for (list<StackEval>::iterator it=tmpEval.begin();it!=tmpEval.end();++it) {
+    result.usedStack+=it->usedS;
+    result.stacks=max(result.stacks,it->freeS+it->usedS);//tmpValue.stacks-tmpValue.usedStack+tofree[n]);
+    result.stacks-=it->usedS;
+  }
   result.stacks=result.stacks+result.usedStack;
   //evaluation du strahler simple
   int tmpDbl;
   int additional=0;
   int available=0;
   strahlerResult.sort();
-  while (!strahlerResult.empty())
-    {
-      tmpDbl=strahlerResult.back();
-      strahlerResult.pop_back();
-      if (tmpDbl>available)
-	{
-	  additional+=tmpDbl - available;
-	  available=tmpDbl - 1;
-	}
-      else
-	available -=1;
-    }
-
+  while (!strahlerResult.empty()) {
+    tmpDbl=strahlerResult.back();
+    strahlerResult.pop_back();
+    if (tmpDbl>available)
+      {
+	additional+=tmpDbl - available;
+	available=tmpDbl - 1;
+      }
+    else
+      available -=1;
+  }
+  
   result.strahler=additional;
   strahlerResult.clear();
   finished [n]=true;
@@ -197,8 +186,7 @@ StrahlerAllMetric::StrahlerAllMetric(const PropertyContext &context):Metric(cont
 StrahlerAllMetric::~StrahlerAllMetric()
 {}
 
-bool StrahlerAllMetric::run()
-{
+bool StrahlerAllMetric::run() {
   stdext::hash_map<node,bool> visited;
   stdext::hash_map<node,bool> finished;
   stdext::hash_map<node,int> prefix;
@@ -206,28 +194,25 @@ bool StrahlerAllMetric::run()
   stdext::hash_map<node,Strahler> cachedValues;
   int curPref=0;
   Iterator<node> *it=superGraph->getNodes();
-  for (int i=0;it->hasNext();++i)
-    {
-      if (!pluginProgress->progress(i,superGraph->numberOfNodes())) break;
-      visited.clear();
-      finished.clear();
-      prefix.clear();
-      tofree.clear();
-      cachedValues.clear();
-      curPref=0;
-      node itn=it->next();
-      tofree[itn]=0;
-      topSortStrahler(itn,curPref,tofree,prefix,visited,finished,cachedValues);
-      metricProxy->setNodeValue(itn,sqrt((double)cachedValues[itn].strahler*(double)cachedValues[itn].strahler
-					 +(double)cachedValues[itn].stacks*(double)cachedValues[itn].stacks));
-    }
-  delete it;
+  for (int i=0;it->hasNext();++i) {
+    if (pluginProgress->progress(i,superGraph->numberOfNodes())!=TLP_CONTINUE) break;
+    visited.clear();
+    finished.clear();
+    prefix.clear();
+    tofree.clear();
+    cachedValues.clear();
+    curPref=0;
+    node itn=it->next();
+    tofree[itn]=0;
+    topSortStrahler(itn,curPref,tofree,prefix,visited,finished,cachedValues);
+    metricProxy->setNodeValue(itn,sqrt((double)cachedValues[itn].strahler*(double)cachedValues[itn].strahler
+				       +(double)cachedValues[itn].stacks*(double)cachedValues[itn].stacks));
+  } delete it;
 
-  return pluginProgress->progress(100,100);
+  return pluginProgress->state()!=TLP_CANCEL;
 }
 
-bool StrahlerAllMetric::check(string &erreurMsg)
-{
+bool StrahlerAllMetric::check(string &erreurMsg) {
   erreurMsg="";
   return true;
 }
