@@ -9,14 +9,21 @@ StrengthMetric::StrengthMetric(const PropertyContext &context):Metric(context) {
 
 StrengthMetric::~StrengthMetric() {}
 
-double StrengthMetric::e(const hash_set<node> &U,const hash_set<node> &V) {
+double StrengthMetric::e(hash_set<node> &U,hash_set<node> &V) {
   hash_set<node>::const_iterator itU;
   double result=0;
-  for (itU=U.begin();itU!=U.end();++itU) {
+  hash_set<node> *A, *B;
+  if (U.size()<V.size()) {
+    A = &U; B=&V;
+  }
+  else {
+    A = &V; B=&U;
+  }
+  for (itU=A->begin();itU!=A->end();++itU) {
     Iterator<node> *itN=superGraph->getInOutNodes(*itU);
     while (itN->hasNext()) {
       node itn=itN->next();
-      if (V.find(itn)!=V.end()) result+=1.0;
+      if (B->find(itn)!=B->end()) result+=1.0;
     }delete itN;
   }
   return result;
@@ -35,7 +42,7 @@ double StrengthMetric::e(const hash_set<node> &U) {
   return result/2.0;
 }
 
-double StrengthMetric::s(const hash_set<node> &U,const hash_set<node> &V) {
+double StrengthMetric::s(hash_set<node> &U, hash_set<node> &V) {
   if ((U.size()==0) || (V.size()==0)) return 0;
   return (e(U,V) / double(U.size()*V.size()));
 }
@@ -48,33 +55,46 @@ double StrengthMetric::s(const hash_set<node> &U) {
 double StrengthMetric::getEdgeValue(const edge e ) {
   node u=superGraph->source(e);
   node v=superGraph->target(e);
-  hash_set<node> Nu,Nv,Wuv,Mu,Mv;
+  hash_set<node> Nu,Nv,Wuv;
+
   //Compute Nu
   Iterator<node> *itN=superGraph->getInOutNodes(u);
   while (itN->hasNext()) {
     node n=itN->next();
     if (n!=v) Nu.insert(n);
   }delete itN;
+  if (Nu.size()==0) return 0;
   //Compute Nv
   itN=superGraph->getInOutNodes(v);
   while (itN->hasNext()) {
     node n=itN->next();
     if (n!=u) Nv.insert(n);
-  }delete itN; 
-  //Compute Wuv
+  }delete itN;
+  if (Nv.size()==0) return 0;
+
+
+  //Compute Wuv, choose the minimum set to minimize operation
+  hash_set<node> *A, *B;
+  if (Nu.size()<Nv.size()) {
+    A = &Nu; B=&Nv;
+  }
+  else {
+    A = &Nv; B=&Nu;
+  }
   hash_set<node>::const_iterator itNu;
-  for (itNu=Nu.begin();itNu!=Nu.end();++itNu) {
-    if (Nv.find(*itNu)!=Nv.end()) Wuv.insert(*itNu);
+  for (itNu=A->begin();itNu!=A->end();++itNu) {
+    if (B->find(*itNu)!=B->end()) Wuv.insert(*itNu);
   }
-  //Compute Mu, this implementation is not optimal, should use stl operations
-  for (itNu=Nu.begin();itNu!=Nu.end();++itNu) {
-    if (Wuv.find(*itNu)==Wuv.end()) Mu.insert(*itNu);
+
+  hash_set<node> &Mu = Nu;
+  hash_set<node> &Mv = Nv;
+  /* Compute Mu and Mv, we do not need Nu and Nv anymore,
+     thus we modify them to speed up computation
+  */
+  for (itNu=Wuv.begin();itNu!=Wuv.end();++itNu) {
+    Mu.erase(*itNu);
+    Mv.erase(*itNu);
   }
-  //Compute Mv, this implementation is not optimal
-  hash_set<node>::const_iterator itNv;
-  for (itNv=Nv.begin();itNv!=Nv.end();++itNv) {
-    if (Wuv.find(*itNv)==Wuv.end()) Mv.insert(*itNv);
-  }  
 
   //compute strength metric
   double gamma4,gamma3;
