@@ -43,8 +43,8 @@ public:
   bool run();
 private:
   double e(const stdext::hash_set<node> &U);
-  double e(const stdext::hash_set<node> &U,const stdext::hash_set<node> &V);
-  double s(const stdext::hash_set<node> &U,const stdext::hash_set<node> &V);
+  double e(stdext::hash_set<node> &U, stdext::hash_set<node> &V);
+  double s(stdext::hash_set<node> &U, stdext::hash_set<node> &V);
   double s(const stdext::hash_set<node> &U);
 };
 /*@}*/
