@@ -8,7 +8,7 @@ class TreeArityMax:public Metric
 { 
 
 public:
-  TreeArityMax(PropertyContext *);
+  TreeArityMax(const PropertyContext &);
   ~TreeArityMax();
   double getNodeValue(const node n);
   bool check(std::string &);
