@@ -13,16 +13,18 @@
 #define _VIENNOTMETRIC_H
 
 #include <tulip/TulipPlugin.h>
+/** \addtogroup metric */
+/*@{*/
 ///
 class ViennotMetric:public Metric
 { 
 public:
-  ViennotMetric(PropertyContext *);
+  ViennotMetric(const PropertyContext &);
   ~ViennotMetric();
   double getNodeValue(const node n);
   bool check(std::string &err);
 };
-
+/*@}*/
 #endif
 
 
