@@ -3,15 +3,10 @@
 #define Tulip_InducedSubGraphSelection_H
 
 #include <tulip/TulipPlugin.h>
-///
-class InducedSubGraphSelection:public Selection
-{ 
+
+class InducedSubGraphSelection:public Selection { 
 public:
-  ///
   InducedSubGraphSelection(const PropertyContext &);
-  ///
-  ~InducedSubGraphSelection();
-  ///
   bool run();
 };
 
