@@ -3,18 +3,20 @@
 #define Tulip_ParaSelection_H
 
 #include <tulip/TulipPlugin.h>
+/** \addtogroup selection */
+/*@{*/
 ///
 class MultipleEdgeSelection:public Selection
 { 
 public:
   ///
-  MultipleEdgeSelection(PropertyContext *);
+  MultipleEdgeSelection(const PropertyContext &);
   ///
   ~MultipleEdgeSelection();
   ///
   bool run();
 };
-
+/*@}*/
 #endif
 
 
