@@ -82,7 +82,7 @@ bool ReachableSubGraphSelection::run() {
 	Iterator<node> *itN = superGraph->getNodes();
 	while (itN->hasNext()) { 
 	  node itn = itN->next();
-	  if (distance.get(itn.id) <= maxDepth) 
+	  if (distance.get(itn.id) <= maxDepth && distance.get(itn.id)<superGraph->numberOfNodes() ) 
 	    selectionProxy->setNodeValue(itn,true);
 	} delete itN;
       }
