@@ -8,18 +8,14 @@
 
 class TulipElementProperties;
 
-class Application:public QApplication
-{
+class Application:public QApplication {
 public:
-
   TulipElementProperties *nodeProperties;
   std::string bitmapPath;
   Color nodeColor;
   Color edgeColor;
-
   Application(int argc, char ** argv); 
   ~Application();
-  void  loadPlugin();
 };
 
 #endif
@@ -29,3 +25,6 @@ public:
 
 
 
+
+
+
