@@ -4,6 +4,8 @@
 #include "NavigateGlGraphData.h"
 struct SuperGraph;
 
+class QCloseEvent;
+
 class NavigateGlGraph : public NavigateGlGraphData
 { 
     Q_OBJECT
@@ -13,9 +15,13 @@ public:
     ~NavigateGlGraph();
 
     GlGraphWidget *getGlGraphWidget() const;
-
+    
 public slots:
-    void update();
+  void update();
+ void closeEvent(QCloseEvent *e); 
+
+signals:
+  void closed(NavigateGlGraph *);
 };
 
 #endif // NAVIGATEGLGRAPH_H
