@@ -32,13 +32,12 @@ public slots:
   void setAddEdge();
   void setAddNode();
   void setDel();
-  void setDelSelection();
+  void setZoomBox();
   void setMoveSelection();
   void setSelection();
   void setMagicSelection();
   void setGraphNavigate();
-  void setViewMagBox();
-  
+
 signals:
   void mouseChanged(MouseInterface *);
   
