@@ -31,11 +31,13 @@ class QEvent;
 class PropertyDialog;
 class NavigateGlGraph;
 class GlGraphWidget;
+class GlGraph;
 class View3DSetup;
 class ClusterTree;
 class TulipElementProperties;
 class ToolBar;
 class Overview;
+class Morphing;
 
 ///Widget for manipulation and visualization of a graph
 class viewGl : public TulipData, Observer {
@@ -45,7 +47,6 @@ public:
   viewGl(QWidget *parent=NULL, const char *name=NULL);
   virtual ~viewGl();
   void setParameters(const DataSet);
-  //  const GlGraphWidget *getGlGraphWidget() const;
   bool eventFilter(QObject *, QEvent *);
 
 protected:
@@ -60,7 +61,7 @@ protected:
   PropertyDialog *propertiesWidget;
   TulipElementProperties *nodeProperties;
   SuperGraph * copyCutPasteGraph;
-
+  bool elementsDisabled;
 
   //  QPopupMenu propertyMenu;
   QPopupMenu layoutMenu;
@@ -86,11 +87,16 @@ protected:
   void update ( ObserverIterator begin, ObserverIterator end);
   void initObservers();
   void clearObservers();
-  void timerEvent( QTimerEvent * );
+  void enableQPopupMenu(QPopupMenu *, bool);
+  void enableElements(bool);
+  void setNavigateCaption(std::string);
+  void initializeGraph(SuperGraph *);
+  void initializeGlGraph(GlGraph *);
 
 public slots:
   void fileOpen(std::string *,QString &);
-
+  void closeEvent(QCloseEvent *e); 
+  
 protected slots:
   void helpAbout();
   void fileExit();
@@ -134,14 +140,20 @@ protected slots:
   void goInside();
   void changeSuperGraph(SuperGraph *);
   void superGraphAboutToBeRemoved(SuperGraph *);
+  void navigateWidgetClosed(NavigateGlGraph *);
+  void ungroup();  
+  void group();  
 
 private:
-  template<typename PROPERTY> bool changeProperty(std::string, std::string, bool = true );
+  template<typename PROPERTY> bool changeProperty(std::string, std::string, bool = true, bool = false );
   GlGraphWidget *newOpenGlView(SuperGraph *graph,const QString &);
   stdext::hash_map<unsigned int, std::string> openFiles;
   void buildMenus();
   bool fileSave(std::string plugin, std::string filename);
+  int alreadyTreated(std::set<unsigned int>, SuperGraph *);
   unsigned int mouseClicX,mouseClicY;
+  Morphing *morph;
 };
 
 #endif // viewGl_included
+
