@@ -18,7 +18,7 @@ using namespace std;
 InfoDialog::InfoDialog( QWidget* parent,  const char* name, bool modal, WFlags fl )
     : InfoDialogForm( parent, name, modal, fl )
 {
-  string tmp="Tulip version ";
+  string tmp="Tulip v.";
   tmp+=VERSION;
   TextLabel2->setText(tmp.c_str());
 }
