@@ -12,8 +12,8 @@
 
 void MouseAddNode::mPressEvent(GlGraphWidget *glGraphWidget, QMouseEvent *qMouseEv){
   SuperGraph*_superGraph=glGraphWidget->getSuperGraph();
-  LayoutProxy* mLayout=getProxy<LayoutProxy>(_superGraph,"viewLayout");
-  ColorsProxy* mColors=getProxy<ColorsProxy>(_superGraph,"viewColors");
+  LayoutProxy* mLayout=_superGraph->getProperty<LayoutProxy>("viewLayout");
+  //  ColorsProxy* mColors=_superGraph->getProperty<ColorsProxy>("viewColor");
   node newNode;
   double x1,y1,z1;
   switch(qMouseEv->button()) {
@@ -21,9 +21,9 @@ void MouseAddNode::mPressEvent(GlGraphWidget *glGraphWidget, QMouseEvent *qMouse
       newNode = _superGraph->addNode();
       //if (isViewStrahler()) orderedNode.push_front(newNode);
       x1 = (double) glGraphWidget->width() - (double) qMouseEv->x() ;y1 = (double) qMouseEv->y();z1 = 0;
-      glGraphWidget->getGlGraph()->changeCoord(x1,y1,z1);
+      glGraphWidget->getGlGraph()->screenTo3DWorld(x1,y1,z1);
       mLayout->setNodeValue(newNode, Coord(x1,y1,z1));
-      mColors->setNodeValue(newNode,((Application *)qApp)->nodeColor);
+      //      mColors->setNodeValue(newNode,((Application *)qApp)->nodeColor);
       glGraphWidget->redraw();
       break;
   default:
