@@ -57,22 +57,17 @@ void MouseMagicSelection::mPressEvent(GlGraphWidget *glGraphWidget,QMouseEvent *
     bfsFifo.push_back(tmpNode);
     while(!bfsFifo.empty()) {
       node itn = bfsFifo.front();
-      selection->setNodeValue(itn,true);
       bfsFifo.pop_front();
+      selection->setNodeValue(itn,true);
+      visited->setNodeValue(itn,true);
       Iterator<node> *itN = superGraph->getInOutNodes(itn);
-      for (;itN->hasNext();) {
-	node itv= itN->next();
-	if (!visited->getNodeValue(itv)) {
-	  double curValue = metric->getNodeValue(itv);
-	  if (start) bfsFifo.push_back(itv);
-	  else
-	  if ( ((curValue<initValue+threshold) && (curValue>initValue-threshold)) ) {
-	    bfsFifo.push_back(itv);
-	  }
+      while (itN->hasNext()) {
+	node itv = itN->next();
+	double curValue = metric->getNodeValue(itv);
+	if ( curValue == initValue && (!visited->getNodeValue(itv)) ) {
+	  bfsFifo.push_back(itv);
 	}
-	visited->setNodeValue(itv,true);
-	start=false;
-      }delete itN;
+      } delete itN;
     }
     Observable::unholdObservers();
   }
