@@ -46,6 +46,7 @@ void MouseSelection::mPaint(GlGraphWidget *glGraphWidget){
     superGraph=0;started=false;glGraphWidget->setMouseTracking(false);
   }
   if (!started) return;
+  glPushAttrib(GL_ALL_ATTRIB_BITS);
   glMatrixMode (GL_PROJECTION);
   glPushMatrix();
   glLoadIdentity ();
@@ -77,14 +78,17 @@ void MouseSelection::mPaint(GlGraphWidget *glGraphWidget){
   glVertex2f(x,y-h);
   glEnd();
   glLineWidth(1);
-  glDisable(GL_LINE_STIPPLE);
+  /*
+    glDisable(GL_LINE_STIPPLE);
   glEnable(GL_DEPTH_TEST);
   glEnable(GL_CULL_FACE);
   glEnable(GL_LIGHTING);
+  */
   glPopMatrix();
   glMatrixMode (GL_PROJECTION);
   glPopMatrix();
   glMatrixMode (GL_MODELVIEW);
+  glPopAttrib();
 }
 /*
 
