@@ -3,6 +3,7 @@
 #endif
 
 #include <qpixmap.h>
+#include <qevent.h>
 
 #include <tulip/GlGraphWidget.h>
 #include <tulip/MouseObject.h>
@@ -38,7 +39,7 @@ NavigateGlGraph::NavigateGlGraph( QWidget* parent,  const char* name, SuperGraph
  */
 NavigateGlGraph::~NavigateGlGraph()
 {
-    // no need to delete child widgets, Qt does it all for us
+  // no need to delete child widgets, Qt does it all for us
 }
 
 GlGraphWidget *NavigateGlGraph::getGlGraphWidget() const
@@ -53,5 +54,8 @@ void NavigateGlGraph::update()
     qWarning( "NavigateGlGraph::update() not yet implemented!" ); 
 }
 
+void NavigateGlGraph::closeEvent(QCloseEvent *e) {
+  emit closed(this);
+}
 
 
