@@ -143,11 +143,11 @@ void PropertyDialog::newProperty() {
   QStringList lst;
   lst << "Selection" << "Metric" << "Layout" << "String" << "Integer" << "Sizes" << "Color";
   bool ok = FALSE;
-  QString res = QInputDialog::getItem( "Property type","Please select your property type", lst, 1, TRUE, &ok, this );
+  QString res = QInputDialog::getItem( "Property type","Please select your property type", lst, 1, FALSE, &ok, this );
   if ( ok ) {
       QString text = QInputDialog::getText("Property name", "Please enter the property name", QLineEdit::Normal, QString::null, &ok, this );
       if (ok) {
-	bool cached,resultBool;string erreurMsg;
+	string erreurMsg;
 	if (strcmp(res.ascii(),"Selection")==0) supergraph->getLocalProperty<SelectionProxy>(text.ascii());
 	if (strcmp(res.ascii(),"Metric")==0) supergraph->getLocalProperty<MetricProxy>(text.ascii());
 	if (strcmp(res.ascii(),"Layout")==0) supergraph->getLocalProperty<LayoutProxy>(text.ascii());
@@ -212,7 +212,7 @@ void PropertyDialog::cloneProperty() {
 	return;
       }
     }
-    bool cached,resultBool;string erreurMsg;
+    string erreurMsg;
     if (typeid((*editedProperty)) == typeid(MetricProxy))
       {*supergraph->getLocalProperty<MetricProxy>(text.ascii())=*((MetricProxy*)editedProperty);}
     if (typeid((*editedProperty)) == typeid(LayoutProxy))
