@@ -2,13 +2,14 @@
 #include <config.h>
 #endif
 
+#include <qfileinfo.h>
+
 #include <tulip/TlpTools.h>
 #include "AppStartUp.h"
 #include "Application.h"
 #include "viewGl.h"
 
-
-
+using namespace std;
 int main( int argc, char **argv ) {
   Application tulip( argc, argv );
   qApp=&tulip;
@@ -22,8 +23,9 @@ int main( int argc, char **argv ) {
   mainWindow->show();
   if (argc>1) {
     for (int i=1;i<argc;++i) {
-      QString s(argv[i]);
-      mainWindow->fileOpen(0,s);
+      QFileInfo info(argv[i]);
+      QString s = info.absFilePath();
+      mainWindow->fileOpen(0, s);
     }
   }
   //  delete appStart;
