@@ -337,14 +337,13 @@ int main (int argc, char **argv) {
     bool resultBool=false, cached=false;
     string errorMsg;
     if (LayoutProxy::factory.exists(layoutName)) {
-      LayoutProxy *myLayout = glGraph.getSuperGraph()->getLocalProperty<LayoutProxy>(layoutName, cached, resultBool, errorMsg);
-      if (cached) resultBool = myLayout->recompute(errorMsg);
+      LayoutProxy *myLayout = glGraph.getSuperGraph()->getProperty<LayoutProxy>("viewLayout");
+      resultBool = glGraph.getSuperGraph()->computeProperty(layoutName, myLayout, errorMsg);
       if (!resultBool) {
         cerr << programName << ": layout error, reason: " << errorMsg << endl;
         exit(LAYOUT_ERROR);
       }
       else {
-        *glGraph.getSuperGraph()->getLocalProperty<LayoutProxy>("viewLayout") = *myLayout;
         myLayout->resetBoundingBox();
         myLayout->center();
         myLayout->notifyObservers();
